% File src/library/base/man/Dates.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Dates}
\alias{Date}
\alias{Dates}
\alias{print.Date}
\alias{summary.Date}
\alias{Math.Date}
\alias{Summary.Date}
\alias{[.Date}
\alias{[<-.Date}
\alias{[[.Date}
\alias{as.data.frame.Date}
\alias{as.list.Date}
\alias{c.Date}
\alias{mean.Date}
\alias{split.Date}

\title{Date Class}
\description{
  暦日を表すクラス \code{"Date"} の記述．
}
\usage{
\method{summary}{Date}(object, digits = 12, \dots)
}
\arguments{
  \item{object}{要約されるオブジェクト．}
  \item{digits}{計算に対する有効桁数．}
  \item{\dots}{他のメソッドへ・から引き渡されるその他の引数．}
}
\details{
日付は 1970-01-01 からの日数で表される．負の数はそれ以前を表す．
これらは，大昔それが使われていなかったとしても，常に以下の現在の
グレゴリオ暦の規則(１７５２年に大英帝国とその植民地で採用された)
に従いプリントされる．

日付は整数であるとされるが，内部的表現では強制されない．
分数の日付はプリント時に無視される．分数の日付は \code{mean} メソッドや，
加減算で生成することが出来る(\code{\link{Ops.Date}} を参照)．

プリントメソッドは \code{\link{options}("max.print")} を尊重する．
}
\seealso{
  現在の日付は \code{\link{Sys.Date}}．

  \code{"Date"} オブジェクトに対する演算には \code{\link{Ops.Date}}．

  文字列への・からの変換には \code{\link{format.Date}}．

  プロットには \code{\link{axis.Date}} と \code{\link{hist.Date}}．

  便利な抽出関数は \code{\link{weekdays}}．

  ユーティリティ操作 \code{\link{seq.Date}}, \code{\link{cut.Date}}, \code{\link{round.Date}}．

  暦日時刻クラスは \code{\link{DateTimeClasses}} ．
}
\examples{\donttest{
(today <- Sys.Date())
format(today, "\%d \%b \%Y")  # 月を単語として
(tenweeks <- seq(today, length.out=10, by="1 week")) # 次の10日
weekdays(today)
months(tenweeks)
as.Date(.leap.seconds)
}}
\keyword{utilities}
\keyword{chron}

%% File src/library/base/man/Dates.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Dates}
%\alias{Date}
%\alias{Dates}
%\alias{print.Date}
%\alias{summary.Date}
%\alias{Math.Date}
%\alias{Summary.Date}
%\alias{[.Date}
%\alias{[<-.Date}
%\alias{[[.Date}
%\alias{as.data.frame.Date}
%\alias{as.list.Date}
%\alias{c.Date}
%\alias{mean.Date}
%\alias{split.Date}
%
%\title{Date Class}
%\description{
%  Description of the class \code{"Date"} representing calendar dates.
%}
%\usage{
%\method{summary}{Date}(object, digits = 12, \dots)
%}
%\arguments{
%  \item{object}{An object summarized.}
%  \item{digits}{Number of significant digits for the computations.}
%  \item{\dots}{Further arguments to be passed from or to other methods.}
%}
%\details{
%  Dates are represented as the number of days since 1970-01-01, with
%  negative values for earlier dates.  They are always printed
%  following the rules of the current Gregorian calendar, even though
%  that calendar was not in use long ago (it was adopted in 1752 in
%  Great Britain and its colonies).
%
%  It is intended that the date should be an integer, but this is not
%  enforced in the internal representation.  Fractional days will be
%  ignored when printing.  It is possible to produce fractional days via
%  the \code{mean} method or by adding or subtracting (see
%  \code{\link{Ops.Date}}).
%
%  The print methods respect \code{\link{options}("max.print")}.
%}
%\seealso{
%  \code{\link{Sys.Date}} for the current date.
%
%  \code{\link{Ops.Date}} for operators on \code{"Date"} objects.
%
%  \code{\link{format.Date}} for conversion to and from character strings.
%
%  \code{\link{axis.Date}} and
%  \code{\link{hist.Date}} for plotting.
%
%  \code{\link{weekdays}} for convenience extraction functions.
%
%  \code{\link{seq.Date}}, \code{\link{cut.Date}},
%  \code{\link{round.Date}} for utility operations.
%
%  \code{\link{DateTimeClasses}} for date-time classes.
%}
%\examples{\donttest{
%(today <- Sys.Date())
%format(today, "\%d \%b \%Y")  # with month as a word
%(tenweeks <- seq(today, length.out=10, by="1 week")) # next ten weeks
%weekdays(today)
%months(tenweeks)
%as.Date(.leap.seconds)
%}}
%\keyword{utilities}
%\keyword{chron}
%

\encoding{UTF8}
