% File src/library/base/man/Encoding.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{Encoding}
\alias{Encoding}
\alias{Encoding<-}
\alias{enc2native}
\alias{enc2utf8}
\concept{encoding}
\title{Read or Set the Declared Encodings for a Character Vector}
\description{
文字列に対する宣言されたエンコーディングを読む，設定する.
}
\usage{
Encoding(x)

Encoding(x) <- value

enc2native(x)
enc2utf8(x)
}
\arguments{
  \item{x}{文字列ベクトル．}
  \item{value}{正の長さの文字列ベクトル．}
}
\details{
\R の文字列ベクトルは \code{"latin1"} または \code{"UTF-8"} もしくは \code{"bytes"} として
エンコードされると宣言されている．こうした宣言は \code{Encoding} で見ることができ，
これは値 \code{"latin1"}, \code{"UTF-8"}, \code{"bytes"} もしくは \code{"unknown"}
からなる文字列ベクトルを返す． または \code{value} が必要に応じてリサイクルされ設定され，
他の値は黙って \code{"unknown"} として扱われる．
アスキー文字列は決して宣言されたエンコーディングでマークされない．
なぜならすべてのサポートされているエンコーディングで表現が同一であるからである．
\code{"bytes"} とマークされた文字列はバイトとして処理されるべき非アスキー文字列を意図して
おり，文字列エンコーディングに決して変換されない(だからそれらをテキスト
ファイルに書き出すことはサポートされていない)．% non-bug report PR#16327

\code{enc2native} と \code{enc2utf8} は文字列ベクトルの要素を
それぞれネイティブのエンコーディングかUFT-８に変換し，任意のマークされたエンコーディングを
考慮する．これらは \link{primitive} 関数であり，最小機能のコピーを行うように
デザインされている．

明確に設定する以外に文字列が宣言されたエンコーディングを持つようにする別の方法も
ある(そしてこれは \R が進化するに従い変化してきている．
関数 \code{\link{scan}},  \code{\link{read.table}}, \code{\link{readLines}}， そして
\code{\link{parse}} はエンコーディングを宣言するのに使える \code{encoding} 引数を持つ．
\code{\link{iconv}} はエンコーディングをその \code{to} 引数から宣言する．
適当なロケールでのコンソール入力もそうである．
\code{\link{intToUtf8}} はその入力を \code{"UTF-8"} と宣言し，出力テキストコネクション
(\code{\link{textConnection}} を見よ)は適応なロケール下で動作しているときはマークされる．
ある種の状況(ヘルプ頁を見よ)では \code{\link{source}(encoding=)} はそれが
出力する文字列のエンコーディングをマークする．

殆どの文字操作関数は，もし対応入力が宣言されていれば，
出力にそのエンコーディングを設定する．
これらは \code{\link{chartr}}, \code{\link{strsplit}(useBytes = FALSE)},
\code{\link{tolower}} そして \code{\link{toupper}}，また同様に 
\code{\link{sub}(useBytes = FALSE)} そして \code{\link{gsub}(useBytes =
 FALSE)} を含む．そうした関数はエンコーディングを \emph{保存しない} ことを
 注意しよう．しかしもし入力エンコーディングが知られており，文字列が成功裏に
 再エンコーディング(現在のエンコーディングか UTF-8 に)されておれば，
 出力はマークされる．

\code{\link{substr}} はエンコーディングを保存せず，
\code{\link{chartr}}, \code{\link{tolower}} そして \code{\link{toupper}} 
はシステムのユニコード幅広文字を持つ UTF-8 エンコーディングを保存する．
\code{fixed} と \code{perl} オプション付きで， \code{\link{strsplit}},
  \code{\link{sub}} そして  \code{gsub} は，もし入力のどれかが UTF-8 であれば，
マークされた UTF-8 の結果を返す．

\code{\link{paste}} と \code{\link{sprintf}} は，もし対応入力のどれかがバイトと
マークされていれば，バイトとマークされた要素を返す．そして，さもなければ，
入力のどれかが UTF-8 とマークされていれば UTF-8 とマークされる．

\code{\link{match}}, \code{\link{pmatch}}, \code{\link{charmatch}},
\code{\link{duplicated}} そして \code{\link{unique}} は，要素のどれかが
UTF-8 とマークされていれば UTF-8 でマッチする．
}
\value{
文字列ベクトル．

\code{enc2utf8} に対してはエンコーディングは常にマークされる：
これらは UTF-8 と Latin-1 ロケールでの \code{enc2native} 用である．
}
\examples{
## x は latin1 であると意図している
x <- "fa\xE7ile"
Encoding(x)
Encoding(x) <- "latin1"
x
xx <- iconv(x, "latin1", "UTF-8")
Encoding(c(x, xx))
c(x, xx)
Encoding(xx) <- "bytes"
xx # 16進数でエンコードされる
cat("xx = ", xx, "\n", sep = "")
}
\keyword{utilities}
\keyword{character}


%% File src/library/base/man/Encoding.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Encoding}
%\alias{Encoding}
%\alias{Encoding<-}
%\alias{enc2native}
%\alias{enc2utf8}
%\concept{encoding}
%\title{Read or Set the Declared Encodings for a Character Vector}
%\description{
%  Read or set the declared encodings for a character vector.
%}
%\usage{
%Encoding(x)
%
%Encoding(x) <- value
%
%enc2native(x)
%enc2utf8(x)
%}
%\arguments{
%  \item{x}{A character vector.}
%  \item{value}{A character vector of positive length.}
%}
%\details{
%  Character strings in \R can be declared to be encoded in
%  \code{"latin1"} or \code{"UTF-8"} or as \code{"bytes"}.  These
%  declarations can be read by \code{Encoding}, which will return a
%  character vector of values \code{"latin1"}, \code{"UTF-8"}
%  \code{"bytes"} or \code{"unknown"}, or set, when \code{value} is
%  recycled as needed and other values are silently treated as
%  \code{"unknown"}.  ASCII strings will never be marked with a declared
%  encoding, since their representation is the same in all supported
%  encodings.  Strings marked as \code{"bytes"} are intended to be
%  non-ASCII strings which should be manipulated as bytes, and never
%  converted to a character encoding (so writing them to a text file is
%  not supported). % non-bug report PR#16327
%
%  \code{enc2native} and \code{enc2utf8} convert elements of character
%  vectors to the native encoding or UTF-8 respectively, taking any
%  marked encoding into account.  They are \link{primitive} functions,
%  designed to do minimal copying.
%
%  There are other ways for character strings to acquire a declared
%  encoding apart from explicitly setting it (and these have changed as
%  \R has evolved).  Functions \code{\link{scan}},
%  \code{\link{read.table}}, \code{\link{readLines}}, and
%  \code{\link{parse}} have an \code{encoding} argument that is used to
%  declare encodings, \code{\link{iconv}} declares encodings from its
%  \code{to} argument, and console input in suitable locales is also
%  declared.  \code{\link{intToUtf8}} declares its output as
%  \code{"UTF-8"}, and output text connections (see
%  \code{\link{textConnection}}) are marked if running in a
%  suitable locale.  Under some circumstances (see its help page)
%  \code{\link{source}(encoding=)} will mark encodings of character
%  strings it outputs.
%
%  Most character manipulation functions will set the encoding on output
%  strings if it was declared on the corresponding input.  These include
%  \code{\link{chartr}}, \code{\link{strsplit}(useBytes = FALSE)},
%  \code{\link{tolower}} and \code{\link{toupper}} as well as
%  \code{\link{sub}(useBytes = FALSE)} and \code{\link{gsub}(useBytes =
%  FALSE)}.  Note that such functions do not \emph{preserve} the
%  encoding, but if they know the input encoding and that the string has
%  been successfully re-encoded (to the current encoding or UTF-8), they
%  mark the output.
%
%  \code{\link{substr}} does preserve the encoding, and
%  \code{\link{chartr}}, \code{\link{tolower}} and \code{\link{toupper}}
%  preserve UTF-8 encoding on systems with Unicode wide characters.  With
%  their \code{fixed} and \code{perl} options, \code{\link{strsplit}},
%  \code{\link{sub}} and \code{gsub} will give a marked UTF-8 result if
%  any of the inputs are UTF-8.
%
%  \code{\link{paste}} and \code{\link{sprintf}} return elements marked
%  as bytes if any of the corresponding inputs is marked as bytes, and
%  otherwise marked as UTF-8 of any of the inputs is marked as UTF-8.
%
%  \code{\link{match}}, \code{\link{pmatch}}, \code{\link{charmatch}},
%  \code{\link{duplicated}} and \code{\link{unique}} all match in UTF-8
%  if any of the elements are marked as UTF-8.
%}
%\value{
%  A character vector.
%
%  For \code{enc2utf8} encodings are always marked: they are for
%  \code{enc2native} in UTF-8 and Latin-1 locales.
%}
%\examples{
%## x is intended to be in latin1
%x <- "fa\xE7ile"
%Encoding(x)
%Encoding(x) <- "latin1"
%x
%xx <- iconv(x, "latin1", "UTF-8")
%Encoding(c(x, xx))
%c(x, xx)
%Encoding(xx) <- "bytes"
%xx # will be encoded in hex
%cat("xx = ", xx, "\n", sep = "")
%}
%\keyword{utilities}
%\keyword{character}
%
%
\encoding{UTF8}
