% File src/library/base/man/Sys.time.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Sys.time}
\alias{Sys.time}
\alias{Sys.Date}

\title{Get Current Date and Time}
\description{
  \code{Sys.time} と \code{Sys.Date} はシステムが考えるところの
現在の日付を時刻付き，無しで返す．
}
\usage{
Sys.time()
Sys.Date()
}
\details{
  \code{Sys.time} は絶対的な日付・時刻を返しす．これは
様々なタイムゾーンに変換でき，異なった日付を返すかもしれない．

  \code{Sys.Date} は現在のタイムゾーンでの日付を返す．
}
\value{
  \code{Sys.time} はクラス \code{"POSIXct"} のオブジェクトを
返す(\link{DateTimeClasses} を見よ)．ほとんどすべてのシステムで
これは秒以下の精度を持ち，可能性としてマイクロ秒かそれ以上である．
Windows ではこれはクロック単位(普通 1/60 秒)で増加しミリ秒の精度と
報告されている．

  \code{Sys.Date} はクラス \code{"Date"} のオブジェクトを返す
(\link{Date} を見よ)．
}
\note{
  \code{Sys.time} は分数秒を返すが，クラス \code{"POSIXct"}
 に対する既定の変換(例えばプリント)で無視される．
 確認には例と \code{\link{format.POSIXct}} を見よ．
}
\seealso{
  固定書式文字列でのシステムタイムについては \code{\link{date}}．

  \code{\link{Sys.timezone}}．
  
  表現式の経過/CPU時間については \code{\link{system.time}}．
}
\examples{\donttest{
Sys.time()
## 恐らくより正確にプリントする：
op <- options(digits.secs = 6)
Sys.time()
options(op)

## ロケール固有のバージョンの date()
format(Sys.time(), "\%a \%b \%d \%X \%Y")

Sys.Date()
}}
\keyword{utilities}
\keyword{chron}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Sys.time.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Sys.time}
%\alias{Sys.time}
%\alias{Sys.Date}
%
%\title{Get Current Date and Time}
%\description{
%  \code{Sys.time} and \code{Sys.Date} returns the system's idea of the
%  current date with and without time.
%}
%\usage{
%Sys.time()
%Sys.Date()
%}
%\details{
%  \code{Sys.time} returns an absolute date-time value which can be
%  converted to various time zones and may return different days.
%
%  \code{Sys.Date} returns the current day in the current \link{time zone}.
%}
%\value{
%  \code{Sys.time} returns an object of class \code{"POSIXct"} (see
%  \link{DateTimeClasses}).  On almost all systems it will have
%  sub-second accuracy, possibly microseconds or better.  On Windows it
%  increments in clock ticks (usually 1/60 of a second) reported to
%  millisecond accuracy.
%
%  \code{Sys.Date} returns an object of class \code{"Date"} (see \link{Date}).
%}
%\note{
%  \code{Sys.time} may return fractional seconds, but they are ignored by
%  the default conversions (e.g., printing) for class \code{"POSIXct"}.
%  See the examples and \code{\link{format.POSIXct}} for ways to reveal them.
%}
%\seealso{
%  \code{\link{date}} for the system time in a fixed-format character
%  string.
%
%  \code{\link{Sys.timezone}}.
%  
%  \code{\link{system.time}} for measuring elapsed/CPU time of expressions.
%}
%\examples{\donttest{
%Sys.time()
%## print with possibly greater accuracy:
%op <- options(digits.secs = 6)
%Sys.time()
%options(op)
%
%## locale-specific version of date()
%format(Sys.time(), "\%a \%b \%d \%X \%Y")
%
%Sys.Date()
%}}
%\keyword{utilities}
%\keyword{chron}
%
\encoding{UTF8}
