% File src/library/base/man/octmode.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2012 R Core Team
% Distributed under GPL 2 or later

\name{bitwise}
\alias{bitwNot}
\alias{bitwAnd}
\alias{bitwOr}
\alias{bitwXor}
\alias{bitwShiftL}
\alias{bitwShiftR}

\title{Bitwise Logical Operations}
\description{
  要素をビットの集まりとみなした整数ベクトルへの論理演算．
}
\usage{
bitwNot(a)
bitwAnd(a, b)
bitwOr(a, b)
bitwXor(a, b)

bitwShiftL(a, n)
bitwShiftR(a, n)
}
\arguments{
  \item{a, b}{整数ベクトル；数値ベクトルは整数ベクトルに変換される．}
  \item{n}{値が最大31の非負整数ベクトル．}
}
\details{
  整数ベクトルの各要素は32ビットを持つ．

  対毎の演算結果は整数 \code{NA} になるかもしれない．

  シフト操作は値が符号なし整数と仮定して行われる．
}
\value{
  長さが引数のそれの大きい方である整数ベクトル．もしくは
  一方が長さがゼロなら長さはゼロになる．

  出力要素は，もし入力が  \code{NA} (強変換後に)か不正なシフトであれば，
  \code{NA} になる．
}
\seealso{
  論理演算 \code{\link{!}},  \code{\link{&}},
  \code{\link{|}}, \code{\link{xor}}．
  
  クラス \code{"octmode"} と \code{"hexmnode"} の標準的論理演算の実装は
  これらの関数に基づいている．

  パッケージ \pkg{bitOps} は数値ベクトルに対する類似の関数を持ち，
   \eqn{2^{31}}{2^31} やそれ以上の整数の処理法が異なる．
}

\examples{
bitwAnd(15L, 7L)
bitwOr(15L, 7L)
bitwXor(15L, 7L)
bitwXor(-1L, 1L)

bitwShiftR(-1, 1:31) # 2^32-1 = 4294967295 のシフト
}

\keyword{logic}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/octmode.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{bitwise}
%\alias{bitwNot}
%\alias{bitwAnd}
%\alias{bitwOr}
%\alias{bitwXor}
%\alias{bitwShiftL}
%\alias{bitwShiftR}
%
%\title{Bitwise Logical Operations}
%\description{
%  Logical operations on integer vectors with elements viewed as sets of bits.
%}
%\usage{
%bitwNot(a)
%bitwAnd(a, b)
%bitwOr(a, b)
%bitwXor(a, b)
%
%bitwShiftL(a, n)
%bitwShiftR(a, n)
%}
%\arguments{
%  \item{a, b}{integer vectors; numeric vectors are coerced to integer vectors.}
%  \item{n}{non-negative integer vector of values up to 31.}
%}
%\details{
%  Each element of an integer vector has 32 bits.
%
%  Pairwise operations can result in integer \code{NA}.
%
%  Shifting is done assuming the values represent unsigned integers.
%}
%\value{
%  An integer vector of length the longer of the arguments, or zero
%  length if one is zero-length.
%
%  The output element is \code{NA} if an input is \code{NA} (after
%  coercion) or an invalid shift.
%}
%\seealso{
%  The logical operators, \code{\link{!}},  \code{\link{&}},
%  \code{\link{|}}, \code{\link{xor}}.
%
%  The classes \code{"octmode"} and \code{"hexmnode"} whose
%  implementation of the standard logical operators is based on these
%  functions.
%
%  Package \pkg{bitOps} has similar functions for numeric vectors which
%  differ in the way they treat integers \eqn{2^{31}}{2^31} or larger.
%}
%
%\examples{
%bitwAnd(15L, 7L)
%bitwOr(15L, 7L)
%bitwXor(15L, 7L)
%bitwXor(-1L, 1L)
%
%bitwShiftR(-1, 1:31) # shifts of 2^32-1 = 4294967295
%}
%
%\keyword{logic}
%
\encoding{UTF8}
