% File src/library/base/man/body.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{body}
\alias{body}
\alias{body<-}
\title{Access to and Manipulation of the Body of a Function}
\description{
  関数の本体を得る，設定する．
}
\usage{
body(fun = sys.function(sys.parent()))
body(fun, envir = environment(fun)) <- value
}
\arguments{
  \item{fun}{関数オブジェクト，もしくは\sQuote{詳細}を見よ．}
  \item{envir}{その中に関数が定義されるべき環境．}
  \item{value}{オブジェクトで，普通言語オブジェクト：
    \sQuote{値}の節を見よ．}
}
\details{
  最初の形式では \code{fun} は操作されるべき関数の名前を与える文字列で良い．
  これは親環境から探される．もしこれが指定されないと
  \code{body} を呼び出している関数が使われる．

  最も単純なものを除けば本体は波括弧で括られた表現式，
  つまり \code{\{} の呼び出しである：そうした呼び出しの作り方については
  \sQuote{例}の節を見よ．
}
\value{
  \code{body} は指定された関数の本体を返す．これは通常
  言語オブジェクトであり，最もしばしば \code{\{} の呼び出しであるが，
  関数の返り値であるオブジェクト(例えば \code{pi})でも良い．

  置き換え形は関数の本体を右側のオブジェクトに設定し，
  (可能性として)関数の環境をリセットする．
  もし \code{value} がクラス \code{"\link{expression}"} ならば，
  最初の要素が本体として使われる：他のすべての要素は無視され，警告が出る．
}
\seealso{
  \code{\link{alist}},
  \code{\link{args}},
  \code{\link{function}}.
}
\examples{
body(body)
f <- function(x) x^5
body(f) <- quote(5^x)
## もしくは同じことだが  body(f) <- expression(5^x)
f(3) # = 125
body(f)

## 複数表現式をもつ本体を作る
e <- expression(y <- x^2, return(y)) # or a list
body(f) <- as.call(c(as.name("{"), e))
f
f(8)
}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/body.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{body}
%\alias{body}
%\alias{body<-}
%\title{Access to and Manipulation of the Body of a Function}
%\description{
%  Get or set the body of a function.
%}
%\usage{
%body(fun = sys.function(sys.parent()))
%body(fun, envir = environment(fun)) <- value
%}
%\arguments{
%  \item{fun}{a function object, or see \sQuote{Details}.}
%  \item{envir}{environment in which the function should be defined.}
%  \item{value}{an object, usually a \link{language object}: see section
%    \sQuote{Value}.}
%}
%\details{
%  For the first form, \code{fun} can be a character string
%  naming the function to be manipulated, which is searched for from the
%  parent frame.  If it is not specified, the function calling
%  \code{body} is used.
%
%  The bodies of all but the simplest are braced expressions, that is
%  calls to \code{\{}: see the \sQuote{Examples} section for how to
%  create such a call.
%}
%\value{
%  \code{body} returns the body of the function specified.  This is
%  normally a \link{language object}, most often a call to \code{\{}, but
%  it can also be an object (e.g., \code{pi}) to be the return value of
%  the function.
%
%  The replacement form sets the body of a function to the
%  object on the right hand side, and (potentially) resets the
%  environment of the function.  If \code{value} is of class
%  \code{"\link{expression}"} the first element is used as the body:  any
%  additional elements are ignored, with a warning.
%}
%\seealso{
%  \code{\link{alist}},
%  \code{\link{args}},
%  \code{\link{function}}.
%}
%\examples{
%body(body)
%f <- function(x) x^5
%body(f) <- quote(5^x)
%## or equivalently  body(f) <- expression(5^x)
%f(3) # = 125
%body(f)
%
%## creating a multi-expression body
%e <- expression(y <- x^2, return(y)) # or a list
%body(f) <- as.call(c(as.name("{"), e))
%f
%f(8)
%}
%\keyword{programming}
%
\encoding{UTF8}
