% File src/library/base/man/conditions.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{conditions}
\alias{conditions}
\alias{condition}
\alias{computeRestarts}
\alias{conditionCall}
\alias{conditionMessage}
\alias{findRestart}
\alias{invokeRestart}
\alias{invokeRestartInteractively}
\alias{isRestart}
\alias{restartDescription}
\alias{restartFormals}
\alias{signalCondition}
\alias{simpleCondition}
\alias{simpleError}
\alias{simpleWarning}
\alias{simpleMessage}
\alias{tryCatch}
\alias{withCallingHandlers}
\alias{withRestarts}

\alias{.signalSimpleWarning}
\alias{.handleSimpleError}

\alias{as.character.condition}
\alias{as.character.error}
\alias{conditionCall.condition}
\alias{conditionMessage.condition}
\alias{print.condition}
\alias{print.restart}

\title{Condition Handling and Recovery}
\description{
  これらの関数はエラーや警告を含む例外的条件の処理に対する機構を与える．
}

\usage{
tryCatch(expr, \dots, finally)
withCallingHandlers(expr, \dots)

signalCondition(cond)

simpleCondition(message, call = NULL)
simpleError    (message, call = NULL)
simpleWarning  (message, call = NULL)
simpleMessage  (message, call = NULL)

\method{as.character}{condition}(x, \dots)
\method{as.character}{error}(x, \dots)
\method{print}{condition}(x, \dots)
\method{print}{restart}(x, \dots)

conditionCall(c)
\method{conditionCall}{condition}(c)
conditionMessage(c)
\method{conditionMessage}{condition}(c)

withRestarts(expr, \dots)

computeRestarts(cond = NULL)
findRestart(name, cond = NULL)
invokeRestart(r, \dots)
invokeRestartInteractively(r)

isRestart(x)
restartDescription(r)
restartFormals(r)

.signalSimpleWarning(msg, call)
.handleSimpleError(h, msg, call)
}

\arguments{
  \item{c}{条件オブジェクト．}
  \item{call}{呼び出し表現式．}
  \item{cond}{条件オブジェクト．}
  \item{expr}{評価されるべき表現式．}
  \item{finally}{復帰もしくは励起(excite)前に評価されるべき表現式．}
  \item{h}{関数．}
  \item{message}{文字列．}
  \item{msg}{文字列．}
  \item{name}{再開処理(restart)の名前を与える文字列．}
  \item{r}{再開処理オブジェクト．}
  \item{x}{オブジェクト．}
  \item{\dots}{追加引数．以下の詳細を見よ．}
}

\details{
   条件システムはエラーと警告を含む例外的条件の合図と処理に対する機構を与える．
   条件はメッセージとそれが生起した呼び出しのような，生起条件に関する
   情報を含むオブジェクトとして表現される．
   現在の条件は S3 風のオブジェクトであるが，いつか変更されるかもしれない．

   条件は抽象的クラス \code{condition} を継承するオブジェクトである．
   エラーと警告は抽象的サブクラス \code{error} と \code{warning} を
   継承する．クラス \code{simpleError} は \code{stop} と
   すべての内部エラー信号によって使われ，
   そして \code{simpleMessage} は \code{message} によって使用される．
   同じ名前による構成子は引数として条件を記述する文字列と
   オプションの呼び出しを取る．関数
   \code{conditionMessage} と \code{conditionCall} は
   メッセージと条件の呼び出しを返す総称的関数である．

   条件は \code{signalCondition} によりシグナルが生じる.  更に，
   \code{stop} と \code{warning} 関数は条件付き引数も受け付けるように
   変更されている．

   関数 \code{tryCatch} はその表現式引数を \code{\dots} 引数中で提供された
   ハンドラーが利用可能な文脈中で評価する．
   それから \code{finally} 表現式が  \code{tryCatch} が呼び出された
   文脈中で評価される；つまり，現在の \code{tryCatch} 呼び出しに与えられた
   ハンドラーは \code{finally} 表現式が評価される時アクティブではない．

   \code{tryCatch} への \code{\dots} 引数中で与えられたハンドラーは
   \code{expr} の評価の持続の間確立される．
   \code{expr} の評価中に如何なる条件もシグナルを発しなければ，
   \code{tryCatch} は表現式の値を返す．

   ある条件が  \code{expr} の評価中にシグナルを発生すれば，
   条件のクラスにマッチするものに対し，確立されたハンドラーが
   最も最近に確立されたそれからチェックする．
   一つの \code{tryCatch} に複数のハンドラーが提供されると，
   最初のものが二番目よりより新しいとされる．
   もしハンドラーが見つかると，制御はそのハンドラーを確立した 
   \code{tryCatch} の呼び出しに移り，見つかったハンドラーと
   すべてのより最近のハンドラーが不確立になる．
   ハンドラーがその引数を条件として呼び出され，ハンドラーが返した
   結果が \code{tryCatch} 呼び出しの結果として返される．

   呼び出しハンドラーは \code{withCallingHandlers} によって確立される．
   もしある条件がシグナルを生じ，適用可能なハンドラーが呼び出しハンドラーならば，
   そのハンドラーが条件がシグナルを生じた文脈中で \code{signalCondition}
   により呼びだされる．しかしながら利用可能なハンドラーはハンドラーのスタックで
   呼びだされたハンドラーよりも下にあるものに制限される．
   もしハンドラーが復帰すると，次のハンドラーが試される；
   最後のハンドラーが試されると \code{signalCondition} は
   \code{NULL} を返す．

   ユーザによる中断は既定の中断動作の前に
   クラス \code{condition} を継承するクラス \code{interrupt} の
   条件のシグナルを生じさせる．

   再開処理は復元プロトコルを確立するために使われる．
   それらは \code{withRestarts} を使って確立することが出来る．
   一つの予め確立された再開処理は
   トップレベルへのジャンプを表す \code{abort} である．

   \code{findRestart} と \code{computeRestarts} は利用可能な再開処理を探す．
   \code{findRestart} は指定された名前を持つ最も最近に確立された再開処理を
   返す．\code{computeRestarts} はすべての再開処理のリストを与える．
   どちらも条件の引数を与えることができ，
   そうするとその条件に適用できない再開処理を無視する．

   \code{invokeRestart} は制御を指定された再開処理が確立した点へ
   移し，そして再開処理のハンドラーを，(もしあれば) \code{invokeRestart}
   への追加引数として与えられた引数と共に呼び出す．
   \code{invokeRestart} への再開処理引数は文字列でも良く，
   その場合 \code{findRestart} が再開処理を探すために使われる．

    \code{withRestarts} に対する新しい再開処理は幾つもの方法で
    指定できる．
   最も単純なものは \code{name = function} の形式で，ここで関数は
   再開処理が起動された時に呼び出すハンドラーである．もう一つの
   単純な変種は \code{name = string} とすることで，ここで文字列は
   \code{findRestart} によって返される再開処理オブジェクトの
   \code{description} 欄に保管されている：
   このケースではハンドラーはその引数を無視し \code{NULL} を返す．
   最も柔軟性に富んだ再開処理指定の形式は，\code{handler},
   \code{description}, そして \code{test} のような幾つかの欄を含むことが出来る
   リストを使うことである．
   \code{test} 欄は唯一の引数が条件である関数を含むべきで，
   これは再開処理が条件に適用されれば \code{TRUE} を，
   さもなければ \code{FALSE} を返す；既定の関数はあらゆる条件に対して
   \code{TRUE} を返す．

   再開処理に対して指定できる一つの欄は
   \code{interactive} である．これは引数を持たず，再開処理ハンドラーに
   引き渡す引数リストを返すべきである．
   必要ならリストは対話的にユーザが与えても良い．
   関数 \code{invokeRestartInteractively} はこの関数を再開処理を
   起動する際に使う引数を得るために呼び出す．
   既定の \code{interactive} メソッドはハンドラー関数の形式的引数
   に対する値についてユーザに問い合わせる．

   \code{.signalSimpleWarning} と \code{.handleSimpleError}
   は内部的に使われ，直接呼び出すべきではない．
}

\references{\code{tryCatch} 機構は Java のエラー処理に類似している．
  呼び出しハンドラーは Common Lisp と Dylan に基づいている．
  再開は Common Lisp の再開機構に基づいている．}

\seealso{シグナル条件には \code{\link{stop}} と \code{\link{warning}}，
  そして \code{\link{try}} は本質的に \code{tryCatch} の簡易版．
  パッケージ \pkg{tools} 中の \code{\link{assertCondition}} は
  上記のハンドラーによって条件が合図され動作したことをテストする．
}

\examples{
tryCatch(1, finally = print("Hello"))
e <- simpleError("test error")
\dontrun{
 stop(e)
 tryCatch(stop(e), finally = print("Hello"))
 tryCatch(stop("fred"), finally = print("Hello"))
}
tryCatch(stop(e), error = function(e) e, finally = print("Hello"))
tryCatch(stop("fred"),  error = function(e) e, finally = print("Hello"))
withCallingHandlers({ warning("A"); 1+2 }, warning = function(w) {})
\dontrun{
 { withRestarts(stop("A"), abort = function() {}); 1 }
}
withRestarts(invokeRestart("foo", 1, 2), foo = function(x, y) {x + y})

##--> より多くの例には
##-->   demo(error.catching)
}
\keyword{programming}
\keyword{error}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/conditions.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{conditions}
%\alias{conditions}
%\alias{condition}
%\alias{computeRestarts}
%\alias{conditionCall}
%\alias{conditionMessage}
%\alias{findRestart}
%\alias{invokeRestart}
%\alias{invokeRestartInteractively}
%\alias{isRestart}
%\alias{restartDescription}
%\alias{restartFormals}
%\alias{signalCondition}
%\alias{simpleCondition}
%\alias{simpleError}
%\alias{simpleWarning}
%\alias{simpleMessage}
%\alias{tryCatch}
%\alias{withCallingHandlers}
%\alias{withRestarts}
%
%\alias{.signalSimpleWarning}
%\alias{.handleSimpleError}
%
%\alias{as.character.condition}
%\alias{as.character.error}
%\alias{conditionCall.condition}
%\alias{conditionMessage.condition}
%\alias{print.condition}
%\alias{print.restart}
%
%\title{Condition Handling and Recovery}
%\description{
%  These functions provide a mechanism for handling unusual conditions,
%  including errors and warnings.
%}
%
%\usage{
%tryCatch(expr, \dots, finally)
%withCallingHandlers(expr, \dots)
%
%signalCondition(cond)
%
%simpleCondition(message, call = NULL)
%simpleError    (message, call = NULL)
%simpleWarning  (message, call = NULL)
%simpleMessage  (message, call = NULL)
%
%\method{as.character}{condition}(x, \dots)
%\method{as.character}{error}(x, \dots)
%\method{print}{condition}(x, \dots)
%\method{print}{restart}(x, \dots)
%
%conditionCall(c)
%\method{conditionCall}{condition}(c)
%conditionMessage(c)
%\method{conditionMessage}{condition}(c)
%
%withRestarts(expr, \dots)
%
%computeRestarts(cond = NULL)
%findRestart(name, cond = NULL)
%invokeRestart(r, \dots)
%invokeRestartInteractively(r)
%
%isRestart(x)
%restartDescription(r)
%restartFormals(r)
%
%.signalSimpleWarning(msg, call)
%.handleSimpleError(h, msg, call)
%}
%
%\arguments{
%  \item{c}{a condition object.}
%  \item{call}{call expression.}
%  \item{cond}{a condition object.}
%  \item{expr}{expression to be evaluated.}
%  \item{finally}{expression to be evaluated before returning or exiting.}
%  \item{h}{function.}
%  \item{message}{character string.}
%  \item{msg}{character string.}
%  \item{name}{character string naming a restart.}
%  \item{r}{restart object.}
%  \item{x}{object.}
%  \item{\dots}{additional arguments; see details below.}
%}
%
%\details{
%
%   The condition system provides a mechanism for signaling and
%   handling unusual conditions, including errors and warnings.
%   Conditions are represented as objects that contain information
%   about the condition that occurred, such as a message and the call in
%   which the condition occurred.  Currently conditions are S3-style
%   objects, though this may eventually change.
%
%   Conditions are objects inheriting from the abstract class
%   \code{condition}.  Errors and warnings are objects inheriting
%   from the abstract subclasses \code{error} and \code{warning}.
%   The class \code{simpleError} is the class used by \code{stop}
%   and all internal error signals.  Similarly, \code{simpleWarning}
%   is used by \code{warning}, and \code{simpleMessage} is used by
%   \code{message}.  The constructors by the same names take a string
%   describing the condition as argument and an optional call.  The
%   functions \code{conditionMessage} and \code{conditionCall} are
%   generic functions that return the message and call of a condition.
%
%   Conditions are signaled by \code{signalCondition}.  In addition,
%   the \code{stop} and \code{warning} functions have been modified to
%   also accept condition arguments.
%
%   The function \code{tryCatch} evaluates its expression argument
%   in a context where the handlers provided in the \code{\dots}
%   argument are available.  The \code{finally} expression is then
%   evaluated in the context in which \code{tryCatch} was called; that
%   is, the handlers supplied to the current \code{tryCatch} call are
%   not active when the \code{finally} expression is evaluated.
%
%   Handlers provided in the \code{\dots} argument to \code{tryCatch}
%   are established for the duration of the evaluation of \code{expr}.
%   If no condition is signaled when evaluating \code{expr} then
%   \code{tryCatch} returns the value of the expression.
%
%   If a condition is signaled while evaluating \code{expr} then
%   established handlers are checked, starting with the most recently
%   established ones, for one matching the class of the condition.
%   When several handlers are supplied in a single \code{tryCatch} then
%   the first one is considered more recent than the second.  If a
%   handler is found then control is transferred to the
%   \code{tryCatch} call that established the handler, the handler
%   found and all more recent handlers are disestablished, the handler
%   is called with the condition as its argument, and the result
%   returned by the handler is returned as the value of the
%   \code{tryCatch} call.
%
%   Calling handlers are established by \code{withCallingHandlers}.  If
%   a condition is signaled and the applicable handler is a calling
%   handler, then the handler is called by \code{signalCondition} in
%   the context where the condition was signaled but with the available
%   handlers restricted to those below the handler called in the
%   handler stack.  If the handler returns, then the next handler is
%   tried; once the last handler has been tried, \code{signalCondition}
%   returns \code{NULL}.
%
%   User interrupts signal a condition of class \code{interrupt} that
%   inherits directly from class \code{condition} before executing the
%   default interrupt action.
%
%   Restarts are used for establishing recovery protocols.  They can be
%   established using \code{withRestarts}.  One pre-established restart is
%   an \code{abort} restart that represents a jump to top level.
%
%   \code{findRestart} and \code{computeRestarts} find the available
%   restarts.  \code{findRestart} returns the most recently established
%   restart of the specified name.  \code{computeRestarts} returns a
%   list of all restarts.  Both can be given a condition argument and
%   will then ignore restarts that do not apply to the condition.
%
%   \code{invokeRestart} transfers control to the point where the
%   specified restart was established and calls the restart's handler with the
%   arguments, if any, given as additional arguments to
%   \code{invokeRestart}.  The restart argument to \code{invokeRestart}
%   can be a character string, in which case \code{findRestart} is used
%   to find the restart.
%
%   New restarts for \code{withRestarts} can be specified in several ways.
%   The simplest is in \code{name = function} form where the function is
%   the handler to call when the restart is invoked.  Another simple
%   variant is as \code{name = string} where the string is stored in the
%   \code{description} field of the restart object returned by
%   \code{findRestart}; in this case the handler ignores its arguments
%   and returns \code{NULL}.  The most flexible form of a restart
%   specification is as a list that can include several fields, including
%   \code{handler}, \code{description}, and \code{test}.  The
%   \code{test} field should contain a function of one argument, a
%   condition, that returns \code{TRUE} if the restart applies to the
%   condition and \code{FALSE} if it does not; the default function
%   returns \code{TRUE} for all conditions.
%
%   One additional field that can be specified for a restart is
%   \code{interactive}.  This should be a function of no arguments that
%   returns a list of arguments to pass to the restart handler.  The list
%   could be obtained by interacting with the user if necessary.  The
%   function \code{invokeRestartInteractively} calls this function to
%   obtain the arguments to use when invoking the restart.  The default
%   \code{interactive} method queries the user for values for the
%   formal arguments of the handler function.
%
%   \code{.signalSimpleWarning} and \code{.handleSimpleError}
%   are used internally and should not be called directly.
%}
%
%\references{The \code{tryCatch} mechanism is similar to Java
%  error handling.  Calling handlers are based on Common Lisp and
%  Dylan.  Restarts are based on the Common Lisp restart mechanism.}
%
%\seealso{\code{\link{stop}} and \code{\link{warning}} signal conditions,
%  and \code{\link{try}} is essentially a simplified version of
%  \code{tryCatch}.
%  \code{\link{assertCondition}} in package \pkg{tools} \emph{tests}
%  that conditions are signalled and works with several of the above
%  handlers.
%}
%
%\examples{
%tryCatch(1, finally = print("Hello"))
%e <- simpleError("test error")
%\dontrun{
% stop(e)
% tryCatch(stop(e), finally = print("Hello"))
% tryCatch(stop("fred"), finally = print("Hello"))
%}
%tryCatch(stop(e), error = function(e) e, finally = print("Hello"))
%tryCatch(stop("fred"),  error = function(e) e, finally = print("Hello"))
%withCallingHandlers({ warning("A"); 1+2 }, warning = function(w) {})
%\dontrun{
% { withRestarts(stop("A"), abort = function() {}); 1 }
%}
%withRestarts(invokeRestart("foo", 1, 2), foo = function(x, y) {x + y})
%
%##--> More examples are part of
%##-->   demo(error.catching)
%}
%\keyword{programming}
%\keyword{error}
%
\encoding{UTF8}
