% File src/library/base/man/cumsum.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{cumsum}
\alias{cumsum}
\alias{cumprod}
\alias{cummin}
\alias{cummax}
\title{Cumulative Sums, Products, and Extremes}
\description{
  引数の要素の累積した和，積，最小値又は最大値が要素であるベクトルを返す．
}
\usage{
cumsum(x)
cumprod(x)
cummax(x)
cummin(x)
}
\arguments{
  \item{x}{数値又は複素数(\code{cummin} や \code{cummax} では無し)
    オブジェクト，もしくはそうしたものの一つに強制変換出来る
    オブジェクト．}
}
\details{
  これらは総称的関数である：それらに対するメソッドを
  個別に又は \code{\link[=S3groupGeneric]{Math}} グループ総称的に
  定義できる．
}
\value{
  \code{x} と同じ(強制変換後の)長さと型のベクトル．
  但し \code{cumprod} は整数入力に対して数値ベクトルを返す
  (\code{*} との一貫性のため)．名前は保存される．

  \code{x} 中の \code{NA} 値は返り値の対応する，そしてそれ以降の
  要素を \code{NA} にする．
  \code{cumsum} の桁溢れの場合も含む(警告が出る)．
}
\section{S4 メソッド}{
  \code{cumsum} と \code{cumprod} は S4 総称的関数である：
  それらに対するメソッドを個別に，又は
  \code{\link[=S4groupGeneric]{Math}} グループ総称的に書くことが出来る．
  \code{cummax} と \code{cummin} は個別に S4 総称的関数である．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole. (\code{cumsum} のみ．)
}
\examples{
cumsum(1:10)
cumprod(1:10)
cummin(c(3:1, 2:0, 4:2))
cummax(c(3:1, 2:0, 4:2))
}
\keyword{arith}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/cumsum.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cumsum}
%\alias{cumsum}
%\alias{cumprod}
%\alias{cummin}
%\alias{cummax}
%\title{Cumulative Sums, Products, and Extremes}
%\description{
%  Returns a vector whose elements are the cumulative sums, products,
%  minima or maxima of the elements of the argument.
%}
%\usage{
%cumsum(x)
%cumprod(x)
%cummax(x)
%cummin(x)
%}
%\arguments{
%  \item{x}{a numeric or complex (not \code{cummin} or \code{cummax})
%    object, or an object that can be coerced to one of these.}
%}
%\details{
%  These are generic functions: methods can be defined for them
%  individually or via the \code{\link[=S3groupGeneric]{Math}} group generic.
%}
%\value{
%  A vector of the same length and type as \code{x} (after coercion),
%  except that \code{cumprod} returns a numeric vector for integer input
%  (for consistency with \code{*}).  Names are preserved.
%
%  An \code{NA} value in \code{x} causes the corresponding and following
%  elements of the return value to be \code{NA}, as does integer overflow
%  in \code{cumsum} (with a warning).
%}
%\section{S4 methods}{
%  \code{cumsum} and \code{cumprod} are S4 generic functions:
%  methods can be defined for them individually or via the
%  \code{\link[=S4groupGeneric]{Math}} group generic.
%  \code{cummax} and \code{cummin} are individually S4 generic functions.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole. (\code{cumsum} only.)
%}
%\examples{
%cumsum(1:10)
%cumprod(1:10)
%cummin(c(3:1, 2:0, 4:2))
%cummax(c(3:1, 2:0, 4:2))
%}
%\keyword{arith}
%
\encoding{UTF8}
