% File src/library/base/man/dcf.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{dcf}
\alias{read.dcf}
\alias{write.dcf}
\title{Read and Write Data in DCF Format}
\description{
  \R オブジェクトを Debian Control File 書式のファイルから・へ読み書きする．
}
\usage{
read.dcf(file, fields = NULL, all = FALSE, keep.white = NULL)

write.dcf(x, file = "", append = FALSE,
          indent = 0.1 * getOption("width"),
          width = 0.9 * getOption("width"),
          keep.white = NULL)
}
\arguments{
  \item{file}{ファイルやコネクションの名前を与える文字列．
    \code{""} はコンソールへの出力を指示する．
    \code{read.dcf} に対してはこれは圧縮ファイルの名前で良い
    (\code{\link{gzfile}} を見よ)．}
  \item{fields}{DFC ファイルから読み取る欄．既定ではすべての欄を読む．}
  \item{all}{論理値で，記録の中に一つの欄が複数ある時これをすべて
    一緒にすることを指示する．
    もし \code{all} が偽なら(既定)そうしたものの最後に登場したものが使われる．}
  \item{keep.white}{欄名の空白をそのままにする欄の文字列，又は
    \code{NULL} (既定)はそうした欄が無いことを指示する．
    可能ならば文字列に強制変換する．
    空白がそのままにされない欄に対しては，
    \code{read.dcf} は先頭と末尾にある空白は取り除かれ，
    そして \code{write.dcf} は \code{\link{strwrap}} を用いて保持する．}
  \item{x}{書き込まれるべきオブジェクトで典型的にはデータフレーム．
    もしそうでなければ \code{x} をデータフレームに強制変換しようとする．}
  \item{append}{論理値．もし \code{TRUE} なら出力はファイルに付加される．
    もし \code{FALSE} ならその名前の既存のファイルは破壊される．}
  \item{indent}{出力項目中の継続行に対するインデンテーションを指定する正整数．}
  \item{width}{出力中の行の折り返しに対する目標コラムを与える正整数．}
}
\details{
  DCF は平文テキストファイル中にデータベースを保管する簡単な書式で，
  人が簡単に直接読み書きできる．DCF は記述やパッケージの内容等の \R
  のシステム情報を保管するために様々な場所で使われる．

  \R に移植されている DCF 規則は：
  \enumerate{
    \item データベースは一つ又はそれ以上の記録からなり，各々は一つ又は
    それ以上の名前付き欄を持つ．すべての記録が各欄を持つ必要はない．
    欄は一つの記録に複数回登場しても良い．
    \item 普通の行は空白でない文字から始まる．
    \item 普通の行は \code{tag:value} の形式である，つまり名前タグと
    その欄に対する名前を持ち \code{:} で分離される(最初の 
    \code{:} がカウントされる)．値は空であっても良い(つまり空白のみ)．
    \item もし行に空白以外の文字が一つでもあれば，空白で始まる行は
    継続行である(先行欄に対して)．空白でない文字が\samp{.} だけで
    ある継続行は空の行とされる(複数パラグラフの欄値を許す)．
    \item 記録は一つもしくはそれ以上の空の行(つまり空白文字のみ)で
    分離される．
    \item 個々の行は任意に長くなれないかもしれない；\R 3.0.2 以前では
    長さの制限は行ごとに約 8191 バイトである．
  }

  \code{read.dcf(all = FALSE)} は欄をバイトごとに読むことを注意する．
  これは読み込まれる \file{DESCRIPTION} ファイルの ASCII 欄のみが
  使われること，又はその \samp{Encoding} 欄は残りの欄の再エンコーディング
  に使われることを許す．

  \code{write.dcf} は \code{NA} 欄を書き込まない．
}
\value{
  既定の \code{read.dcf(all = FALSE)} は記録ごとに一つの行と欄ごとに一つの
  列を持つ文字列行列を返す．欄の値の先頭と末尾の引き続く空白は
  欄が \code{keep.white} 中にリストされていなければ無視される．
  もしタグ名がファイル中に指定されているが対応する値が空ならば，
  空文字列が返される．
  もし欄のタグ名が \code{fields} 中に指定されているが記録中に
  使われていないならば，対応する値は \code{NA} である．
  もし欄が記録中で繰り返されていれば，遭遇した最後の欄が返される．
  不正な書式の行はエラーになる．

  \code{read.dcf(all = TRUE)} に対してはデータフレームが返され，
  再び記録ごとに一つの行と欄ごとに一つの列をもつ．
  列は複数回登場した欄に対する文字列ベクトルのリストであり，
  さもなければ文字列ベクトルである．

  空のファイルは適正な DCF ファイルであることを注意しよう．そして
  \code{read.dcf} はゼロ行の行列やデータフレームを返す．

  \code{write.dcf} に対しては不可視の \code{NULL}．
}

\references{
  \url{https://www.debian.org/doc/debian-policy/ch-controlfields.html}.
  
  \R はエンコーディング UTF-8 を要求していない．それは最近の
  Debian の要求である．更にそれは \samp{#} で始まるコメント行を認める
  Debian 固有の副書式も使用しない．
}
\seealso{
  \code{\link{write.table}}.

   \code{read.dcf} を使ってパッケージのレポジトリの索引を読む
   \code{\link{available.packages}}．
}
\examples{\donttest{
## パッケージ  'splines' 中の DESCRIPTION file の簡略版を作る
x <- read.dcf(file = system.file("DESCRIPTION", package = "splines"),
              fields = c("Package", "Version", "Title"))
write.dcf(x)

## 複数の記録を持つオンラインの DCF ファイル
con <- url("http://cran.r-project.org/src/contrib/PACKAGES")
y <- read.dcf(con, all = TRUE)
close(con)
utils::str(y)
}}
\keyword{print}
\keyword{file}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/dcf.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dcf}
%\alias{read.dcf}
%\alias{write.dcf}
%\title{Read and Write Data in DCF Format}
%\description{
%  Reads or writes an \R object from/to a file in Debian Control File
%  format.
%}
%\usage{
%read.dcf(file, fields = NULL, all = FALSE, keep.white = NULL)
%
%write.dcf(x, file = "", append = FALSE,
%          indent = 0.1 * getOption("width"),
%          width = 0.9 * getOption("width"),
%          keep.white = NULL)
%}
%\arguments{
%  \item{file}{either a character string naming a file or a \link{connection}.
%    \code{""} indicates output to the console.  For \code{read.dcf} this
%    can name a compressed file (see \code{\link{gzfile}}).}
%  \item{fields}{Fields to read from the DCF file.  Default is to read all
%    fields.}
%  \item{all}{a logical indicating whether in case of multiple
%    occurrences of a field in a record, all these should be gathered.
%    If \code{all} is false (default), only the last such occurrence is
%    used.}
%  \item{keep.white}{a character string with the names of the fields for
%    which whitespace should be kept as is, or \code{NULL} (default)
%    indicating that there are no such fields.  Coerced to character if
%    possible.  For fields where whitespace is not to be kept as is,
%    \code{read.dcf} removes leading and trailing whitespace, and
%    \code{write.dcf} folds using \code{\link{strwrap}}.
%   }
%  \item{x}{the object to be written, typically a data frame.  If not, it
%    is attempted to coerce \code{x} to a data frame.}
%  \item{append}{logical.  If \code{TRUE}, the output is appended to the
%    file.  If \code{FALSE}, any existing file of the name is destroyed.}
%  \item{indent}{a positive integer specifying the indentation for
%    continuation lines in output entries.}
%  \item{width}{a positive integer giving the target column for wrapping
%    lines in the output.}
%}
%\details{
%  DCF is a simple format for storing databases in plain text files that
%  can easily be directly read and written by humans.  DCF is used in
%  various places to store \R system information, like descriptions and
%  contents of packages.
%
%  The DCF rules as implemented in \R are:
%  \enumerate{
%    \item A database consists of one or more records, each with one or
%    more named fields.  Not every record must contain each field.
%    Fields may appear more than once in a record.
%    \item Regular lines start with a non-whitespace character.
%    \item Regular lines are of form \code{tag:value}, i.e., have a name
%    tag and a value for the field, separated by \code{:} (only the first
%    \code{:} counts).  The value can be empty (i.e., whitespace only).
%    \item Lines starting with whitespace are continuation lines (to the
%    preceding field) if at least one character in the line is
%    non-whitespace.  Continuation lines where the only non-whitespace
%    character is a \samp{.} are taken as blank lines (allowing for
%    multi-paragraph field values).
%    \item Records are separated by one or more empty (i.e., whitespace
%    only) lines.
%    \item Individual lines may not be arbitrarily long; prior to \R 3.0.2 the
%    length limit was approximately 8191 bytes per line.
%  }
%
%  Note that \code{read.dcf(all = FALSE)} reads the file byte-by-byte.
%  This allows a \file{DESCRIPTION} file to be read and only its ASCII
%  fields used, or its \samp{Encoding} field used to re-encode the
%  remaining fields.
%
%  \code{write.dcf} does not write \code{NA} fields.
%}
%\value{
%  The default \code{read.dcf(all = FALSE)} returns a character matrix
%  with one row per record and one column per field.  Leading and
%  trailing whitespace of field values is ignored unless a field is
%  listed in \code{keep.white}.  If a tag name is specified in the file,
%  but the corresponding value is empty, then an empty string is
%  returned.  If the tag name of a field is specified in \code{fields}
%  but never used in a record, then the corresponding value is \code{NA}.
%  If fields are repeated within a record, the last one encountered is
%  returned.  Malformed lines lead to an error.
%
%  For \code{read.dcf(all = TRUE)} a data frame is returned, again with
%  one row per record and one column per field.  The columns are lists of
%  character vectors for fields with multiple occurrences, and character
%  vectors otherwise.
%
%  Note that an empty \code{file} is a valid DCF file, and
%  \code{read.dcf} will return a zero-row matrix or data frame.
%
%  For \code{write.dcf}, invisible \code{NULL}.
%}
%
%\references{
%  \url{https://www.debian.org/doc/debian-policy/ch-controlfields.html}.
%  
%  Note that \R does not require encoding in UTF-8, which is a recent
%  Debian requirement.  Nor does it use the Debian-specific sub-format
%  which allows comment lines starting with \samp{#}.
%}
%\seealso{
%  \code{\link{write.table}}.
%
%  \code{\link{available.packages}}, which uses \code{read.dcf} to read
%  the indices of package repositories.
%}
%\examples{\donttest{
%## Create a reduced version of the DESCRIPTION file in package 'splines'
%x <- read.dcf(file = system.file("DESCRIPTION", package = "splines"),
%              fields = c("Package", "Version", "Title"))
%write.dcf(x)
%
%## An online DCF file with multiple records
%con <- url("http://cran.r-project.org/src/contrib/PACKAGES")
%y <- read.dcf(con, all = TRUE)
%close(con)
%utils::str(y)
%}}
%\keyword{print}
%\keyword{file}
%
\encoding{UTF8}
