% File src/library/base/man/grepRaw.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{grepRaw}
\title{Pattern Matching for Raw Vectors}
\alias{grepRaw}
\description{
  \code{grepRaw} はバイトベクトル \code{x} 中で副文字列 \code{pattern} の
  マッチを探す．
}
\usage{
grepRaw(pattern, x, offset = 1L, ignore.case = FALSE,
        value = FALSE, fixed = FALSE, all = FALSE, invert = FALSE)
}
\arguments{
  \item{pattern}{与えられたバイトベクトル中でマッチされるべき正規表現
    (又は \code{fixed = TRUE} に対しては固定パターン)を
    含むバイトベクトル．もし可能なら \code{\link{charToRaw}} で
    文字列に変換される．}
  \item{x}{マッチが探されるバイトベクトル，もしくは
    \code{charToRaw} でバイトベクトルに変換可能なオブジェクト．
    ロングベクトルはサポートされていない．}
  \item{ignore.case}{もし \code{FALSE} ならば，パターンマッチングは
      \emph{大・小文字を区別}し，もし \code{TRUE} なら
      大・小文字の区別はマッチングの間無視される．}
  \item{offset}{探索がそこから開始されるべきオフセットを
    指定する整数．正でなければならない．行の先頭はそのオフセットで
    定義されるので \code{"^"} はそこでマッチする．}
  \item{value}{論理値．返り値を決定する：\sQuote{値}を見よ．}
  \item{fixed}{論理値．もし \code{TRUE} ならば \code{pattern} はそのままで
    マッチされるべきパターンである．}
  \item{all}{論理値．もし \code{TRUE} ならばすべてのマッチが返される．
    さもなければ単に最初だけが返される．}
  \item{invert}{論理値．もし \code{TRUE} ならばマッチしなかった要素に対する
    添字や値が返される．\code{value = TRUE} で無い限り(警告と共に)無視される．}
}
\details{
  \code{\link{grep}} とは異なりバイトベクトル \code{x} の中で
  マッチングパターンを求める．これは特に \code{all = TRUE} のケース
  中で意味を持つ．例えば，空文字列にマッチするパターンが本質的に無限個で，
  従って予期しない結果に導く可能性がある場合である．

  引数 \code{invert} はマッチの補集合を返すように要求すると解釈される．
  これは \code{value = TRUE} の場合だけ意味を持つ．
  引数 \code{offset} は検索の開始位置を決定し，補集合のそれではない．
  \code{all = TRUE} の時の \code{invert = TRUE} は \code{x} を先頭と末尾の
  空文字列を含むパターンで区切られた部分に分割する
  (従ってこの場合に \code{"^"} や \code{"$"} を伴う正規表現を使うと
  より直感的でない結果に導く可能性がある)．

  \code{value = TRUE} を伴う \code{fixed = TRUE} のような引数の組み込みは
  サポートされているがあまり意味がない．
}

\value{
  \code{grepRaw(value = FALSE)} はマッチが起きた場所のオフセットの整数ベクトル
  を返す．もし \code{all = FALSE} ならばこれは
  長さ0(マッチ無し)か長さ1(最初のマッチング位置)である．

  \code{grepRaw(value = TRUE, all = FALSE)} はバイトベクトルを返す．
  これは空(マッチ無し)か \code{x} のマッチした部分である．

  \code{grepRaw(value = TRUE, all = TRUE)} はマッチした部分に対応する
  バイトベクトルのリスト(可能性として空の)を返す．
}

\source{
  \code{fixed = TRUE} の場合を除き Ville Laurikari の
  TRE ライブラリ  (\url{http://laurikari.net/tre/})
  が使われる．
}

% the `aka' below is for ESS
\seealso{
  パターン指定の詳細は \link{regular expression} (\code{\link{regexp}} としても
  知られている)．

  文字列ベクトルのマッチングについては \code{\link{grep}}．
}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/grepRaw.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grepRaw}
%\title{Pattern Matching for Raw Vectors}
%\alias{grepRaw}
%\description{
%  \code{grepRaw} searches for substring \code{pattern} matches within a
%  raw vector \code{x}.
%}
%\usage{
%grepRaw(pattern, x, offset = 1L, ignore.case = FALSE,
%        value = FALSE, fixed = FALSE, all = FALSE, invert = FALSE)
%}
%\arguments{
%  \item{pattern}{raw vector containing a \link{regular expression}
%    (or fixed pattern for \code{fixed = TRUE}) to be matched in the
%    given raw vector.  Coerced by \code{\link{charToRaw}} to a character
%    string if possible.}
%  \item{x}{a raw vector where matches are sought, or an object which can
%    be coerced by \code{charToRaw} to a raw vector.  \link{Long vectors}
%    are not supported.}
%  \item{ignore.case}{if \code{FALSE}, the pattern matching is \emph{case
%      sensitive} and if \code{TRUE}, case is ignored during matching.}
%  \item{offset}{An integer specifying the offset from
%    which the search should start.  Must be positive.  The beginning of
%    line is defined to be at that offset so \code{"^"} will match there.}
%  \item{value}{logical.  Determines the return value: see \sQuote{Value}.}
%  \item{fixed}{logical.  If \code{TRUE}, \code{pattern} is a pattern to be
%    matched as is.}
%  \item{all}{logical.  If \code{TRUE} all matches are returned,
%    otherwise just the first one.}
%  \item{invert}{logical.  If \code{TRUE} return indices or values for
%    elements that do \emph{not} match.  Ignored (with a warning) unless
%    \code{value = TRUE}.}
%}
%\details{
%  Unlike \code{\link{grep}}, seeks matching patterns within the raw
%  vector \code{x} . This has implications especially in the \code{all =
%  TRUE} case, e.g., patterns matching empty strings are inherently
%  infinite and thus may lead to unexpected results.
%
%  The argument \code{invert} is interpreted as asking to return the
%  complement of the match, which is only meaningful for \code{value =
%  TRUE}.  Argument \code{offset} determines the start of the search, not
%  of the complement.  Note that \code{invert = TRUE} with \code{all =
%  TRUE} will split \code{x} into pieces delimited by the pattern
%  including leading and trailing empty strings (consequently the use of
%  regular expressions with \code{"^"} or \code{"$"} in that case may
%  lead to less intuitive results).
%
%  Some combinations of arguments such as \code{fixed = TRUE} with
%  \code{value = TRUE} are supported but are less meaningful.
%}
%
%\value{
%  \code{grepRaw(value = FALSE)} returns an integer vector of the offsets
%  at which matches have occurred.  If \code{all = FALSE} then it will be
%  either of length zero (no match) or length one (first matching
%  position).
%
%  \code{grepRaw(value = TRUE, all = FALSE)} returns a raw vector which
%  is either empty (no match) or the matched part of \code{x}.
%
%  \code{grepRaw(value = TRUE, all = TRUE)} returns a (potentially
%  empty) list of raw vectors corresponding to the matched parts.
%}
%
%\source{
%  The TRE library of Ville Laurikari (\url{http://laurikari.net/tre/})
%  is used except for \code{fixed = TRUE}.
%}
%
%% the `aka' below is for ESS
%\seealso{
%  \link{regular expression} (aka \code{\link{regexp}}) for the details
%  of the pattern specification.
%
%  \code{\link{grep}} for matching character vectors.
%}
%\keyword{utilities}
%
\encoding{UTF8}
