% File src/library/base/man/integer.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{integer}
\alias{integer}
\alias{as.integer}
\alias{is.integer}
\title{Integer Vectors}
\description{
  \code{"integer"} 型のオブジェクトを作る，検査する．
}
\usage{
integer(length = 0)
as.integer(x, \dots)
is.integer(x)
}
\arguments{
  \item{length}{希望する長さを与える非負整数．
    倍精度実数値は整数に変換される：
    長さが1以外の引数を与えるとエラーになる．}
  \item{x}{強制変換又は検査するオブジェクト．}
  \item{\dots}{他のメソッドに・から渡される追加引数．}
}
\details{
  整数ベクトルはデータがそれらを期待する C や Fortran コードに渡せるように
  存在する．従って(小さな)整数データは正確かつコンパクトに表現できる．

  現在の \R の実装は整数ベクトルのために 32 ビット整数を使うため，
  表現可能な整数は約 \eqn{\pm 2 \times 10^9}{+/-2*10^9} に制限される：
  \code{\link{double}} はもっと大きな整数を正確に表現できる．
}
\value{
  \code{integer} は指定された長さの整数ベクトルを作る．
  ベクトルの各要素は \code{0} に等しい．

  \code{as.integer} はその引数を整数型に変換しようと試みる．
  回答は変換が成功しない限り \code{NA} になる．絶対値で最大整数より
  大きな実数値は \code{NA} に変換される(同じ符号の最大整数を与える S とは
  異なり)．整数でない数値はゼロに向かって切り詰められる
  (つまりそこでは \code{as.integer(x)} は \code{\link{trunc}(x)} に等しい)．
  そして複素数の虚部は(警告付きで)捨て去られる．
  オプションで(\code{0x} or \code{0X} で始まる)10進法表現や16進数表現が
  後に続く空白を含む文字列は，実数に対してプラットフォームが変換できるようなものと
  並んで，変換可能である．\code{\link{as.vector}} と同様にこれは名前を含む
  属性を剥ぎ取る．(オブジェクト \code{x} が属性を失うこと無く整数型であることを
  保証するには \code{\link{storage.mode}(x) <- "integer"} を使う．)

  \code{is.integer} はその引数が整数型か否かに応じて \code{TRUE} か \code{FALSE}
  を返すが，それが因子であれば \code{FALSE} を返す．
}
\note{
  \code{is.integer(x)} は \code{x} が整数を含むかどうかを検査しない!
  そのためには \code{\link{round}} を使った例の中の \code{is.wholenumber(x)}
  関数のようにする．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{numeric}}, \code{\link{storage.mode}}.

  整数値への変換は \code{\link{round}} (そして \code{ceiling} と \code{floor}
  のヘルプページ)．
}
\examples{
## as.integer() は切り捨てる：
x <- pi * c(-1:1, 10)
as.integer(x)

is.integer(1) # FALSE になる!

is.wholenumber <-
    function(x, tol = .Machine$double.eps^0.5)  abs(x - round(x)) < tol
is.wholenumber(1) # TRUE である
(x <- seq(1, 5, by = 0.5) )
is.wholenumber( x ) #-->  TRUE FALSE TRUE ...
}
\keyword{classes}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/integer.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{integer}
%\alias{integer}
%\alias{as.integer}
%\alias{is.integer}
%\title{Integer Vectors}
%\description{
%  Creates or tests for objects of type \code{"integer"}.
%}
%\usage{
%integer(length = 0)
%as.integer(x, \dots)
%is.integer(x)
%}
%\arguments{
%  \item{length}{A non-negative integer specifying the desired length.
%    Double values will be coerced to integer:
%    supplying an argument of length other than one is an error.}
%  \item{x}{object to be coerced or tested.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\details{
%  Integer vectors exist so that data can be passed to C or Fortran code
%  which expects them, and so that (small) integer data can be represented
%  exactly and compactly.
%
%  Note that current implementations of \R use 32-bit integers for
%  integer vectors, so the range of representable integers is restricted
%  to about \eqn{\pm 2 \times 10^9}{+/-2*10^9}: \code{\link{double}}s can
%  hold much larger integers exactly.
%}
%\value{
%  \code{integer} creates a integer vector of the specified length.
%  Each element of the vector is equal to \code{0}.
%
%  \code{as.integer} attempts to coerce its argument to be of integer
%  type.  The answer will be \code{NA} unless the coercion succeeds.  Real
%  values larger in modulus than the largest integer are coerced to
%  \code{NA} (unlike S which gives the most extreme integer of the same
%  sign).  Non-integral numeric values are truncated towards zero (i.e.,
%  \code{as.integer(x)} equals \code{\link{trunc}(x)} there), and
%  imaginary parts of complex numbers are discarded (with a warning).
%  Character strings containing optional whitespace followed by either a
%  decimal representation or a hexadecimal representation (starting with
%  \code{0x} or \code{0X}) can be converted, as well as any allowed by
%  the platform for real numbers.  Like \code{\link{as.vector}} it strips
%  attributes including names.  (To ensure that an object \code{x} is of
%  integer type without stripping attributes, use
%  \code{\link{storage.mode}(x) <- "integer"}.)
%
%  \code{is.integer} returns \code{TRUE} or \code{FALSE} depending on
%  whether its argument is of integer \link{type} or not, unless it is a
%  factor when it returns \code{FALSE}.
%}
%\note{
%  \code{is.integer(x)} does \bold{not} test if \code{x} contains integer
%  numbers!  For that, use \code{\link{round}}, as in the function
%  \code{is.wholenumber(x)} in the examples.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{numeric}}, \code{\link{storage.mode}}.
%
%  \code{\link{round}} (and \code{ceiling} and \code{floor} on that help
%  page) to convert to integral values.
%}
%\examples{
%## as.integer() truncates:
%x <- pi * c(-1:1, 10)
%as.integer(x)
%
%is.integer(1) # is FALSE !
%
%is.wholenumber <-
%    function(x, tol = .Machine$double.eps^0.5)  abs(x - round(x)) < tol
%is.wholenumber(1) # is TRUE
%(x <- seq(1, 5, by = 0.5) )
%is.wholenumber( x ) #-->  TRUE FALSE TRUE ...
%}
%\keyword{classes}
%
\encoding{UTF8}
