% File src/library/base/man/is.finite.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{is.finite}
\title{Finite, Infinite and NaN Numbers}
\alias{is.finite}
\alias{is.infinite}
\alias{Inf}
\alias{NaN}
\alias{is.nan}
\alias{finite} % for when people ask what 'finite' means.
\alias{infinite}
\description{
  \code{is.finite} と \code{is.infinite} は
  どの要素が有限(無限でなく欠損もしていない)か無限かを指示する
  \code{x} と同じ長さのベクトルを返す．
  
  \code{Inf} と \code{-Inf} は正負の無限であり，
  \code{NaN} は\sQuote{非数}を意味する．(これらは数値と複素数の実部と虚部に
  適用されるが整数には適用されない．)  \code{Inf} と \code{NaN} は
  \R 言語の予約語である．
}
\usage{
is.finite(x)
is.infinite(x)
is.nan(x)

Inf
NaN
}
\arguments{
  \item{x}{検査される \R オブジェクト：既定のメソッドは原子的なベクトルを処理する．}
}
\details{
  \code{is.finite} は \code{x} と同じ長さのベクトルを返す．
  その j 番目の要素はもし \code{x[j]} が有限(つまり \code{NA}, \code{NaN}, \code{Inf}
  もしくは \code{-Inf} でない)であれば \code{TRUE} で，さもなければ
  \code{FALSE} である．複素数はもし実部と虚部の双方が有限ならば有限とされる．

  \code{is.infinite} は \code{x} と同じ長さのベクトルを返す．
  その j 番目の要素はもし \code{x[j]} が無限(つまり \code{Inf}
  もしくは \code{-Inf})であれば \code{TRUE} で，さもなければ
  \code{FALSE} である．複素数はもし実部と虚部のどちらかが無限ならば無限とされる．

  \code{is.nan} は数値が \code{NaN} かどうかを検査する．
  システムは典型的には多くの異なった NaN 値を持つため，
  \code{NaN} との等号比較はしてはならず，\code{\link{identical}} も
  使うべきではない．
  これらの一つは数値的な欠損値 \code{NA} として使われ，\code{is.nan} は
  そうした値に対して偽になる．
  複素数はもし実部と虚部のどちらかが \code{NaN} であるが \code{NA} でない時
  \code{NaN} と見做される．
  すべての論理値，整数，そしてバイトベクトルは NaN ではないと考えられる．

  これらの三つの関数は入力として \code{NULL} を受け入れ長さゼロのベクトルを
  返す．既定のメソッドは文字列とバイトベクトルを受け入れ，そして
  すべての項目に対し \code{FALSE} を返す．\R のバージョン 2.14.0 以前では
  これらはすべての入力を受け入れ，ほとんどの数値でない値に対し
  \code{FALSE} を返した；原子的なベクトルではないケースに対しては
  現在はエラーとなる．

  三つの関数は総称的である：特殊なオブジェクトを処理するメソッドを
  書くことが出来る，\link{InternalMethods} を見よ．
}
\note{
  \R ではすべての数学値関数(基本的な算術を含み)は入力や出力に対し基本的に
  \code{+/- Inf} と \code{NaN} を適切に処理すると考えられている．

  基本的な規則は \code{Inf} を伴う呼び出しと関係は，実際は
  適切な数学的\emph{極限}を伴う文であるべきということである．

  \code{NaN} を含む計算は \code{NaN} かもしかすると 
  \code{\link{NA}} を返す：どちらになるかは保証されず
  \R プラットフォームに依存する(コンパイラーが計算を再要求するかもしれないので)．
}
\value{
  \code{x} と同じ長さの論理値ベクトル：属性 \code{dim},
  \code{dimnames} そして \code{names} は保存される．
}
\seealso{
  \code{\link{NA}}, \sQuote{\emph{非数(Not A Number)}} は同様に数ではないが，
  普通欠損値として使われ，単に数値と複素数値だけでなく，多くのモードに適用される．

  \code{\link{Arithmetic}}, \code{\link{double}}.
}
\references{
  IEC 60559 標準，
  ANSI/IEEE 754 浮動少数点標準としても知られている．

  \url{https://en.wikipedia.org/wiki/NaN}.

  D. Goldberg (1991) \emph{What Every Computer Scientist Should Know
    about Floating-Point Arithmetic}  ACM Computing Surveys, \bold{23(1)}.\cr
  Postscript 版が次で得られる
  \url{http://www.validlab.com/goldberg/paper.ps}．
  拡張 PDF 版は \url{http://www.validlab.com/goldberg/paper.pdf} にある．

  C99 関数 \code{isfinite} が \code{is.finite} に対して使われている．
}
\examples{
pi / 0 ## = Inf ゼロで割った非ゼロ数は無限を作り出す
0 / 0  ## =  NaN

1/0 + 1/0 # Inf
1/0 - 1/0 # NaN

stopifnot(
    1/0 == Inf,
    1/Inf == 0
)
sin(Inf)
cos(Inf)
tan(Inf)
}
\keyword{programming}
\keyword{math}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/is.finite.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{is.finite}
%\title{Finite, Infinite and NaN Numbers}
%\alias{is.finite}
%\alias{is.infinite}
%\alias{Inf}
%\alias{NaN}
%\alias{is.nan}
%\alias{finite} % for when people ask what 'finite' means.
%\alias{infinite}
%\description{
%  \code{is.finite} and \code{is.infinite} return a vector of the same
%  length as \code{x}, indicating which elements are finite (not infinite
%  and not missing) or infinite.
%
%  \code{Inf} and \code{-Inf} are positive and negative infinity
%  whereas \code{NaN} means \sQuote{Not a Number}.  (These apply to numeric
%  values and real and imaginary parts of complex values but not to
%  values of integer vectors.)  \code{Inf} and \code{NaN} are
%  \link{reserved} words in the \R language.
%}
%\usage{
%is.finite(x)
%is.infinite(x)
%is.nan(x)
%
%Inf
%NaN
%}
%\arguments{
%  \item{x}{\R object to be tested: the default methods handle atomic
%    vectors.}
%}
%\details{
%  \code{is.finite} returns a vector of the same length as \code{x} the
%  jth element of which is \code{TRUE} if \code{x[j]} is finite (i.e., it
%  is not one of the values \code{NA}, \code{NaN}, \code{Inf} or
%  \code{-Inf}) and \code{FALSE} otherwise.  Complex
%  numbers are finite if both the real and imaginary parts are.
%
%  \code{is.infinite} returns a vector of the same length as \code{x} the
%  jth element of which is \code{TRUE} if \code{x[j]} is infinite (i.e.,
%  equal to one of \code{Inf} or \code{-Inf}) and \code{FALSE}
%  otherwise.  This will be false unless \code{x} is numeric or complex.
%  Complex numbers are infinite if either the real or the imaginary part is.
%
%  \code{is.nan} tests if a numeric value is \code{NaN}.  Do not test
%  equality to \code{NaN}, or even use \code{\link{identical}}, since
%  systems typically have many different NaN values.  One of these is
%  used for the numeric missing value \code{NA}, and \code{is.nan} is
%  false for that value.  A complex number is regarded as \code{NaN} if
%  either the real or imaginary part is \code{NaN} but not \code{NA}.
%  All elements of logical, integer and raw vectors are considered not to
%  be NaN.
%
%  All three functions accept \code{NULL} as input and return a length
%  zero result. The default methods accept character and raw vectors, and
%  return \code{FALSE} for all entries. Prior to \R version 2.14.0 they
%  accepted all input, returning \code{FALSE} for most non-numeric
%  values; cases which are not atomic vectors are now signalled as
%  errors.
%
%  All three functions are generic: you can write methods to handle
%  specific classes of objects, see \link{InternalMethods}.
%}
%\note{
%  In \R, basically all mathematical functions (including basic
%  \code{\link{Arithmetic}}), are supposed to work properly with
%  \code{+/- Inf} and \code{NaN} as input or output.
%
%  The basic rule should be that calls and relations with \code{Inf}s
%  really are statements with a proper mathematical \emph{limit}.
%
%  Computations involving \code{NaN} will return \code{NaN} or perhaps
%  \code{\link{NA}}: which of those two is not guaranteed and may depend
%  on the \R platform (since compilers may re-order computations).
%}
%\value{
%  A logical vector of the same length as \code{x}: \code{dim},
%  \code{dimnames} and \code{names} attributes are preserved.
%}
%\seealso{
%  \code{\link{NA}}, \sQuote{\emph{Not Available}} which is not a number
%  as well, however usually used for missing values and applies to many
%  modes, not just numeric and complex.
%
%  \code{\link{Arithmetic}}, \code{\link{double}}.
%}
%\references{
%  The IEC 60559 standard, also known as the
%  ANSI/IEEE 754 Floating-Point Standard.
%
%  \url{https://en.wikipedia.org/wiki/NaN}.
%
%  D. Goldberg (1991) \emph{What Every Computer Scientist Should Know
%    about Floating-Point Arithmetic}  ACM Computing Surveys, \bold{23(1)}.\cr
%  Postscript version available at
%  \url{http://www.validlab.com/goldberg/paper.ps}
%  Extended PDF version at \url{http://www.validlab.com/goldberg/paper.pdf}
%
%  The C99 function \code{isfinite} is used for \code{is.finite}.
%}
%\examples{
%pi / 0 ## = Inf a non-zero number divided by zero creates infinity
%0 / 0  ## =  NaN
%
%1/0 + 1/0 # Inf
%1/0 - 1/0 # NaN
%
%stopifnot(
%    1/0 == Inf,
%    1/Inf == 0
%)
%sin(Inf)
%cos(Inf)
%tan(Inf)
%}
%\keyword{programming}
%\keyword{math}
%
\encoding{UTF8}
