% File src/library/base/man/library.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{library}
\title{Loading/Attaching and Listing of Packages}
\alias{library}
\alias{require}

\alias{.noGenerics}
\alias{format.libraryIQR}
\alias{print.libraryIQR}
\alias{format.packageInfo}
\alias{print.packageInfo}
\description{
  \code{library} と \code{require} はアドオン・パッケージをロードし
  付加する．
}
\usage{
library(package, help, pos = 2, lib.loc = NULL,
        character.only = FALSE, logical.return = FALSE,
        warn.conflicts = TRUE, quietly = FALSE,
        verbose = getOption("verbose"))

require(package, lib.loc = NULL, quietly = FALSE,
        warn.conflicts = TRUE,
        character.only = FALSE)
}
\arguments{
  \item{package, help}{パッケージの名前で，\code{character.only} が
    \code{FALSE} (既定)か \code{TRUE} に応じて，\link{name} か 
    literal な文字列又は文字列．}
  \item{pos}{ロードされた名前空間をそこへ付加する検索リスト上の位置．
    \code{\link{search}()} で与えられる現在の検索リスト上名前でも良い．}
  \item{lib.loc}{探索される \R のライブラリツリーの位置を記述する文字列か
    \code{NULL}．既定値である \code{NULL} は \code{\link{.libPaths}()} が現在
    知っている全てのライブラリに対応する．
    存在しないライブラリツリーは無言で無視される．}
  \item{character.only}{\code{package} か \code{help} が文字列であることを
    仮定して良い顔塚を指示する論理値．}
  \item{logical.return}{論理値．もしこれが \code{TRUE} なら，成功を意味する
    \code{FALSE} か \code{TRUE} が返される．}
  \item{warn.conflicts}{論理値．もし \code{TRUE} なら新しいパッケージの付加
    からの相克に関して警告が出る．相克とは関数が関数を隠蔽したり，
    関数でないものが関数を隠蔽することをいう．}
  \item{verbose}{論理値．もし \code{TRUE} ならば追加の診断がプリントされる．}
  \item{quietly}{論理値．もし \code{TRUE} ならばパッケージの付加を
    確定するメッセージはプリントされない．そして最もしばしば，パッケージの
    付加が失敗してもエラー/警告はプリントされない．}
}
\details{
  \code{library(package)} と \code{require(package)} は共に名前
   \code{package} を持つパッケージの名前空間をロードし，それを検索パス
  上に付加する．\code{require} は他の関数中で使うようにデザインされている；
  これはもしパッケージが存在しないと \code{FALSE} を返し警告を与える
  (\code{library()} が既定で行うようなエラーではなく)．
  二つの関数はともに現在付加されているパッケージのリストをチェックしそして更新し，
  既にロードされている名前空間は再ロードしない．
  (もしそうしたパッケージを再ロードしたければ
  \code{\link{detach}(unload = TRUE)} か \code{\link{unloadNamespace}} を
  先ず呼び出す．)  もし検索パス上に付加すること無くパッケージをロードしたければ
  \code{\link{requireNamespace}} を見よ．

  パッケージのロード中のメッセージを無くすには
  \code{\link{suppressPackageStartupMessages}} を使う：これは \R 自体からの
  全てのメッセージを抑えるがパッケージ作者からのそれら全てを抑えるとは
  限らない．

  もし \code{library} が \code{package} や \code{help} 引数なしに呼び出されると，
  \code{lib.loc} で指定されるライブラリ中の全ての利用可能なパッケージをリストする．
  そしてクラス \code{"libraryIQR"} のオブジェクトとして対応する情報を返す．
  (このクラスの構造は将来のバージョンで変更されるかもしれない．)
  全ての利用可能なパッケージの名前だけを得るには \code{.packages(all = TRUE)}
  を使う．そしてより多くの情報のためには \code{\link{installed.packages}()}
  とする．

  \code{library(help = somename)} はパッケージ \pkg{somename} に関する
  基本的な情報を計算し，そしてこれをクラス \code{"packageInfo"} のオブジェクトととして
  返す．(このクラスの構造は将来のバージョンで変更されるかもしれない．)
  \code{lib.loc} に対する既定値(\code{NULL})と共に使われると付加されたパッケージは
  ライブラリより前に探される．
}
\value{
  普通 \code{library} は(不可視で)付加されたパッケージのリストを返すが，
  もし \code{logical.return} が \code{TRUE} ならば \code{TRUE} か \code{FALSE}
  を返す．\code{library()} iとして呼ばれるとクラス 
  \code{"libraryIQR"} のオブジェクトを返す．そして \code{library(help=)} に
  対してはクラス \code{"packageInfo"} の一つ．

  \code{require} は(不可視で)要求されたパッケージが利用可能かどうかを指示する
  論理値を返す．
}
\section{ライセンス}{
  ある種のパッケージは制限的なライセンスを持ち，
  そうしたライセンスをユーザに気づかせることが出来る機構がある．
  もし \code{\link{getOption}("checkPackageLicense") == TRUE} ならば，
  FOSS であることが知られていない(下を見よ)ライセンスを持つパッケージの最初の使用時に
  ユーザはライセンスを眺めそれを受け入れることを要求される：
  受け入れられたライセンスのリストはファイル \file{~/.R/licensed} に
  保存される．非対話的なセッションではライセンスが未だ受け入れられていない
  そうしたパッケージを使うとエラーになる．

  フリーもしくはオープンソースのソフトウェア(FOSS,
  例えば \url{https://en.wikipedia.org/wiki/FOSS})パッケージは
  \code{\link{available.packages}} が使用するのと同じフィルターで
  決定されるが現在のパッケージだけに適用され，その従属物には
  適用されない．

  またサイト全体に渡るパッケージのファイル \file{R_HOME/etc/licensed.site} が
  ある(行ごとに一つ)．
}
\section{形式的メソッド}{
  \code{library} はパッケージ \pkg{methods} が付加された時(既定では)
  幾つかの更なる行動を取る．パッケージは形式的総称関数の定義と並んで
  他のパッケージ中の関数(特に \pkg{base} 中の)を総称的になるように
  再定義しているかもしれない．そうした名前空間が \code{methods} の
  後でロードされる度にこの情報はキャッシュされ，再定義された関数
  (\link{implicit generic}s)は相克リストから除外される．
  相克に対するキャッシュとチェックはパターンオブジェクトの調査を必要とする；
  検索は名前空間中のオブジェクト \code{.noGenerics} (値は任意)を定義することで
  避けられる．もしパッケージがそうした何らかのそうしたメソッドを持てば，これは自然に
  それらが使われることを防止する．
}
\note{
  \code{library} と \code{require} は\emph{インストールされた}パッケージ
  だけをロード/付加出来る．そしてこれは \samp{Built:} 欄を含む
  \file{DESCRIPTION} ファイルを持つことで検出される．

  Unix風システムではコードはパッケージが，コンパイルコードを含む限り，
  \code{R.version$platform} (R がコンパイルされたプラットフォームの標準名)で
  与えられるのと類似のオペレーティング・システムの下でインストール
  されたかどうかをチェックする．
  コンパイルコードを含まないパッケージはUnix風・システム間で共有できるが，
  行の終末と OS 固有のヘルプファイルに伴う固有の潜在的問題のせいで，他の
  OS では共有できるとは限らない．
  もしサブアーキテクチャが使われていると，構築に使われた OS は異なるかも
  しれないので，OS の類似性はチェックされない．
  (例えば \code{i386-pc-linux-gnu} コードは
  \code{x86_64-unknown-linux-gnu} OS 上でコンパイル出来る)．

  \code{library} と \code{require} に与えられたパッケージ名は
  パッケージの \file{DESCRIPTION} ファイル中で与えられたのと正確に
  同じでなければならない．これは Windows や OS X では通例の大・小文字を
  区別しないファイルシステムに於いても同じである．
}
\seealso{
  \code{\link{.libPaths}}, \code{\link{.packages}}.

  \code{\link{attach}}, \code{\link{detach}}, \code{\link{search}},
  \code{\link{objects}}, \code{\link{autoload}}, 
  \code{\link{requireNamespace}},
  \code{\link{library.dynam}}, \code{\link{data}},
  \code{\link{install.packages}} and
  \code{\link{installed.packages}};
  \code{\link{INSTALL}}, \code{\link{REMOVE}}.
  
  付加される初期パッケージのセットは
  \code{\link{options}(defaultPackages=)} で設定される:
  \code{\link{Startup}} も見よ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
library()                   # 利用可能なパッケージをリストする
library(lib.loc = .Library) # 既定のライブラリ中の全てのパッケージをリストする
\donttest{library(help = splines)     # パッケージ 'splines' に関するドキュメント}
library(splines)            # パッケージ 'splines' を付加する
require(splines)            # 同じ
search()                    # "splines" も
detach("package:splines")

# もしパッケージ名が文字列ベクトル中にあれば pkg <- "splines" を使う
library(pkg, character.only = TRUE)
detach(pos = match(paste("package", pkg, sep = ":"), search()))

require(pkg, character.only = TRUE)
detach(pos = match(paste("package", pkg, sep = ":"), search()))

require(nonexistent)        # FALSE
\dontrun{
## もしできるだけ少しだけマスクしたければ次を使う
library(mypkg, pos = "package:base")
}}
\keyword{data}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/library.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{library}
%\title{Loading/Attaching and Listing of Packages}
%\alias{library}
%\alias{require}
%
%\alias{.noGenerics}
%\alias{format.libraryIQR}
%\alias{print.libraryIQR}
%\alias{format.packageInfo}
%\alias{print.packageInfo}
%\description{
%  \code{library} and \code{require} load and attach add-on packages.
%}
%\usage{
%library(package, help, pos = 2, lib.loc = NULL,
%        character.only = FALSE, logical.return = FALSE,
%        warn.conflicts = TRUE, quietly = FALSE,
%        verbose = getOption("verbose"))
%
%require(package, lib.loc = NULL, quietly = FALSE,
%        warn.conflicts = TRUE,
%        character.only = FALSE)
%}
%\arguments{
%  \item{package, help}{the name of a package, given as a \link{name} or
%    literal character string, or a character string, depending on
%    whether \code{character.only} is \code{FALSE} (default) or
%    \code{TRUE}).}
%  \item{pos}{the position on the search list at which to attach the
%    loaded namespace.  Can also be the name of a position on the current
%    search list as given by \code{\link{search}()}.}
%  \item{lib.loc}{a character vector describing the location of \R
%    library trees to search through, or \code{NULL}.  The default value
%    of \code{NULL} corresponds to all libraries currently known to
%    \code{\link{.libPaths}()}.
%    Non-existent library trees are silently ignored.}
%  \item{character.only}{a logical indicating whether \code{package} or
%    \code{help} can be assumed to be character strings.}
%  \item{logical.return}{logical.  If it is \code{TRUE},  \code{FALSE} or
%    \code{TRUE} is returned to indicate success.}
%  \item{warn.conflicts}{logical.  If \code{TRUE}, warnings are
%    printed about \code{\link{conflicts}} from attaching the new
%    package.  A conflict is a function masking a function,
%    or a non-function masking a non-function.
%  }
%  \item{verbose}{a logical.  If \code{TRUE}, additional diagnostics are
%    printed.}
%  \item{quietly}{a logical.  If \code{TRUE}, no message confirming
%    package attaching is printed, and most often, no errors/warnings are
%    printed if package attaching fails.}
%}
%\details{
%  \code{library(package)} and \code{require(package)} both load the
%  namespace of the package with name \code{package} and attach it on the
%  search list.  \code{require} is designed for use inside other
%  functions; it returns \code{FALSE} and gives a warning (rather than an
%  error as \code{library()} does by default) if the package does not
%  exist.  Both functions check and update the list of currently attached
%  packages and do not reload a namespace which is already loaded.  (If
%  you want to reload such a package, call \code{\link{detach}(unload =
%  TRUE)} or \code{\link{unloadNamespace}} first.)  If you want to load a
%  package without attaching it on the search list, see
%  \code{\link{requireNamespace}}.
%
%  To suppress messages during the loading of packages use
%  \code{\link{suppressPackageStartupMessages}}: this will suppress all
%  messages from \R itself but not necessarily all those from package
%  authors.
%
%  If \code{library} is called with no \code{package} or \code{help}
%  argument, it lists all available packages in the libraries specified
%  by \code{lib.loc}, and returns the corresponding information in an
%  object of class \code{"libraryIQR"}.  (The structure of this class may
%  change in future versions.)  Use \code{.packages(all = TRUE)} to
%  obtain just the names of all available packages, and
%  \code{\link{installed.packages}()} for even more information.
%
%  \code{library(help = somename)} computes basic information about the
%  package \pkg{somename}, and returns this in an object of class
%  \code{"packageInfo"}.  (The structure of this class may change in
%  future versions.)  When used with the default value (\code{NULL}) for
%  \code{lib.loc}, the attached packages are searched before the libraries.
%}
%\value{
%  Normally \code{library} returns (invisibly) the list of attached
%  packages, but \code{TRUE} or \code{FALSE} if \code{logical.return} is
%  \code{TRUE}.  When called as \code{library()} it returns an object of
%  class \code{"libraryIQR"}, and for \code{library(help=)}, one of
%  class \code{"packageInfo"}.
%
%  \code{require} returns (invisibly) a logical indicating whether the required
%  package is available.
%}
%\section{Licenses}{
%  Some packages have restrictive licenses, and there is a mechanism to
%  allow users to be aware of such licenses.  If
%  \code{\link{getOption}("checkPackageLicense") == TRUE}, then at first
%  use of a package with a not-known-to-be-FOSS (see below) license the
%  user is asked to view and accept the license: a list of accepted
%  licenses is stored in file \file{~/.R/licensed}.  In a non-interactive
%  session it is an error to use such a package whose license has not
%  already been accepted.
%
%  Free or Open Source Software (FOSS,
%  e.g.\sspace{}\url{https://en.wikipedia.org/wiki/FOSS}) packages are
%  determined by the same filters used by
%  \code{\link{available.packages}} but applied to just the current
%  package, not its dependencies.
%
%  There can also be a site-wide file \file{R_HOME/etc/licensed.site} of
%  packages (one per line).
%}
%\section{Formal methods}{
%  \code{library} takes some further actions when package \pkg{methods}
%  is attached (as it is by default).  Packages may define formal generic
%  functions as well as re-defining functions in other packages (notably
%  \pkg{base}) to be generic, and this information is cached whenever
%  such a namespace is loaded after \pkg{methods} and re-defined functions
%  (\link{implicit generic}s) are excluded from the list of conflicts.
%  The caching and check for conflicts require looking for a pattern of
%  objects; the search may be avoided by defining an object
%  \code{.noGenerics} (with any value) in the namespace.  Naturally, if the
%  package \emph{does} have any such methods, this will prevent them from
%  being used.
%}
%\note{
%  \code{library} and \code{require} can only load/attach an
%  \emph{installed} package, and this is detected by having a
%  \file{DESCRIPTION} file containing a \samp{Built:} field.
%
%  Under Unix-alikes, the code checks that the package was installed
%  under a similar operating system as given by \code{R.version$platform}
%  (the canonical name of the platform under which R was compiled),
%  provided it contains compiled code.  Packages which do not contain
%  compiled code can be shared between Unix-alikes, but not to other OSes
%  because of potential problems with line endings and OS-specific help
%  files.  If sub-architectures are used, the OS similarity is not
%  checked since the OS used to build may differ
%  (e.g.\sspace{}\code{i386-pc-linux-gnu} code can be built on an
%  \code{x86_64-unknown-linux-gnu} OS).
%
%  The package name given to \code{library} and \code{require} must match
%  the name given in the package's \file{DESCRIPTION} file exactly, even
%  on case-insensitive file systems such as are common on Windows and
%  OS X.
%}
%\seealso{
%  \code{\link{.libPaths}}, \code{\link{.packages}}.
%
%  \code{\link{attach}}, \code{\link{detach}}, \code{\link{search}},
%  \code{\link{objects}}, \code{\link{autoload}}, 
%  \code{\link{requireNamespace}},
%  \code{\link{library.dynam}}, \code{\link{data}},
%  \code{\link{install.packages}} and
%  \code{\link{installed.packages}};
%  \code{\link{INSTALL}}, \code{\link{REMOVE}}.
%  
%  The initial set of packages attached is set by
%  \code{\link{options}(defaultPackages=)}: see also \code{\link{Startup}}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%library()                   # list all available packages
%library(lib.loc = .Library) # list all packages in the default library
%\donttest{library(help = splines)     # documentation on package 'splines'}
%library(splines)            # attach package 'splines'
%require(splines)            # the same
%search()                    # "splines", too
%detach("package:splines")
%
%# if the package name is in a character vector, use
%pkg <- "splines"
%library(pkg, character.only = TRUE)
%detach(pos = match(paste("package", pkg, sep = ":"), search()))
%
%require(pkg, character.only = TRUE)
%detach(pos = match(paste("package", pkg, sep = ":"), search()))
%
%require(nonexistent)        # FALSE
%\dontrun{
%## if you want to mask as little as possible, use
%library(mypkg, pos = "package:base")
%}}
%\keyword{data}
%
\encoding{UTF8}
