% File src/library/base/man/proc.time.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{proc.time}
\alias{proc.time}
\alias{print.proc_time}
\alias{summary.proc_time}
\title{Running Time of R}
\description{
  \code{proc.time} は現在実行中の \R プロセスがどれだけの
  実と CPU 時間(秒単位)を既に使ったかを決定する．
}
\usage{
proc.time()
}
\details{
  \code{proc.time} は後方互換性のため5つの要素を返すが，
  その \code{print} メソッドは長さ 3 の名前付きベクトルを返す．
  最初の二項目は現在の \R プロセスとそれが待っている任意の子プロセスの
  トータルのユーザとシステム CPU 時間を，そして
  三番目の項目はプロセスが開始してからの\sQuote{実}経過時間を表す．
}
\value{
  長さ5の数値ベクトルであるクラス \code{"proc_time"} のオブジェクトで，
  現在実行中の \R プロセスのユーザ，システムとトータルの経過時間，
  そしそれが生み出し実行終了を待機している子プロセスのユーザとシステム時間の
  累計総計を含む．(\code{print} メソッドは子プロセス時間と主プロセス
  を連結する \code{summary} メソッドを使う．)
  
  \sQuote{ユーザ}と\sQuote{システム}時間は使用している OS からの
  ものである．典型的にはこれは次のようになる．

  \sQuote{ユーザ時間}は呼び出しプロセスのユーザ指示の実行に必要とされる
  CPU 時間である．\sQuote{システム時間}は呼び出しプロセスの実行ために
  必要とされた CPU 時間である．

  Windows では子プロセスの時間は利用出来ず常に \code{NA} と与えられる．

  時間の解像度はシステム固有であり，
  Unix 風システムではミリ秒で丸められている．
  現代のシステムではそれらはその程度の正確さであるが，
  過去のシステムでは 1/100 か 1/60 秒の精度である．
  これらは典型的に 10 ミリ秒で与えられる．

  これはプリミティブな関数である．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \R 表現式の時間計測には \code{\link{system.time}} そして
  ガベージコレクションにどれだけ時間がかかったかを知るには \code{\link{gc.time}}．
}
\examples{\donttest{
## R 表現式の時間計測の一つ方法：system.time の方が好ましい
ptm <- proc.time()
for (i in 1:50) mad(stats::runif(500))
proc.time() - ptm
}}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/proc.time.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{proc.time}
%\alias{proc.time}
%\alias{print.proc_time}
%\alias{summary.proc_time}
%\title{Running Time of R}
%\description{
%  \code{proc.time} determines how much real and CPU time (in seconds)
%  the currently running \R process has already taken.
%}
%\usage{
%proc.time()
%}
%\details{
%  \code{proc.time} returns five elements for backwards compatibility,
%  but its \code{print} method prints a named vector of
%  length 3.  The first two entries are the total user and system CPU
%  times of the current \R process and any child processes on which it
%  has waited, and the third entry is the \sQuote{real} elapsed time
%  since the process was started.
%}
%\value{
%  An object of class \code{"proc_time"} which is a numeric vector of
%  length 5, containing the user, system, and total elapsed times for the
%  currently running \R process, and the cumulative sum of user and
%  system times of any child processes spawned by it on which it has
%  waited.  (The \code{print} method uses the \code{summary} method to
%  combine the child times with those of the main process.)
%  
%  The definition of \sQuote{user} and \sQuote{system} times is from your
%  OS.  Typically it is something like
%
%  \emph{The \sQuote{user time} is the CPU time charged for the execution
%  of user instructions of the calling process.  The \sQuote{system time}
%  is the CPU time charged for execution by the system on behalf of the
%  calling process.}
%
%  Times of child processes are not available on Windows and will always
%  be given as \code{NA}.
%
%  The resolution of the times will be system-specific and on Unix-alikes
%  times are rounded down to milliseconds.  On modern systems they will
%  be that accurate, but on older systems they might be accurate to 1/100
%  or 1/60 sec.  They are typically available to 10ms on Windows.
%
%  This is a \link{primitive} function.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{system.time}} for timing an \R expression,
%  \code{\link{gc.time}} for how much of the time was spent in garbage
%  collection.
%}
%\examples{\donttest{
%## a way to time an R expression: system.time is preferred
%ptm <- proc.time()
%for (i in 1:50) mad(stats::runif(500))
%proc.time() - ptm
%}}
%\keyword{utilities}
%
\encoding{UTF8}
