% File src/library/base/man/qr.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{qr}
\alias{qr}
\alias{qr.default}
\alias{qr.coef}
\alias{qr.qy}
\alias{qr.qty}
\alias{qr.resid}
\alias{qr.fitted}
\alias{qr.solve}
\alias{is.qr}
\alias{as.qr}
\alias{solve.qr}
\title{The QR Decomposition of a Matrix}
\usage{
qr(x, \dots)
\method{qr}{default}(x, tol = 1e-07 , LAPACK = FALSE, \dots)

qr.coef(qr, y)
qr.qy(qr, y)
qr.qty(qr, y)
qr.resid(qr, y)
qr.fitted(qr, y, k = qr$rank)
qr.solve(a, b, tol = 1e-7)
\method{solve}{qr}(a, b, \dots)

is.qr(x)
as.qr(x)
}
\arguments{
  \item{x}{QR 分解を計算すべき数値もしくは複素数値行列．論理値行列は
    数値に変換される．}
  \item{tol}{\code{x} の列中の線形従属性を検出する際の許容度．
    \code{LAPACK} が偽で \code{x} が実数の時だけ使われる．}
  \item{qr}{\code{qr} によって計算される QR 分解のタイプ．}
  \item{y, b}{方程式の右辺のベクトルもしくは行列．}
  \item{a}{QR 分解もしくは(\code{qr.solve} のみ)矩形行列．}
  \item{k}{実効的ランク．}
  \item{LAPACK}{論理値．実 \code{x} に対しては，もし真ならLAPACK，
    さもなければ LINPACK (既定値)を使う．}
  \item{\dots}{他のメソッドに・へ渡される追加引数．}
}
\description{
  \code{qr} は行列の QR 分解を計算する．
}
\details{
  QR 分解は多くの統計テクニックで重要な役割を果たす．特に
  与えられた行列 \eqn{\bold{A}} とベクトル \code{b} に対して
  方程式 \eqn{\bold{Ax} = \bold{b}} を解くのに使われる．
  回帰係数の計算と Newton-Raphson アルゴリズムの応用で役に立つ．

  関数 \code{qr.coef}, \code{qr.resid} そして \code{qr.fitted}
  は QR 分解 \code{qr} を用いて \code{y} を当てはめた時の係数，残差，
  そして当てはめ値を返す．
  (ピボットが使われた時は係数の幾つかは \code{NA} になる．)
  \code{qr.qy} そして \code{qr.qty} は\code{Q \%*\% y} と
  \code{t(Q) \%*\% y} を返す．ここで \code{Q} は
  (完全) \eqn{\bold{Q}} 行列である．

  上の関数の全ては，もしあれば \code{x} と \code{y} の \code{dimnames}
  (と \code{names}) を保存する．

  \code{solve.qr} は \code{qr} オブジェクトに対する \code{\link{solve}} の
  メソッドである． 
  \code{qr.solve} は方程式系を QR 分解を使って解く：
  もし \code{a} が QR 分解ならそれは \code{solve.qr} と同じであるが，
  もし \code{a} が矩形行列ならば QR 分解がまず計算される．
  どちらも優決定的と劣決定的なシステムを
  扱い，もし適当ならば最少二乗フィットを与える．

  \code{is.qr} は，
  もし \code{x} が名前 \code{qr}, \code{rank} そして \code{qraux} を
  持つリストならば \code{TRUE} を返し，さもなければ
  \code{FALSE} を返す．

  オブジェクトをモード \code{"qr"} に強制変換することは出来ない．
  オブジェクトは QR 分解であるか無いかのどちらかである．

  LINPACK インタフェイスは要素数が 
  \eqn{2^{31}}{2^31} 未満の行列 \code{x} に制限される．

  \code{qr.fitted} と \code{qr.resid} は LINPACK インタフェイスだけをサポートする．

  基礎にある LAPACK コードの不成功の結果は正のエラーコードを持つエラーを
  与える：これらは FORTRAN コードの詳細な吟味によってのみ解釈できる．
}
\value{
  LINPACK か LAPACK で計算された行列の QR 分解．
  返り値の成分は直接 DQRDC, DGEQP3, ZGEQP3 が返す値と対応する．
  \item{qr}{\code{x} と同じ次元を持つ行列．
    上側三角部分は分解の \eqn{\bold{R}} を含み，
    下側三角部分は分解の \eqn{\bold{Q}} に関する情報を含む
    (コンパクトな形で保管されている)．DQRDC と DGEQP3 が
    用いる保管形式は異なることを注意する．}
  \item{qraux}{長さ \code{ncol(x)} のベクトルで
    \eqn{\bold{Q}} に関する追加の情報を持つ．}
  \item{rank}{分解で計算された \code{x} のランク：
    LAPACK ケースでは常にフルランク．}
  \item{pivot}{分解の途中で用いられたピボット操作に関する情報．}

  LAPACK により計算された非複素数値の QR オブジェクトは値が \code{TRUE} の
  属性 \code{"useLAPACK"} を持つ．
}
\note{
  行列の行列式の計算には(\emph{本当に}それが必要か?)
  QR 分解は固有値(\code{\link{eigen}})を使うよりも遥かに効率的である．
  \code{\link{det}} を見よ．

  LAPACK (複素数ケースを含み)の使用はピボットを用い，
  ランク落ち行列の検出を行わない．
}
\source{
  \code{qr} に付いては LINPACK ルーチン \code{DQRDC} と LAPACK
  ルーチン \code{DGEQP3} と \code{ZGEQP3}.  更に LINPACK と LAPACK
  ルーチンが \code{qr.coef}, \code{qr.qy} そして \code{qr.aty}
  に使われている．

  LAPACK と LINPACK は \url{http://www.netlib.org/lapack} と
  \url{http://www.netlib.org/linpack} にある．それらのガイドは
  参考文献にリストされている．
}
\references{
  Anderson. E. and ten others (1999)
  \emph{LAPACK Users' Guide}. Third Edition. SIAM.\cr
  Available on-line at
  \url{http://www.netlib.org/lapack/lug/lapack_lug.html}.

  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Dongarra, J. J., Bunch, J. R., Moler, C. B. and Stewart, G. W. (1978)
  \emph{LINPACK Users Guide.}  Philadelphia: SIAM Publications.
}
\seealso{
  行列の再構成については \code{\link{qr.Q}},  \code{\link{qr.R}},  \code{\link{qr.X}}．
  \code{\link{lm.fit}},  \code{\link{lsfit}},
  \code{\link{eigen}}, \code{\link{svd}}.

  (\code{qr} を用いた)行列式の計算については \code{\link{det}}．
}
\examples{
hilbert <- function(n) { i <- 1:n; 1 / outer(i - 1, i, "+") }
h9 <- hilbert(9); h9
qr(h9)$rank           #--> たった 7
qrh9 <- qr(h9, tol = 1e-10)
qrh9$rank             #--> 9
##-- 線形方程式 H \%*\% x = y を解く：
y <- 1:9/10
x <- qr.solve(h9, y, tol = 1e-10) # 又は同値な：
x <- qr.coef(qrh9, y) #-- == であるが，solve(h9) \%*\% y よりははるかに良い
h9 \%*\% x              # = y


## 優決定的なシステム
A <- matrix(runif(12), 4)
b <- 1:4
qr.solve(A, b) # or solve(qr(A), b)
solve(qr(A, LAPACK = TRUE), b)
# これは最少二乗解である，lm(b ~ 0 + A) を参照

## 劣決定的なシステム
A <- matrix(runif(12), 3)
b <- 1:3
qr.solve(A, b)
solve(qr(A, LAPACK = TRUE), b)
# 解は一つのゼロを持つが，同じものとは限らない
}
\keyword{algebra}
\keyword{array}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/qr.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{qr}
%\alias{qr}
%\alias{qr.default}
%\alias{qr.coef}
%\alias{qr.qy}
%\alias{qr.qty}
%\alias{qr.resid}
%\alias{qr.fitted}
%\alias{qr.solve}
%\alias{is.qr}
%\alias{as.qr}
%\alias{solve.qr}
%\title{The QR Decomposition of a Matrix}
%\usage{
%qr(x, \dots)
%\method{qr}{default}(x, tol = 1e-07 , LAPACK = FALSE, \dots)
%
%qr.coef(qr, y)
%qr.qy(qr, y)
%qr.qty(qr, y)
%qr.resid(qr, y)
%qr.fitted(qr, y, k = qr$rank)
%qr.solve(a, b, tol = 1e-7)
%\method{solve}{qr}(a, b, \dots)
%
%is.qr(x)
%as.qr(x)
%}
%\arguments{
%  \item{x}{a numeric or complex matrix whose QR decomposition is to be
%    computed.  Logical matrices are coerced to numeric.}
%  \item{tol}{the tolerance for detecting linear dependencies in the
%    columns of \code{x}. Only used if \code{LAPACK} is false and
%    \code{x} is real.}
%  \item{qr}{a QR decomposition of the type computed by \code{qr}.}
%  \item{y, b}{a vector or matrix of right-hand sides of equations.}
%  \item{a}{a QR decomposition or (\code{qr.solve} only) a rectangular matrix.}
%  \item{k}{effective rank.}
%  \item{LAPACK}{logical.  For real \code{x}, if true use LAPACK
%    otherwise use LINPACK (the default).}
%  \item{\dots}{further arguments passed to or from other methods}
%}
%\description{
%  \code{qr} computes the QR decomposition of a matrix.
%}
%\details{
%  The QR decomposition plays an important role in many
%  statistical techniques.  In particular it can be used to solve the
%  equation \eqn{\bold{Ax} = \bold{b}} for given matrix \eqn{\bold{A}},
%  and vector \eqn{\bold{b}}.  It is useful for computing regression
%  coefficients and in applying the Newton-Raphson algorithm.
%
%  The functions \code{qr.coef}, \code{qr.resid}, and \code{qr.fitted}
%  return the coefficients, residuals and fitted values obtained when
%  fitting \code{y} to the matrix with QR decomposition \code{qr}.
%  (If pivoting is used, some of the coefficients will be \code{NA}.)
%  \code{qr.qy} and \code{qr.qty} return \code{Q \%*\% y} and
%  \code{t(Q) \%*\% y}, where \code{Q} is the (complete) \eqn{\bold{Q}} matrix.
%
%  All the above functions keep \code{dimnames} (and \code{names}) of
%  \code{x} and \code{y} if there are any.
%
%  \code{solve.qr} is the method for \code{\link{solve}} for \code{qr} objects.
%  \code{qr.solve} solves systems of equations via the QR decomposition:
%  if \code{a} is a QR decomposition it is the same as \code{solve.qr},
%  but if \code{a} is a rectangular matrix the QR decomposition is
%  computed first.  Either will handle over- and under-determined
%  systems, providing a least-squares fit if appropriate.
%
%  \code{is.qr} returns \code{TRUE} if \code{x} is a \code{\link{list}}
%  with components named \code{qr}, \code{rank} and \code{qraux} and
%  \code{FALSE} otherwise.
%
%  It is not possible to coerce objects to mode \code{"qr"}.  Objects
%  either are QR decompositions or they are not.
%
%  The LINPACK interface is restricted to matrices \code{x} with less
%  than \eqn{2^{31}}{2^31} elements.
%
%  \code{qr.fitted} and \code{qr.resid} only support the LINPACK interface.
%
%  Unsuccessful results from the underlying LAPACK code will result in an
%  error giving a positive error code: these can only be interpreted by
%  detailed study of the FORTRAN code.
%}
%\value{
%  The QR decomposition of the matrix as computed by LINPACK or LAPACK.
%  The components in the returned value correspond directly
%  to the values returned by DQRDC/DGEQP3/ZGEQP3.
%  \item{qr}{a matrix with the same dimensions as \code{x}.
%    The upper triangle contains the \eqn{\bold{R}} of the decomposition
%    and the lower triangle contains information on the \eqn{\bold{Q}} of
%    the decomposition (stored in compact form).  Note that the storage
%    used by DQRDC and DGEQP3 differs.}
%  \item{qraux}{a vector of length \code{ncol(x)} which contains
%    additional information on \eqn{\bold{Q}}.}
%  \item{rank}{the rank of \code{x} as computed by the decomposition:
%    always full rank in the LAPACK case.}
%  \item{pivot}{information on the pivoting strategy used during
%    the decomposition.}
%
%  Non-complex QR objects computed by LAPACK have the attribute
%  \code{"useLAPACK"} with value \code{TRUE}.
%}
%\note{
%  To compute the determinant of a matrix (do you \emph{really} need it?),
%  the QR decomposition is much more efficient than using Eigen values
%  (\code{\link{eigen}}).  See \code{\link{det}}.
%
%  Using LAPACK (including in the complex case) uses column pivoting and
%  does not attempt to detect rank-deficient matrices.
%}
%\source{
%  For \code{qr}, the LINPACK routine \code{DQRDC} and the LAPACK
%  routines \code{DGEQP3} and \code{ZGEQP3}.  Further LINPACK and LAPACK
%  routines are used for \code{qr.coef}, \code{qr.qy} and \code{qr.aty}.
%
%  LAPACK and LINPACK are from \url{http://www.netlib.org/lapack} and
%  \url{http://www.netlib.org/linpack} and their guides are listed
%  in the references.
%}
%\references{
%  Anderson. E. and ten others (1999)
%  \emph{LAPACK Users' Guide}. Third Edition. SIAM.\cr
%  Available on-line at
%  \url{http://www.netlib.org/lapack/lug/lapack_lug.html}.
%
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Dongarra, J. J., Bunch, J. R., Moler, C. B. and Stewart, G. W. (1978)
%  \emph{LINPACK Users Guide.}  Philadelphia: SIAM Publications.
%}
%\seealso{
%  \code{\link{qr.Q}},  \code{\link{qr.R}},  \code{\link{qr.X}} for
%  reconstruction of the matrices.
%  \code{\link{lm.fit}},  \code{\link{lsfit}},
%  \code{\link{eigen}}, \code{\link{svd}}.
%
%  \code{\link{det}} (using \code{qr}) to compute the determinant of a matrix.
%}
%\examples{
%hilbert <- function(n) { i <- 1:n; 1 / outer(i - 1, i, "+") }
%h9 <- hilbert(9); h9
%qr(h9)$rank           #--> only 7
%qrh9 <- qr(h9, tol = 1e-10)
%qrh9$rank             #--> 9
%##-- Solve linear equation system  H \%*\% x = y :
%y <- 1:9/10
%x <- qr.solve(h9, y, tol = 1e-10) # or equivalently :
%x <- qr.coef(qrh9, y) #-- is == but much better than
%                      #-- solve(h9) \%*\% y
%h9 \%*\% x              # = y
%
%
%## overdetermined system
%A <- matrix(runif(12), 4)
%b <- 1:4
%qr.solve(A, b) # or solve(qr(A), b)
%solve(qr(A, LAPACK = TRUE), b)
%# this is a least-squares solution, cf. lm(b ~ 0 + A)
%
%## underdetermined system
%A <- matrix(runif(12), 3)
%b <- 1:3
%qr.solve(A, b)
%solve(qr(A, LAPACK = TRUE), b)
%# solutions will have one zero, not necessarily the same one
%}
%\keyword{algebra}
%\keyword{array}
%
\encoding{UTF8}
