% File src/library/base/man/qraux.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Copyright 2002-2012 The R Foundation
% Distributed under GPL 2 or later

\name{QR.Auxiliaries}
\title{Reconstruct the Q, R, or X Matrices from a QR Object}
\usage{
qr.X(qr, complete = FALSE, ncol =)
qr.Q(qr, complete = FALSE, Dvec =)
qr.R(qr, complete = FALSE, \dots)
}
\alias{qr.X}
\alias{qr.Q}
\alias{qr.R}
\arguments{
  \item{qr}{QR 分解を表現するオブジェクト．これは典型的には
    先立つ \code{\link{qr}} 又は \code{\link{lsfit}} への呼び出しに由来する．}
  \item{complete}{長さ 1 の論理値． \eqn{\bold{Q}} または
    \eqn{\bold{X}} 行列の任意の直交補完を作るべきかどうかを指示する．
    又は \eqn{\bold{R}} 行列が正方上側三角部分の下にゼロ値を付け加えて
    補完すべきかどうかを指示する．}
  \item{ncol}{範囲 \code{1:nrow(qr$qr)} 中の整数．
    構成された \eqn{\bold{X}} 中にある列数．
    \code{complete} が \code{FALSE} の時の既定値は
    それからオブジェクトが構成された元の \eqn{\bold{X}} の
    最初の \code{min(ncol(X), nrow(X))} 個の列．
    \code{complete} が \code{TRUE} の時の既定値は
    \eqn{\bold{X}} が最初の \code{ncol(X)} 個の列で残りの列に
    任意の直交補完(複素ケースではユニタリ補完)を持つ正方行列．}
  \item{Dvec}{対角部分の値のベクトル(行列ではない)．
    返り値  \eqn{\bold{Q}}  の各列には対応する対角値が掛けられる．
    既定値は全ての \code{1}．}
  \item{\dots}{追加の引数で，非既定のメソッドに渡される．}
}
\description{
  それからオブジェクトが構成された元の行列を返す．又は分解の成分から
  計算する．
}
\value{
  \code{qr.X} は \code{ncol(X) <= nrow(X)} ならば，qr オブジェクトが
  それから構成された元の \eqn{\bold{X}} を返す．
  もし \code{complete} が \code{TRUE} か，引数 \code{ncol} が
  \code{ncol(X)} より大きければ，\code{X} の任意の直交(ユニタリ)補完からの
  追加の列が返される．

  \code{qr.Q} は次数 nrow(X) の
  \code{qr} によって表現される直交(ユニタリ)変換である
   \bold{Q} の一部又は全部．
  もし \code{complete} が \code{TRUE} ならば \bold{Q} は \code{nrow(X)}
  個の列を持つ．もし \code{complete} が \code{FALSE} ならば \bold{Q} は
  \code{ncol(X)} 個の列を持つ．\code{Dvec} が指定されると，
  \bold{Q} の各列には \code{Dvec} 中の値が掛けられる．

  \code{qr.Q(qr, *)} は \code{\link{qr.qy}(qr, y)}
  (\dQuote{対角の} \code{y}) の特殊ケースで，
  \code{qr.X(qr, *)} は基本的に \code{\link{qr.qy}(qr, R)}
  (ピボット操作と \code{dimnames} の設定別として) であることを注意する．.

 \code{qr.R} は \bold{R} を返す．これはピボットされているかもしれない，例えば
 もし \code{a <- qr(x)} なら \code{x[, a$pivot]} = \bold{QR}．
 \bold{R} の行数は \code{nrow(X)} か \code{ncol(X)} である
 (そして \code{complete} が \code{TRUE} か \code{FALSE} かに
 依存するかもしれない)．
}
\seealso{
  \code{\link{qr}},
  \code{\link{qr.qy}}.
}
\examples{
p <- ncol(x <- LifeCycleSavings[, -1]) # 'sr' ではない
qrstr <- qr(x)   # dim(x) == c(n,p)
qrstr $ rank # = 4 = p
Q <- qr.Q(qrstr) # dim(Q) == dim(x)
R <- qr.R(qrstr) # dim(R) == ncol(x)
X <- qr.X(qrstr) # X == x
range(X - as.matrix(x))  # ~ < 6e-12
## この場合のようにピボット操作が無ければ X == Q \%*\% R：
all.equal(unname(X),
          unname(Q \%*\% R))

# ピボット操作の例
x <- cbind(int = 1,
           b1 = rep(1:0, each = 3), b2 = rep(0:1, each = 3),
           c1 = rep(c(1,0,0), 2), c2 = rep(c(0,1,0), 2), c3 = rep(c(0,0,1),2))
x # 特異，列 "b2" と "c3" が "余分"
a <- qr(x)
zapsmall(qr.R(a)) # 列は整数の b1 c1 c2 b2 c3
a$pivot
pivI <- sort.list(a$pivot) # 逆置換
all.equal (x,            qr.Q(a) \%*\% qr.R(a)) # 違う!
stopifnot(
 all.equal(x[, a$pivot], qr.Q(a) \%*\% qr.R(a)),          # TRUE
 all.equal(x           , qr.Q(a) \%*\% qr.R(a)[, pivI]))  # これも TRUE!
}
\keyword{algebra}
\keyword{array}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/qraux.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Copyright 2002-2012 The R Foundation
%% Distributed under GPL 2 or later
%
%\name{QR.Auxiliaries}
%\title{Reconstruct the Q, R, or X Matrices from a QR Object}
%\usage{
%qr.X(qr, complete = FALSE, ncol =)
%qr.Q(qr, complete = FALSE, Dvec =)
%qr.R(qr, complete = FALSE, \dots)
%}
%\alias{qr.X}
%\alias{qr.Q}
%\alias{qr.R}
%\arguments{
%  \item{qr}{object representing a QR decomposition.  This will
%    typically have come from a previous call to \code{\link{qr}} or
%    \code{\link{lsfit}}.}
%  \item{complete}{logical expression of length 1.  Indicates whether an
%    arbitrary  orthogonal completion of the \eqn{\bold{Q}} or
%    \eqn{\bold{X}} matrices is to be made, or whether the \eqn{\bold{R}}
%    matrix is to be completed  by binding zero-value rows beneath the
%    square upper triangle.}
%  \item{ncol}{integer in the range \code{1:nrow(qr$qr)}.  The number
%    of columns to be in the reconstructed \eqn{\bold{X}}.  The default
%    when \code{complete} is \code{FALSE} is the first
%    \code{min(ncol(X), nrow(X))} columns of the original \eqn{\bold{X}}
%    from which the qr object was constructed.  The default when
%    \code{complete} is \code{TRUE} is a square matrix with the original
%    \eqn{\bold{X}} in the first \code{ncol(X)} columns and an arbitrary
%    orthogonal completion (unitary completion in the complex case) in
%    the remaining columns.}
%  \item{Dvec}{vector (not matrix) of diagonal values.  Each column of
%    the returned \eqn{\bold{Q}} will be multiplied by the corresponding
%    diagonal value.  Defaults to all \code{1}s.}
%  \item{\dots}{potentially further arguments, passed potentially to
%    non-default methods.}
%}
%\description{
%  Returns the original matrix from which the object was constructed or
%  the components of the decomposition.
%}
%\value{
%  \code{qr.X} returns \eqn{\bold{X}}, the original matrix from
%  which the qr object was constructed, provided \code{ncol(X) <= nrow(X)}.
%  If \code{complete} is \code{TRUE} or the argument \code{ncol} is greater than
%  \code{ncol(X)}, additional columns from an arbitrary orthogonal
%  (unitary) completion of \code{X} are returned.
%
%  \code{qr.Q} returns part or all of \bold{Q}, the order-nrow(X)
%  orthogonal (unitary) transformation represented by \code{qr}.  If
%  \code{complete} is \code{TRUE}, \bold{Q} has \code{nrow(X)} columns.
%  If \code{complete} is \code{FALSE}, \bold{Q} has \code{ncol(X)}
%  columns.  When \code{Dvec} is specified, each column of \bold{Q} is
%  multiplied by the corresponding value in \code{Dvec}.
%
%  Note that \code{qr.Q(qr, *)} is a special case of
%  \code{\link{qr.qy}(qr, y)} (with a \dQuote{diagonal} \code{y}), and
%  \code{qr.X(qr, *)} is basically \code{\link{qr.qy}(qr, R)} (apart from
%  pivoting and \code{dimnames} setting).
%
% \code{qr.R} returns \bold{R}.  This may be pivoted, e.g., if
% \code{a <- qr(x)} then \code{x[, a$pivot]} = \bold{QR}.  The number of
% rows of \bold{R} is either \code{nrow(X)} or \code{ncol(X)} (and may
% depend on whether \code{complete} is \code{TRUE} or \code{FALSE}).
%}
%\seealso{
%  \code{\link{qr}},
%  \code{\link{qr.qy}}.
%}
%\examples{
%p <- ncol(x <- LifeCycleSavings[, -1]) # not the 'sr'
%qrstr <- qr(x)   # dim(x) == c(n,p)
%qrstr $ rank # = 4 = p
%Q <- qr.Q(qrstr) # dim(Q) == dim(x)
%R <- qr.R(qrstr) # dim(R) == ncol(x)
%X <- qr.X(qrstr) # X == x
%range(X - as.matrix(x))  # ~ < 6e-12
%## X == Q \%*\% R if there has been no pivoting, as here:
%all.equal(unname(X),
%          unname(Q \%*\% R))
%
%# example of pivoting
%x <- cbind(int = 1,
%           b1 = rep(1:0, each = 3), b2 = rep(0:1, each = 3),
%           c1 = rep(c(1,0,0), 2), c2 = rep(c(0,1,0), 2), c3 = rep(c(0,0,1),2))
%x # is singular, columns "b2" and "c3" are "extra"
%a <- qr(x)
%zapsmall(qr.R(a)) # columns are int b1 c1 c2 b2 c3
%a$pivot
%pivI <- sort.list(a$pivot) # the inverse permutation
%all.equal (x,            qr.Q(a) \%*\% qr.R(a)) # no, no
%stopifnot(
% all.equal(x[, a$pivot], qr.Q(a) \%*\% qr.R(a)),          # TRUE
% all.equal(x           , qr.Q(a) \%*\% qr.R(a)[, pivI]))  # TRUE too!
%}
%\keyword{algebra}
%\keyword{array}
%
\encoding{UTF8}
