% File src/library/base/man/sample.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{sample}
\alias{sample}
\alias{sample.int}
\title{Random Samples and Permutations}
\description{
  \code{sample} は \code{x} の要素から指定されたサイズのサンプルを置き換え，又は
  置き換え無しで取り出す．
}
\usage{
sample(x, size, replace = FALSE, prob = NULL)

sample.int(n, size = n, replace = FALSE, prob = NULL)
}
\arguments{
  \item{x}{それから選択する一つもしくはそれ以上の要素のベクトルか，
    正整数．\sQuote{詳細} を見よ．}
  \item{n}{正整数で，選択される項目の個数．\sQuote{詳細} を見よ．}
  \item{size}{選択される項目の数を与える非負整数．}
  \item{replace}{サンプリングは置き換え有りで行うか?}
  \item{prob}{サンプルされるベクトルの要素を得るための確率重みのベクトル．}
}
\details{
  もし \code{x} が長さ 1 を持てば数値
  (\code{\link{is.numeric}} の意味で)，そして \code{x >= 1} なら
  \code{1:x} からの \code{sample} によるサンプル．
  この決まりは \code{sample(x)} のような \code{x} が呼び出し中で
  可変な長さを持つときは好ましくない挙動にみちびかれるかもしれない
  ことを注意しよう．

  さもなければ \code{x} は \code{length} と整数による部分抽出が
  意味を持つ任意の \R オブジェクトで良い：
  これらの操作に対する S3 又は S4 メソッドは適切さに応じて
  選択適用される．

  \code{sample} に対しては \code{size} に対する来て地は最初の引数から
  推測される項目数になるので，\code{sample(x)} は \code{x} (又は \code{1:x})
  の無作為置換を生成する．

  \code{n = 0} 又は長さがゼロの \code{x} を用いた \code{size = 0} の
  サンプルを要求することは許されるが，
  さもなければ \code{n > 0} 又は正の \code{length(x)} が要求される．

  \code{x} 又は \code{x} への整数でない正数値は
  次の最少の整数に切り詰められる．
  これは \code{\link{.Machine}$integer.max} よりも大きくあってはならない．

  オプションの \code{prob} 引数はサンプルされるベクトルの要素を得るための
  重みベクトルを与えるのに使うことが出来る．それらは総和が 1 になる
  必要はないが，非負で全部がゼロであってはならない．
  もし \code{replace} が真なら Walker のエイリアス法(Ripley, 1987)が
  合理的にありそうな値が 200 以上ある時に使われる：
  これは \R < 2.2.0 からのそれらとは互換性のない結果を与える．

  もし \code{replace} が偽なら，これらの確率は逐次的に提供される，
  つまり次の項目を選択する確率は残りの項目中での重みに比例する．
  ゼロでない重みの数はこのケースでは少なくとも \code{size} 個
  必要になる．

  \code{sample.int} は飾り気の無いインタフェイスであり，
  \code{n} と \code{size} の両方が整数として与えられなければならない．

  \R 3.0.0 以来 \code{n} は整数型の最大整数よりも大きくてもよく，
  倍精度実数型で表現可能な最大整数まで許される．
  一様なサンプリングだけがサポートされている．二つの乱数が大きな
  整数の一様サンプリングを保証するために使われる．
}

\value{
  \code{sample} に対しては長さ \code{size} のベクトルで，
  その要素は \code{x} か整数 \code{1:x} から取り出される．

  \code{sample.int} に対しては長さが \code{size} の
  整数ベクトルで，その要素は \code{1:n} 又はもし
  \eqn{n \ge 2^{31}}{n >= 2^31} ならば倍精度実数ベクトルから
  取り出される．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Ripley, B. D. (1987) \emph{Stochastic Simulation}. Wiley.
}
\seealso{
  乱数生成については \code{\link{RNG}}．

  置き換え無しの重み付きサンプリングの他の方法については CRAN パッケージ
  \CRANpkg{sampling}．
}
\examples{
x <- 1:12
# ランダムな置換
sample(x)
# ブートストラップリサンプリング -- length(x) > 1 の時だけ!
sample(x, replace = TRUE)

# 100 組のベルヌイ試行
sample(c(0,1), 100, replace = TRUE)

## より慎重なブートストラップ --  プログラム中で sample() を使う際に
## これを考慮しよう(つまり自分の関数やシミュレーション中で)!

# sample() のサプライズ -- 例
x <- 1:10
    sample(x[x >  8]) # 長さ 2
    sample(x[x >  9]) # なんと -- 長さ 10!
    sample(x[x > 10]) # 長さ 0

resample <- function(x, ...) x[sample.int(length(x), ...)]
resample(x[x >  8]) # 長さ 2
resample(x[x >  9]) # 長さ 1
resample(x[x > 10]) # 長さ 0

## R 3.x.y のみ
sample.int(1e10, 12, replace = TRUE)
sample.int(1e10, 12) # 複製出来る可能性はまず無い
}
\keyword{distribution}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/sample.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{sample}
%\alias{sample}
%\alias{sample.int}
%\title{Random Samples and Permutations}
%\description{
%  \code{sample} takes a sample of the specified size from the elements
%  of \code{x} using either with or without replacement.
%}
%\usage{
%sample(x, size, replace = FALSE, prob = NULL)
%
%sample.int(n, size = n, replace = FALSE, prob = NULL)
%}
%\arguments{
%  \item{x}{Either a vector of one or more elements from which to choose,
%    or a positive integer.  See \sQuote{Details.}}
%  \item{n}{a positive number, the number of items to choose from.  See
%    \sQuote{Details.}}
%  \item{size}{a non-negative integer giving the number of items to choose.}
%  \item{replace}{Should sampling be with replacement?}
%  \item{prob}{A vector of probability weights for obtaining the elements
%    of the vector being sampled.}
%}
%\details{
%  If \code{x} has length 1, is numeric (in the sense of
%  \code{\link{is.numeric}}) and \code{x >= 1}, sampling \emph{via}
%  \code{sample} takes place from \code{1:x}.  \emph{Note} that this
%  convenience feature may lead to undesired behaviour when \code{x} is
%  of varying length in calls such as \code{sample(x)}.  See the examples.
%
%  Otherwise \code{x} can be any \R object for which \code{length} and
%  subsetting by integers make sense: S3 or S4 methods for these
%  operations will be dispatched as appropriate.
%
%  For \code{sample} the default for \code{size} is the number of items
%  inferred from the first argument, so that \code{sample(x)} generates a
%  random permutation of the elements of \code{x} (or \code{1:x}).
%
%  It is allowed to ask for \code{size = 0} samples with \code{n = 0} or
%  a length-zero \code{x}, but otherwise \code{n > 0} or positive
%  \code{length(x)} is required.
%
%  Non-integer positive numerical values of \code{n} or \code{x} will be
%  truncated to the next smallest integer, which has to be no larger than
%  \code{\link{.Machine}$integer.max}.
%
%  The optional \code{prob} argument can be used to give a vector of
%  weights for obtaining the elements of the vector being sampled.  They
%  need not sum to one, but they should be non-negative and not all zero.
%  If \code{replace} is true, Walker's alias method (Ripley, 1987) is
%  used when there are more than 200 reasonably probable values: this
%  gives results incompatible with those from \R < 2.2.0.
%
%  If \code{replace} is false, these probabilities are applied
%  sequentially, that is the probability of choosing the next item is
%  proportional to the weights amongst the remaining items.  The number
%  of nonzero weights must be at least \code{size} in this case.
%
%  \code{sample.int} is a bare interface in which both \code{n} and
%  \code{size} must be supplied as integers.
%
%  As from \R 3.0.0, \code{n} can be larger than the largest integer of
%  type \code{integer}, up to the largest representable integer in type
%  \code{double}.  Only uniform sampling is supported.  Two
%  random numbers are used to ensure uniform sampling of large integers.
%}
%
%\value{
%  For \code{sample} a vector of length \code{size} with elements
%  drawn from either \code{x} or from the integers \code{1:x}.
%
%  For \code{sample.int}, an integer vector of length \code{size} with
%  elements from \code{1:n}, or a double vector if
%  \eqn{n \ge 2^{31}}{n >= 2^31}.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Ripley, B. D. (1987) \emph{Stochastic Simulation}. Wiley.
%}
%\seealso{
%  \code{\link{RNG}} about random number generation.
%
%  CRAN package \CRANpkg{sampling} for other methods of weighted sampling
%  without replacement.
%}
%\examples{
%x <- 1:12
%# a random permutation
%sample(x)
%# bootstrap resampling -- only if length(x) > 1 !
%sample(x, replace = TRUE)
%
%# 100 Bernoulli trials
%sample(c(0,1), 100, replace = TRUE)
%
%## More careful bootstrapping --  Consider this when using sample()
%## programmatically (i.e., in your function or simulation)!
%
%# sample()'s surprise -- example
%x <- 1:10
%    sample(x[x >  8]) # length 2
%    sample(x[x >  9]) # oops -- length 10!
%    sample(x[x > 10]) # length 0
%
%resample <- function(x, ...) x[sample.int(length(x), ...)]
%resample(x[x >  8]) # length 2
%resample(x[x >  9]) # length 1
%resample(x[x > 10]) # length 0
%
%## R 3.x.y only
%sample.int(1e10, 12, replace = TRUE)
%sample.int(1e10, 12) # not that there is much chance of duplicates
%}
%\keyword{distribution}
%
\encoding{UTF8}
