% File src/library/base/man/seq.POSIXt.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{seq.POSIXt}
\alias{seq.POSIXt}
\title{Generate Regular Sequences of Times}
\description{
  日付・時刻オブジェクトに対する \code{\link{seq}} メソッド．
}
\usage{
\method{seq}{POSIXt}(from, to, by, length.out = NULL, along.with = NULL, \dots)
}
\arguments{
  \item{from}{開始日，必須．．}
  \item{to}{終了日．オプション．}
  \item{by}{系列の増分．オプション．\sQuote{詳細}を見よ．}
  \item{length.out}{整数，オプション．系列の希望の長さ．}
  \item{along.with}{長さをこの引数の長さから取る．}
  \item{\dots}{他のメソッドへ・から渡される引数．}
}
\details{
  \code{by} は幾つかの方法で指定できる．
  \itemize{
    \item 数値，単位は秒とされる．
    \item クラス \code{\link{difftime}} のオブジェクト．
    \item 文字列で \code{"sec"},
    \code{"min"}, \code{"hour"}, \code{"day"}, \code{"DSTday"},
    \code{"week"}, \code{"month"}, \code{"quarter"} 又は \code{"year"}
    のどれか一つ．これはオプションで(正もしくは負の)整数と空白が
    前にあっても良い．又は \code{"s"} が続く．
  }
  \code{"day"} と \code{"DSTday"} の違いは，前者が夏時間への・からの変更を
  無視するのに対し後者は毎日同じ時計時間を使うことにある．
  (\code{"week"} は DST を無視する(周期144時間)が，\code{"7 DSTdays"} は
  代わりに使うことが出来る)．\code{"month"} と \code{"year"} は
  DST に対して許される．

  結果のタイムゾーンは \code{from} から取られる：
  GMT は UTC を意味するので(そして英国の Greenwich のタイムゾーンではない)
  夏時間を持たない．

  \code{"month"} の使用は日を変更せずに先ず月を進める：
  もし結果が月の不正な日になれば，次の月に進められる：例を見よ．
}
\value{
  クラス \code{"POSIXct"} のベクトル．
}
\note{
  \R 3.1.0 以前では四半期の増分は \code{by = "3 months"} で指定された．
}

\seealso{\code{\link{DateTimeClasses}}}

\examples{
## 一年の最初の日
seq(ISOdate(1910,1,1), ISOdate(1999,1,1), "years")
## 月ごとに
seq(ISOdate(2000,1,1), by = "month", length.out = 12)
seq(ISOdate(2000,1,31), by = "month", length.out = 4)
## 四半期
seq(ISOdate(1990,1,1), ISOdate(2000,1,1), by = "quarter") # または "3 months"
## days 対 DSTdays： タイムゾーンを無くすには c() を使う．
seq(c(ISOdate(2000,3,20)), by = "day", length.out = 10)
seq(c(ISOdate(2000,3,20)), by = "DSTday", length.out = 10)
seq(c(ISOdate(2000,3,20)), by = "7 DSTdays", length.out = 4)
}
\keyword{manip}
\keyword{chron}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/seq.POSIXt.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{seq.POSIXt}
%\alias{seq.POSIXt}
%\title{Generate Regular Sequences of Times}
%\description{
%  The method for \code{\link{seq}} for date-time classes.
%}
%\usage{
%\method{seq}{POSIXt}(from, to, by, length.out = NULL, along.with = NULL, \dots)
%}
%\arguments{
%  \item{from}{starting date.  Required.}
%  \item{to}{end date.  Optional.}
%  \item{by}{increment of the sequence.  Optional.  See \sQuote{Details}.}
%  \item{length.out}{integer, optional.  Desired length of the sequence.}
%  \item{along.with}{take the length from the length of this argument.}
%  \item{\dots}{arguments passed to or from other methods.}
%}
%\details{
%  \code{by} can be specified in several ways.
%  \itemize{
%    \item A number, taken to be in seconds.
%    \item A object of class \code{\link{difftime}}
%    \item A character string, containing one of \code{"sec"},
%    \code{"min"}, \code{"hour"}, \code{"day"}, \code{"DSTday"},
%    \code{"week"}, \code{"month"}, \code{"quarter"} or \code{"year"}.
%    This can optionally be preceded by a (positive or negative) integer
%    and a space, or followed by \code{"s"}.
%  }
%  The difference between \code{"day"} and \code{"DSTday"} is that the
%  former ignores changes to/from daylight savings time and the latter takes
%  the same clock time each day.  (\code{"week"} ignores DST (it is a
%  period of 144 hours), but \code{"7 DSTdays"}) can be used as an
%  alternative.  \code{"month"} and \code{"year"} allow for DST.)
%
%  The \link{time zone} of the result is taken from \code{from}: remember
%  that GMT means UTC (and not the time zone of Greenwich, England) and so
%  does not have daylight savings time.
%
%  Using \code{"month"} first advances the month without changing the
%  day: if this results in an invalid day of the month, it is counted
%  forward into the next month: see the examples.
%}
%\value{
%  A vector of class \code{"POSIXct"}.
%}
%\note{
%  Quarterly increments were specified by \code{by = "3 months"} prior to
%  \R 3.1.0.
%}
%
%\seealso{\code{\link{DateTimeClasses}}}
%
%\examples{
%## first days of years
%seq(ISOdate(1910,1,1), ISOdate(1999,1,1), "years")
%## by month
%seq(ISOdate(2000,1,1), by = "month", length.out = 12)
%seq(ISOdate(2000,1,31), by = "month", length.out = 4)
%## quarters
%seq(ISOdate(1990,1,1), ISOdate(2000,1,1), by = "quarter") # or "3 months"
%## days vs DSTdays: use c() to lose the time zone.
%seq(c(ISOdate(2000,3,20)), by = "day", length.out = 10)
%seq(c(ISOdate(2000,3,20)), by = "DSTday", length.out = 10)
%seq(c(ISOdate(2000,3,20)), by = "7 DSTdays", length.out = 4)
%}
%\keyword{manip}
%\keyword{chron}
%
\encoding{UTF8}
