% File src/library/base/man/tabulate.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{tabulate}
\title{Tabulation for Vectors}
\description{
  \code{tabulate} は整数値ベクトルを取り各整数がその中に登場する
  回数を数える．
}
\usage{
tabulate(bin, nbins = max(1, bin, na.rm = TRUE))
}
\alias{tabulate}
\arguments{
    \item{bin}{(正整数の)数値ベクトル，又は因子．
      ロングベクトルがサポートされている．}
    \item{nbins}{使われるビンの数．}
}
\details{
   \code{tabulate} は \code{\link{table}} 関数の実働関数である．

  もし \code{bin} が因子なら，その内部整数表現が作表される．

  もし \code{bin} の要素が数値であるが整数でなければ
  \code{\link{as.integer}} により切り詰められる．
}
\value{
  整数ベクトル(名前無し)．値 \code{1, \dots, nbins} の各々に対するビンがある；
  この範囲外の値と \code{NA} は(黙って)無視される．

  64 ビットプラットフォームでは \code{bin} は \eqn{2^{31}}{2^31} もしくは
  それ以上の要素を持つことが出来，従って一つのカウントは最大整数を
  超えるかもしれない：これは現在エラーになる．
}
\seealso{
  \code{\link{table}}, \code{\link{factor}}.
}
\examples{
tabulate(c(2,3,5))
tabulate(c(2,3,3,5), nbins = 10)
tabulate(c(-2,0,2,3,3,5))  # -2 と 0 は無視される
tabulate(c(-2,0,2,3,3,5), nbins = 3)
tabulate(factor(letters[1:10]))
}
\keyword{arith}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/tabulate.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{tabulate}
%\title{Tabulation for Vectors}
%\description{
%  \code{tabulate} takes the integer-valued vector \code{bin} and counts
%  the number of times each integer occurs in it.
%}
%\usage{
%tabulate(bin, nbins = max(1, bin, na.rm = TRUE))
%}
%\alias{tabulate}
%\arguments{
%    \item{bin}{a numeric vector (of positive integers), or a factor.
%      \link{Long vectors} are supported.}
%    \item{nbins}{the number of bins to be used.}
%}
%\details{
%   \code{tabulate} is the workhorse for the \code{\link{table}} function.
%
%  If \code{bin} is a factor, its internal integer representation
%  is tabulated.
%
%  If the elements of \code{bin} are numeric but not integers,
%  they are truncated by \code{\link{as.integer}}.
%}
%\value{
%  An integer vector (without names).  There is a bin for each of the
%  values \code{1, \dots, nbins}; values outside that range and \code{NA}s
%  are (silently) ignored.
%
%  On 64-bit platforms \code{bin} can have \eqn{2^{31}}{2^31} or more
%  elements and hence a count could exceed the maximum integer: this is
%  currently an error.
%}
%\seealso{
%  \code{\link{table}}, \code{\link{factor}}.
%}
%\examples{
%tabulate(c(2,3,5))
%tabulate(c(2,3,3,5), nbins = 10)
%tabulate(c(-2,0,2,3,3,5))  # -2 and 0 are ignored
%tabulate(c(-2,0,2,3,3,5), nbins = 3)
%tabulate(factor(letters[1:10]))
%}
%\keyword{arith}
%\encoding{UTF8}

\encoding{UTF8}

