% File src/library/base/man/traceback.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{traceback}
\alias{traceback}
\alias{.Traceback}
\title{Print Call Stacks}
\description{
  既定では \code{traceback()} は最後の未把握のエラーの呼び出しスタックを
  プリントする，つまりエラーに至る呼び出しの列である．
  これは特定出来ないエラーメッセージを持つエラーが起きた時役に立つ．
  これはまた現在のスタックや逆構文解析された呼び出しの任意のリスト
  をプリントするのに使える．
}
\usage{
traceback(x = NULL, max.lines = getOption("deparse.max.lines"))
}
\arguments{
  \item{x}{\code{NULL} (既定は \code{.Traceback}) を意味する．または
    現在のスタック中でスキップする呼び出し回数，又は逆構文解析された呼び出しの
    リスト又は対リスト．詳細を見よ．}
  \item{max.lines}{\emph{呼び出し毎に}プリントされる行の最大数．
    既定では制限なし．}
}
\details{
  既定の表示は \code{.Traceback} 中の逆構文解析された呼び出しのリストとして
  保管された最後の未把握エラーのスタックのものであり，
  \code{traceback} がそれをわかりやすい形でプリントする．逆構文解析された
  呼び出しのリストは常に全ての関数呼び出しと全ての(\code{\link{.Call}} のような)
  外部関数呼び出しを含む：もしプロファイリングが進行中ならこれは
  あるプリミティブな関数への呼び出しを含む．
  (組み込み関数への呼び出しは含まれるが，特殊関数へのそれは含まれない．)

  \code{\link{try}} や \code{\link{tryCatch}} によって補足されたエラーは
  トレースバックを生成しないので，プリントされるものは
  最後の未把握のエラーに対するもので，
  必ずしも最後のエラーに対するものではない．

  もし \code{x} が数値なら，スタックの先頭にある \code{x} 項目をスキップして
  現在のスタックがプリントされる．例えば
  \code{options(error = function() traceback(2))} は
  \code{traceback()} への呼び出しとそれを呼び出したエラー関数をスキップして
  エラー時のスタックをプリントする．

  さもなければ，\code{x} は逆構文解析された呼び出しのリストか対リストであると
  仮定され，同じように表示される．
}
\value{
  \code{traceback()} は逆構文解析された呼び出しスタックを
  最深の呼び出しが最初になるようにプリントし，それを不可視で返す．
  呼び出しは複数行にプリントされるかもしれず，
  各呼び出しに対する最初の行はフレーム番号でラベルが付く．
  プリントされる行数は \code{max.lines} を使って制限できる．
}
\section{警告}{
  \code{.Traceback} がどこに保存されるかまたそれが可視かはどこにも
  文章化されていない．これは将来変更されるかもしれない．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
foo <- function(x) { print(1); bar(2) }
bar <- function(x) { x + a.variable.which.does.not.exist }
\dontrun{
foo(2) # 不思議なエラーを与える
traceback()}
## 2: bar(2)
## 1: foo(2)
bar
## 嗚呼，これが犯人 ...

## これはエラー発生時にスタックのトレースをプリントする
options(error = function() traceback(2))
}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/traceback.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{traceback}
%\alias{traceback}
%\alias{.Traceback}
%\title{Print Call Stacks}
%\description{
%  By default \code{traceback()} prints the call stack of the last
%  uncaught error, i.e., the sequence of calls that lead to the error.
%  This is useful when an error occurs with an unidentifiable error
%  message.  It can also be used to print the current stack or
%  arbitrary lists of deparsed calls.
%}
%\usage{
%traceback(x = NULL, max.lines = getOption("deparse.max.lines"))
%}
%\arguments{
%  \item{x}{\code{NULL} (default, meaning \code{.Traceback}), or an
%    integer count of calls to skip in the current stack, or a list or
%    pairlist of deparsed calls.  See the details.}
%  \item{max.lines}{The maximum number of lines to be printed
%    \emph{per call}.  The default is unlimited.}
%}
%\details{
%  The default display is of the stack of the last uncaught error as
%  stored as a list of deparsed calls in \code{.Traceback}, which
%  \code{traceback} prints in a user-friendly format.  The stack of
%  deparsed calls always contains all function calls and all foreign
%  function calls (such as \code{\link{.Call}}): if profiling is in
%  progress it will include calls to some primitive functions.  (Calls
%  to builtins are included, but not to specials.)
%
%  Errors which are caught \emph{via} \code{\link{try}} or
%  \code{\link{tryCatch}} do not generate a traceback, so what is printed
%  is the call sequence for the last uncaught error, and not necessarily
%  for the last error.
%
%  If \code{x} is numeric, then the current stack is printed, skipping
%  \code{x} entries at the top of the stack.  For example,
%  \code{options(error = function() traceback(2))} will print the stack
%  at the time of the error, skipping the call to \code{traceback()}
%  and the error function that called it.
%
%  Otherwise, \code{x} is assumed to be a list or pairlist of deparsed
%  calls and will be displayed in the same way.
%}
%\value{
%  \code{traceback()} prints the deparsed call stack deepest call
%  first, and returns it invisibly.  The calls may print on more than
%  one line, and the first line for each call is labelled by the frame
%  number.  The number of lines printed per call can be limited via
%  \code{max.lines}.
%}
%\section{Warning}{
%  It is undocumented where \code{.Traceback} is stored nor that it is
%  visible, and this is subject to change.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%foo <- function(x) { print(1); bar(2) }
%bar <- function(x) { x + a.variable.which.does.not.exist }
%\dontrun{
%foo(2) # gives a strange error
%traceback()}
%## 2: bar(2)
%## 1: foo(2)
%bar
%## Ah, this is the culprit ...
%
%## This will print the stack trace at the time of the error.
%options(error = function() traceback(2))
%}
%\keyword{programming}
%\encoding{UTF8}

\encoding{UTF8}

