% File src/library/datasets/man/randu.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{randu}
\docType{data}
\title{RANDU 乱数データ}
\alias{randu}
%%\title{Random Numbers from Congruential Generator RANDU}
\description{
  VMS 1.5 の下で稼働する VAX FORTRAN 関数 RANDU から取られた
  引き続く乱数の三つ組400個．
}
\usage{randu}
\details{
  三次元ディスプレイでは三つ組は
  三次元区間の15枚の平行平面に載ることが明らかである．
  これは RANDU 生成器からの全ての三つ組について正しいことが理論的に
  証明できる．

  これらの特別な400個の三つ組は系列中5つ離れて始まる，
  つまりそれらは
  ((U[5i+1], U[5i+2], U[5i+3]), i= 0, \dots, 399) で，小数点以下6桁に
  丸められている．

  VMS のバージョン 2.0 以降ではこの問題は訂正されている．
}
\format{名前 \code{x}, \code{y} そして \code{z} の
  3変数と400観測値のデータフレームで，三つ組の最初と二番目と三番目の
  乱数を与える．
}
\source{
  David Donoho
}
\examples{
\donttest{## 次の R コードでデータセットを再生成できる
seed <- as.double(1)
RANDU <- function() {
    seed <<- ((2^16 + 3) * seed) \%\% (2^31)
    seed/(2^31)
}
for(i in 1:400) {
    U <- c(RANDU(), RANDU(), RANDU(), RANDU(), RANDU())
    print(round(U[1:3], 6))
}}
}
\keyword{datasets}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/datasets/man/randu.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{randu}
%\docType{data}
%\alias{randu}
%\title{Random Numbers from Congruential Generator RANDU}
%\description{
%  400 triples of successive random numbers were taken from the VAX
%  FORTRAN function RANDU running under VMS 1.5.
%}
%\usage{randu}
%\details{
%  In three dimensional displays it is evident that the triples fall on
%  15 parallel planes in 3-space. This can be shown theoretically to be
%  true for all triples from the RANDU generator.
%
%  These particular 400 triples start 5 apart in the sequence, that is
%  they are ((U[5i+1], U[5i+2], U[5i+3]), i= 0, \dots, 399), and they
%  are rounded to 6 decimal places.
%
%  Under VMS versions 2.0 and higher, this problem has been fixed.
%}
%\format{
%  A data frame with 400 observations on 3 variables named \code{x},
%  \code{y} and \code{z} which give the first, second and third random
%  number in the triple.
%}
%\source{
%  David Donoho
%}
%\examples{
%\donttest{## We could re-generate the dataset by the following R code
%seed <- as.double(1)
%RANDU <- function() {
%    seed <<- ((2^16 + 3) * seed) \%\% (2^31)
%    seed/(2^31)
%}
%for(i in 1:400) {
%    U <- c(RANDU(), RANDU(), RANDU(), RANDU(), RANDU())
%    print(round(U[1:3], 6))
%}}
%}
%\keyword{datasets}
%
%\encoding{UTF8}
%