% File src/library/datasets/man/swiss.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{swiss}
\docType{data}
\title{スイスのswiss}
\alias{swiss}
%%\title{Swiss Fertility and Socioeconomic Indicators (1888) Data}
\description{
  18988年頃のスイスの仏語を話す47の州の各々に対する
  標準化出生度と社会経済的指標．
}
\usage{swiss}
\format{
  各々がパーセント単位，つまり \eqn{[0, 100]} 中，の6変数に対する
  47観測値のデータフレーム．

  \tabular{rll}{
    [,1] \tab Fertility \tab \eqn{I_g}{Ig}, \sQuote{通常の標準化された出生度}\cr
    [,2] \tab Agriculture\tab 農業従事男性の \%\cr
    [,3] \tab Examination\tab 軍隊試験で最高得点を得た被徴兵者の \%\cr
    [,4] \tab Education \tab 被徴兵者の小学校を超える教育．\cr
    [,5] \tab Catholic \tab \sQuote{カソリック} 信者の \% (\sQuote{プロテスタント}に対する)．\cr
    [,6] \tab Infant.Mortality\tab 寿命1年未満の出生者．
  }

  All variables but
  \sQuote{Fertility} を除く全ての変数は人口比を与える．
}
\details{
  (Mosteller and Tukey の解説)：

  1888年のスイスは
  \emph{民生的変換}として知られる時期に入った；つまりその出生度が
  低開発国の高水準から低下し始めた．

  データは1888年頃の47の仏語を話す\dQuote{州}に対して収集された．

  ここで全ての変数は \eqn{[0, 100]} にスケール化されているが，
  オリジナルでは
  \code{"Catholic"} を除く全てが \eqn{[0, 1]} にスケール化されていた．
}
\source{
  以下のプロジェクト \dQuote{16P5}, pages 549--551 

  Mosteller, F. and Tukey, J. W. (1977)
  \emph{Data Analysis and Regression: A Second Course in Statistics}.
  Addison-Wesley, Reading Mass.

  それらの出典は次のように述べられている
  \dQuote{データは
  Franice van de Walle. Office of
  Population Research, Princeton University, 1976 の許可で用いられた．
  未刊行のデータは
  NICHD contract number No 1-HD-O-2077 の下で集められた．}
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\note{
  1888年とその他の年の182全ての地域に対するファイルは
  次から入手出来る
  \url{https://opr.princeton.edu/archive/pefp/switz.aspx}．

  それらは変数 \code{Examination} と \code{Education}
  は1887年，1888年そして1889年に対して平均されていると述べている．
}
\examples{
require(stats); require(graphics)
pairs(swiss, panel = panel.smooth, main = "swiss data",
      col = 3 + (swiss$Catholic > 50))
summary(lm(Fertility ~ . , data = swiss))
}
\keyword{datasets}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/datasets/man/swiss.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{swiss}
%\docType{data}
%\alias{swiss}
%\title{Swiss Fertility and Socioeconomic Indicators (1888) Data}
%\description{
%  Standardized fertility measure and socio-economic indicators for each
%  of 47 French-speaking provinces of Switzerland at about 1888.
%}
%\usage{swiss}
%\format{
%  A data frame with 47 observations on 6 variables, \emph{each} of which
%  is in percent, i.e., in \eqn{[0, 100]}.
%
%  \tabular{rll}{
%    [,1] \tab Fertility \tab \eqn{I_g}{Ig}, \sQuote{common standardized
%    fertility measure}\cr
%    [,2] \tab Agriculture\tab \% of males involved in agriculture
%    as occupation\cr
%    [,3] \tab Examination\tab \% draftees receiving highest mark
%    on army examination\cr
%    [,4] \tab Education \tab \% education beyond primary school for draftees.\cr
%    [,5] \tab Catholic \tab \% \sQuote{catholic} (as opposed to \sQuote{protestant}).\cr
%    [,6] \tab Infant.Mortality\tab live births who live less than 1
%    year.
%  }
%
%  All variables but \sQuote{Fertility} give proportions of the
%  population.
%}
%\details{
%  (paraphrasing Mosteller and Tukey):
%
%  Switzerland, in 1888, was entering a period known as the
%  \emph{demographic transition}; i.e., its fertility was beginning to
%  fall from the high level typical of underdeveloped countries.
%
%  The data collected are for 47 French-speaking \dQuote{provinces} at
%  about 1888.
%
%  Here, all variables are scaled to \eqn{[0, 100]}, where in the
%  original, all but \code{"Catholic"} were scaled to \eqn{[0, 1]}.
%}
%\source{
%  Project \dQuote{16P5}, pages 549--551 in
%
%  Mosteller, F. and Tukey, J. W. (1977)
%  \emph{Data Analysis and Regression: A Second Course in Statistics}.
%  Addison-Wesley, Reading Mass.
%
%  indicating their source as
%  \dQuote{Data used by permission of Franice van de Walle. Office of
%  Population Research, Princeton University, 1976.  Unpublished data
%  assembled under NICHD contract number No 1-HD-O-2077.}
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\note{
%  Files for all 182 districts in 1888 and other years have been available at
%  \url{https://opr.princeton.edu/archive/pefp/switz.aspx}.
%
%  They state that variables \code{Examination} and \code{Education}
%  are averages for 1887, 1888 and 1889.
%}
%\examples{
%require(stats); require(graphics)
%pairs(swiss, panel = panel.smooth, main = "swiss data",
%      col = 3 + (swiss$Catholic > 50))
%summary(lm(Fertility ~ . , data = swiss))
%}
%\keyword{datasets}
%
%\encoding{UTF8}
%