% File src/library/grDevices/man/Type1Font.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{Type1Font}
\alias{Type1Font}
\title{Type1 のフォント}
\alias{CIDFont}
\concept{fonts}
\concept{encoding}
%%\title{Type 1 and CID Fonts}
\description{
  これらの関数は
  \R のグラフィックスフォントファミリの名前を
  Type 1 又は CID フォント記述への翻訳を定義するのに使われ，
  \code{\link{postscript}} と \code{\link{pdf}} グラフィックスデバイスの
  双方で使われる．
}
\usage{
Type1Font(family, metrics, encoding = "default")

CIDFont(family, cmap, cmapEncoding, pdfresource = "")
}
\arguments{
  \item{family}{
    Type 1 又は CID-keyed フォントファミリに対して内部的に
    使われる名前を与える文字列．
    これは各ファミリを一意的に特定する必要があり，
    従って使用中のファミリを修正すると
    (\code{\link{postscriptFonts}} を見よ)ファミリ名を変更する必要がある．}
  \item{metrics}{
    フォントの afm (Adobe Font Metric) ファイルへのパスを与える四つか
    五つの文字列ベクトル．}
  \item{cmap}{
    CID-keyed フォントに対する CMap ファイルの名前．}
  \item{encoding}{
    \code{Type1Font} に対しては，エンコーディングファイルの名前．
    既定は \code{"default"} で，これは Unix 風システムでは
    \code{"ISOLatin1.enc"} に，そして Windows では
    \code{"WinAnsi.enc"} になる．
    さもなければ，
    \pkg{grDevices} パッケージの \file{enc} ディレクトリ中の
    ファイル名で，これはもしパスがパス分離記号を含まなければ
    使われる．拡張子 \code{".enc"} は省略できる．}
  \item{cmapEncoding}{
    名前付きの CMap ファイルと共に使われる文字エンコーディングの名前：
    文字列はファイルに書き込まれるときにこのエンコーディングに翻訳される．}
  \item{pdfresource}{
    PDF コードの塊；
    CID-keyed フォントを \code{pdf} に対して使う時だけ必要になる；
    ユーザがこれを提供することは期待されていない．}
}
\details{
  \code{Type1Fonts} に対しては，もし四つの \file{.afm} ファイルが提供されると
  五番目は \code{"Symbol.afm"} とされる．相対パスは
  ディレクトリ \file{\var{\link{R_HOME}}/library/grDevices/afm} に
  関して相対的とされる．.
  五番目の(シンボルフォントは \code{AdobeSym} エンコーディングで
  無ければならない．
  しかしながら最初の四つのフォント中のグリフは
  名前で参照され，\file{.afm} ファイル内部で与えられたエンコーディングは使われない．

  \file{.afm} は最後の拡張子
  \file{.gz} を持つ(又は無し)圧縮ファイルかもしれない：
  \R とともに出荷されるファイルはこの拡張子を持つ圧縮ファイルとして
  インストールされる．

  CID-keyed フォント中のグリフは
  ID (番号)でアクセスされ名前ではない．
  CMap ファイルはエンコードされた文字列(普通 MBCS で)を ID に
  マップし，従って
  \code{cmap} と \code{cmapEncoding} 指定は一致しなければならない．
  CID フォントには真のボールドやイタリックバージョンは無く
  (ボールド/イタリックは伝統的な東アジアの書体では滅多に使われない)，
  そして
  \code{\link{pdf}} デバイスに対しては四つのフォントフェイスは一致する．
  しかしながら，\code{\link{postscript}} デバイスに対しては，ボールドと
  イタリック(そしてボールドイタリック)体が模倣される．

  CID-keyed フォントは東アジア言語のグリフに対してだけ使われることを
  意図しており，
  それらは全ての等幅で同じバウンディングボックスを埋めるとして
  扱われる．
  (従って \code{\link{plotmath}} はそうした文字と一緒に使えるが，
  間隔は西洋のグリフほどには制御されない．)
  CID-keyed フォントはラテン・アルファベット等の他の文字も含む：
  東アジアグリフでないものは
  東アジアグリフの幅の半分の等幅と見做される．
  これはしばしば起きるが，比例スペーシング用にデザインされたラテングリフ
  が使われることもある
  (そして奇妙に見える)．
  CID-keyed フォントは東アジアグリフに\bold{だけ}使うことを強く
  勧める．
}
\value{
  A list of class
  クラス \code{"Type1Font"} 又は \code{"CIDFont"} のりスト．
}
\seealso{
  \code{\link{postscript}}, \code{\link{pdf}},
  \code{\link{postscriptFonts}} そして \code{\link{pdfFonts}}．
}
\examples{
## これは "ComputerModernItalic" を二重化する．
CMitalic <- Type1Font("ComputerModern2",
                      c("CM_regular_10.afm", "CM_boldx_10.afm",
                        "cmti10.afm", "cmbxti10.afm",
                        "CM_symbol_10.afm"),
                      encoding = "TeXtext.enc")

\dontrun{
## これは次のようにして使うことが出来る
postscript(family = CMitalic)
## または
postscriptFonts(CMitalic = CMitalic)  # セッション中一回だけ
postscript(family = "CMitalic", encoding = "TeXtext.enc")
}}
\keyword{device}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/Type1Font.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Type1Font}
%\alias{Type1Font}
%\alias{CIDFont}
%\concept{fonts}
%\concept{encoding}
%\title{Type 1 and CID Fonts}
%\description{
%  These functions are used to define the translation of a \R graphics
%  font family name to a Type 1 or CID font descriptions, used by both
%  the \code{\link{postscript}} and \code{\link{pdf}} graphics devices.
%}
%\usage{
%Type1Font(family, metrics, encoding = "default")
%
%CIDFont(family, cmap, cmapEncoding, pdfresource = "")
%}
%\arguments{
%  \item{family}{a character string giving the name to be used internally
%    for a Type 1 or CID-keyed font family.  This needs to uniquely
%    identify each family, so if you modify a family which is in use
%    (see \code{\link{postscriptFonts}}) you need to change the family name.}
%  \item{metrics}{a character vector of four or five strings giving paths
%    to the afm (Adobe Font Metric) files for the font.}
%  \item{cmap}{the name of a CMap file for a CID-keyed font.}
%  \item{encoding}{for \code{Type1Font}, the name of an encoding file.
%    Defaults to \code{"default"}, which maps on Unix-alikes to
%    \code{"ISOLatin1.enc"} and on Windows to \code{"WinAnsi.enc"}.
%    Otherwise, a file name in the \file{enc} directory of the
%    \pkg{grDevices} package, which is used if the path does not contain a
%    path separator.  An extension \code{".enc"} can be omitted.}
%  \item{cmapEncoding}{
%    The name of a character encoding to be used with the named CMap
%    file: strings will be translated to this encoding when written to
%    the file.}
%  \item{pdfresource}{A chunk of PDF code;  only required for using
%    a CID-keyed font on \code{pdf}; users should not be expected to
%    provide this.}
%}
%\details{
%  For \code{Type1Fonts}, if four \file{.afm} files are supplied the
%  fifth is taken to be \code{"Symbol.afm"}.  Relative paths are taken
%  relative to the directory \file{\var{\link{R_HOME}}/library/grDevices/afm}.
%  The fifth (symbol) font must be in \code{AdobeSym} encoding.
%  However, the glyphs in the first four fonts are referenced by name
%  and any encoding given within the \file{.afm} files is not used.
%
%  The \file{.afm} files may be compressed with (or without) final
%  extension \file{.gz}: the files which ship with \R are installed as
%  compressed files with this extension.
%
%  Glyphs in CID-keyed fonts are accessed by ID (number) and not by name.
%  The CMap file maps encoded strings (usually in a MBCS) to IDs, so
%  \code{cmap} and \code{cmapEncoding} specifications must match.  There
%  are no real bold or italic versions of CID fonts (bold/italic were
%  very rarely used in traditional East Asian topography), and for the
%  \code{\link{pdf}} device all four font faces will be identical.
%  However, for the \code{\link{postscript}} device, bold and italic (and
%  bold italic) are emulated.
%
%  CID-keyed fonts are intended only for use for the glyphs of East Asian
%  languages, which are all monospaced and are all treated as filling the
%  same bounding box.  (Thus \code{\link{plotmath}} will work with such
%  characters, but the spacing will be less carefully controlled than
%  with Western glyphs.)  The CID-keyed fonts do contain other
%  characters, including a Latin alphabet: non-East-Asian glyphs are
%  regarded as monospaced with half the width of East Asian glyphs.  This
%  is often the case, but sometimes Latin glyphs designed for
%  proportional spacing are used (and may look odd).  We strongly
%  recommend that CID-keyed fonts are \bold{only} used for East Asian
%  glyphs.
%}
%\value{
%  A list of class \code{"Type1Font"} or \code{"CIDFont"}.
%}
%\seealso{
%  \code{\link{postscript}}, \code{\link{pdf}},
%  \code{\link{postscriptFonts}}, and \code{\link{pdfFonts}}.
%}
%\examples{
%## This duplicates "ComputerModernItalic".
%CMitalic <- Type1Font("ComputerModern2",
%                      c("CM_regular_10.afm", "CM_boldx_10.afm",
%                        "cmti10.afm", "cmbxti10.afm",
%                        "CM_symbol_10.afm"),
%                      encoding = "TeXtext.enc")
%
%\dontrun{
%## This could be used by
%postscript(family = CMitalic)
%## or
%postscriptFonts(CMitalic = CMitalic)  # once in a session
%postscript(family = "CMitalic", encoding = "TeXtext.enc")
%}}
%\keyword{device}
%
%\encoding{UTF-8}
%