% File src/library/grDevices/man/cairo.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{cairo}
\alias{svg}
\title{カイロデバイス}
\alias{cairo_pdf}
\alias{cairo_ps}
%%\title{Cairographics-based SVG, PDF and PostScript Graphics Devices}
\description{
  cairo グラフィックス API を用いた SVG, PDF そして PostScript グラフィックスファイル
  に対するグラフィックスデバイス．
}
\usage{
svg(filename = if(onefile) "Rplots.svg" else "Rplot\%03d.svg",
    width = 7, height = 7, pointsize = 12,
    onefile = FALSE, family = "sans", bg = "white",
    antialias = c("default", "none", "gray", "subpixel"))

cairo_pdf(filename = if(onefile) "Rplots.pdf" else "Rplot\%03d.pdf",
          width = 7, height = 7, pointsize = 12,
          onefile = FALSE, family = "sans", bg = "white",
          antialias = c("default", "none", "gray", "subpixel"),
          fallback_resolution = 300)

cairo_ps(filename = if(onefile) "Rplots.ps" else "Rplot\%03d.ps",
         width = 7, height = 7, pointsize = 12,
         onefile = FALSE, family = "sans", bg = "white",
         antialias = c("default", "none", "gray", "subpixel"),
         fallback_resolution = 300)
}
\arguments{
  \item{filename}{出力ファイルの名前．
    既定であるように，もし C 整数書式が文字列に含まれれば
    ページ番号が含められる．
    (結果は
    \code{PATH_MAX} 文字長以下でなければならず，もしそうでなければ
    切り詰められるかもしれない．
    詳細は \code{\link{postscript}} を見よ．)
    プラットフォームがサポートすればチルダ展開が行われる．}
  \item{width}{インチ単位のデバイスの幅．}
  \item{height}{インチ単位のデバイスの高さ．}
  \item{pointsize}{プロット文字の既定ポイントサイズ(ビッグポイント単位)．}
  \item{onefile}{全てのプロットは一つのファイルに現れるべきか，それとも
    別のファイルにか?}
  \item{family}{デバイス依存でないフォントファミリの一つ，
    \code{"sans"}, \code{"serif"} そして \code{"mono"}，又は
    システムに依存しない仕方で探されるフォントファミリを指定する文字列．

%#ifdef unix
    (Unix の場合)\sspace{}
    \code{\link{X11}} に対するヘルプの\sQuote{Cairo フォント}節を見よ．
%#endif
  }
  \item{bg}{初期背景色：
    par("bg") の設定で上書きできる．}
  \item{antialias}{文字列，使われる(もしあれば)アンチエイリアシングのタイプ；
    既定では \code{"default"}．}
  \item{fallback_resolution}{数値：ビットマップ出力に切り替わる際の
    dpi 単位の解像度．\R 3.3.0 以前ではこれは
    cairo の実装に依存したが普通 300 だった．}
}
\details{
  SVG (Scalar Vector Graphics) はベクターグラフィックスに対する W3C 標準である．
  \url{http://www.w3.org/Graphics/SVG/} を見よ．\code{svg} からの出力は
  \code{onefile = FALSE} (既定)に対しては SVG バージョン 1.1 で，
  さもなければ SVG 1.2 である．
  (複数ページ SVG を表示できる SVG ビューアーは殆ど無い．)

  \code{\link{postscript}} や \code{\link{pdf}} とは異なり，
  \code{cairo_pdf} と \code{cairo_ps} はある場合にはベクトル
  グラフィックスではなく\emph{ビットマップ}を記録する．
  他方で(適当なプラットフォームで上では)それらは
  広範囲の UTF-8 グリフを含むことが出来，使われるフォントを
  埋め込むことが出来る．

  \code{cairo_ps(onefile = FALSE)} が生み出す出力は
  cairo >= 1.6 を持つプラットフォームでは
  encapsulated ポストスクリプトである．
  
  \R はこれらのデバイスに対するサポートどれも無しでコンパイル出来る：
  サポートされていないシステム上でこれらを使おうと試みると
  報告が出る．
  これらは全て cairo バージョン 1.2 (2006年から)又はそれ以降を必要とする．

  これらのデバイスのどれかで一ページ以上をプロットしようとし，
  \code{file} 中に \code{\%d} のような系列番号を含め
  なければ(又は \code{onefile = TRUE} を設定すると)
  ファイルは最後のプロットを含む．

  半透明に対する完全なサポートがあるが，
  これを使うのはビットマップ出力を惹き起こしやすい事柄の一つである
  (そして \code{cairo_ps} に対しては常にそうなる)．
}

\note{
  Cairo 1.2.4 (Centos/RHEL 5 中で見られる)は不正な
  SVG 出力を与えることが知られている．
  
  原則としてこれらのデバイスは
  X11 と独立(Windows で使われていることから分かるように)である．
  しかし Unix 風システムでは cairo ライブラリは
  X11 システムの一部として配布されているかもしれず(OS X や
  XQuartz 上)それをインストールする必要があるかもしれない．
}

\value{
  プロットデバイスが開かれる：
  \R インタプリタには何も返されない．
}


\seealso{
  \code{\link{Devices}}, \code{\link{dev.print}}, \code{\link{pdf}},
  \code{\link{postscript}}

  cairo がサポートされているかどうかを知るには \code{\link{capabilities}}．
}

\section{アンチエイリアシング}{アンチエイリアシング
  はグラフィックスとフォントの双方に適用される．
  これは一般に線とテキストに対しては好ましいが，
  塗りつぶし，
  例えば \code{\link{image}} プロット，に対しては好ましくない効果を生むかもしれないので
  塗りつぶしには決して使われない．

  \code{antialias = "default"} は原則としてプラットフォームで依存であるが，
  最もしばしば \code{antialias = "gray"} に等しいように見える．
}

\section{慣例}{
  この節は
  \dQuote{R Internals Manual} で設定されているグラフィックスデバイスに
  対する慣例の移植を説明している．

  \itemize{
    \item ピクセル(\code{svg})又はインチ単位の既定デバイスサイズ．
    \item 大きな点に対するフォントサイズ．
    \item 既定のフォントファミリは Helvetica．
    \item 線幅は 1/96 インチの倍数．
    \item 円の最少半径は 1/72 インチ．
    \item 色はそれを眺めるアプリケーションにより解釈される．
  }
}

\keyword{device}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/cairo.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cairo}
%\alias{svg}
%\alias{cairo_pdf}
%\alias{cairo_ps}
%\title{Cairographics-based SVG, PDF and PostScript Graphics Devices}
%\description{
%  Graphics devices for SVG, PDF and PostScript graphics files using
%  the cairo graphics API.
%}
%\usage{
%svg(filename = if(onefile) "Rplots.svg" else "Rplot\%03d.svg",
%    width = 7, height = 7, pointsize = 12,
%    onefile = FALSE, family = "sans", bg = "white",
%    antialias = c("default", "none", "gray", "subpixel"))
%
%cairo_pdf(filename = if(onefile) "Rplots.pdf" else "Rplot\%03d.pdf",
%          width = 7, height = 7, pointsize = 12,
%          onefile = FALSE, family = "sans", bg = "white",
%          antialias = c("default", "none", "gray", "subpixel"),
%          fallback_resolution = 300)
%
%cairo_ps(filename = if(onefile) "Rplots.ps" else "Rplot\%03d.ps",
%         width = 7, height = 7, pointsize = 12,
%         onefile = FALSE, family = "sans", bg = "white",
%         antialias = c("default", "none", "gray", "subpixel"),
%         fallback_resolution = 300)
%}
%\arguments{
%  \item{filename}{the name of the output file.
%    The page number is substituted if a C integer format is included in
%    the character string, as in the default.  (The result must be less
%    than \code{PATH_MAX} characters long, and may be truncated if not.
%    See \code{\link{postscript}} for further details.)  Tilde expansion
%    is performed where supported by the platform.}
%  \item{width}{the width of the device in inches.}
%  \item{height}{the height of the device in inches.}
%  \item{pointsize}{the default pointsize of plotted text (in big points).}
%  \item{onefile}{should all plots appear in one file or in separate files?}
%  \item{family}{one of the device-independent font families,
%    \code{"sans"}, \code{"serif"} and \code{"mono"}, or a character
%    string specify a font family to be searched for in a
%    system-dependent way.
%#ifdef unix
%    See, the \sQuote{Cairo fonts} section in the help for \code{\link{X11}}.
%#endif
%  }
%  \item{bg}{the initial background colour: can be overridden by setting
%    par("bg").}
%  \item{antialias}{string, the type of anti-aliasing (if any) to be used;
%    defaults to \code{"default"}.}
%  \item{fallback_resolution}{numeric: the resolution in dpi used when
%    falling back to bitmap output.  Prior to \R 3.3.0 this depended on
%    the cairo implementation but was commonly 300.}
%}
%\details{
%  SVG (Scalar Vector Graphics) is a W3C standard for vector graphics.
%  See \url{http://www.w3.org/Graphics/SVG/}.  The output from \code{svg}
%  is SVG version 1.1 for \code{onefile = FALSE} (the default), otherwise
%  SVG 1.2.  (Few SVG viewers are capable of displaying multi-page SVG
%  files.)
%
%  Note that unlike \code{\link{postscript}} and \code{\link{pdf}},
%  \code{cairo_pdf} and \code{cairo_ps} sometimes record \emph{bitmaps}
%  and not vector graphics.  On the other hand, they can
%  (on suitable platforms) include a much wider range of UTF-8 glyphs,
%  and embed the fonts used.
%
%  The output produced by \code{cairo_ps(onefile = FALSE)} will be
%  encapsulated postscript on a platform with cairo >= 1.6.
%
%  \R can be compiled without support for any of these devices: this will
%  be reported if you attempt to use them on a system where they are not
%  supported.  They all require cairo version 1.2 (from 2006) or later.
%
%  If you plot more than one page on one of these devices and do not
%  include something like \code{\%d} for the sequence number in
%  \code{file} (or set \code{onefile = TRUE}) the file will contain the
%  last page plotted.
%
%  There is full support of semi-transparency, but using this is one of
%  the things liable to trigger bitmap output (and will always do so for
%  \code{cairo_ps}).
%}
%
%\note{
%  Cairo 1.2.4 (seen in Centos/RHEL 5) is known to give incorrect SVG output.
%  
%  In principle these devices are independent of X11 (as is seen by their
%  presence on Windows).  But on a Unix-alike the cairo libraries may be
%  distributed as part of the X11 system and hence that (on OS X,
%  XQuartz) may need to be installed.
%}
%
%\value{
%  A plot device is opened: nothing is returned to the \R interpreter.
%}
%
%
%\seealso{
%  \code{\link{Devices}}, \code{\link{dev.print}}, \code{\link{pdf}},
%  \code{\link{postscript}}
%
%  \code{\link{capabilities}} to see if cairo is supported.
%}
%
%\section{Anti-aliasing}{
%  Anti-aliasing is applied to both graphics and fonts.  It is generally
%  preferable for lines and text, but can lead to undesirable effects for
%  fills, e.g.\sspace{}for \code{\link{image}} plots, and so is never used for
%  fills.
%
%  \code{antialias = "default"} is in principle platform-dependent, but
%  seems most often equivalent to \code{antialias = "gray"}.
%}
%
%\section{Conventions}{
%  This section describes the implementation of the conventions for
%  graphics devices set out in the \dQuote{R Internals Manual}.
%
%  \itemize{
%    \item The default device size is in pixels (\code{svg}) or inches.
%    \item Font sizes are in big points.
%    \item The default font family is Helvetica.
%    \item Line widths are multiples of 1/96 inch.
%    \item Circle radii have a minimum of 1/72 inch.
%    \item Colours are interpreted by the viewing application.
%  }
%}
%
%\keyword{device}
%
%\encoding{UTF-8}
%