% File src/library/grDevices/man/hsv.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{hsv}
\title{色調，彩度，値(HSV)による色指定}
\alias{hsv}
%%\title{HSV Color Specification}
\description{
  色調，彩度，そして値を指定するベクトルから色のベクトルを作る．
}
\usage{
hsv(h = 1, s = 1, v = 1, alpha)
}
\arguments{
  \item{h,s,v}{
    \sQuote{色調}に対しては範囲 \code{[0, 1]}，
    \sQuote{彩度} そして色ベクトルを作るために結合される\sQuote{値}の
    数値ベクトル．短い引数中の値はリサイクルされる．}
  \item{alpha}{
    アルファ透明度チャンネルに対する範囲 \code{[0, 1]} 中の値の
    ベクトル(0 は透明で 1 は不透明を表す)．}
}
\details{
  半透明色(\code{0 < alpha < 1}) はある種のデバイスだけでサポートされる：
  \code{\link{rgb}} を見よ．
}
\value{
  この関数は
  HSV 空間中で与えられた値に体操する色のベクトルを作る．
  \code{hsv} が返す値はグラフィックス関数中の \code{col=} 指定や  
  \code{par} 中で使うことが出来る．
}
\seealso{
  知覚に基づく \code{hsv()} のバージョンに対しては
  \code{\link{hcl}}．
  RGB から HSV への変換は \code{\link{rgb}} と \code{\link{rgb2hsv}}，
  \code{\link{rainbow}},
  \code{\link{gray}}．
}
\examples{
require(graphics)

hsv(.5,.5,.5)

## 赤い色調：
n <- 20;  y <- -sin(3*pi*((1:n)-1/2)/n)
op <- par(mar = rep(1.5, 4))
plot(y, axes = FALSE, frame.plot = TRUE,
     xlab = "", ylab = "", pch = 21, cex = 30,
     bg = rainbow(n, start = .85, end = .1),
     main = "Red tones")
par(op)
}
\keyword{color}
\keyword{dplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/hsv.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{hsv}
%\alias{hsv}
%\title{HSV Color Specification}
%\description{
%  Create a vector of colors from vectors specifying hue, saturation and
%  value.
%}
%\usage{
%hsv(h = 1, s = 1, v = 1, alpha)
%}
%\arguments{
%  \item{h,s,v}{numeric vectors of values in the range \code{[0, 1]} for
%    \sQuote{hue}, \sQuote{saturation} and \sQuote{value} to be combined
%    to form a vector of colors.  Values in shorter arguments are
%    recycled.}
%  \item{alpha}{numeric vector of values in the range \code{[0, 1]} for
%    alpha transparency channel (0 means transparent and 1 means opaque).}
%}
%\details{
%  Semi-transparent colors (\code{0 < alpha < 1}) are supported only on
%  some devices: see \code{\link{rgb}}.
%}
%\value{
%  This function creates a vector of colors corresponding to the
%  given values in HSV space.  The values returned by \code{hsv} can be
%  used with a \code{col=} specification in graphics functions or in
%  \code{par}.
%}
%\seealso{
%  \code{\link{hcl}} for a perceptually based version of \code{hsv()},
%  \code{\link{rgb}} and \code{\link{rgb2hsv}} for RGB to HSV conversion;
%  \code{\link{rainbow}},
%  \code{\link{gray}}.
%}
%\examples{
%require(graphics)
%
%hsv(.5,.5,.5)
%
%## Red tones:
%n <- 20;  y <- -sin(3*pi*((1:n)-1/2)/n)
%op <- par(mar = rep(1.5, 4))
%plot(y, axes = FALSE, frame.plot = TRUE,
%     xlab = "", ylab = "", pch = 21, cex = 30,
%     bg = rainbow(n, start = .85, end = .1),
%     main = "Red tones")
%par(op)
%}
%\keyword{color}
%\keyword{dplot}
%
%\encoding{UTF-8}
%