% File src/library/grDevices/man/n2mfrow.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{n2mfrow}
\title{プロット数から mfrow を計算}
\alias{n2mfrow}
%%\title{Compute Default mfrow From Number of Plots}
\description{
  一頁に複数の図(矩形のレイアウト)を簡単にセットアップする．
  これは \code{\link{par}(mfrow)} に対する賢明な既定値を計算する．
}
\usage{
n2mfrow(nr.plots)
}
\arguments{
  \item{nr.plots}{整数；描きたいプロット図の数．}
}
\value{
  長さが 2 の整数ベクトル \code{nr, nc} で，
  \code{nr >= nc >= 1} と \code{nr * nc >= nr.plots}
  を満たす行数と列数を与える．
}
\author{Martin Maechler}
\seealso{\code{\link{par}}, \code{\link{layout}}.}
\examples{
require(graphics)

n2mfrow(8) # 3 x 3

n <- 5 ; x <- seq(-2, 2, len = 51)
## ここで 'n' が未知とする{関数内部で}
op <- par(mfrow = n2mfrow(n))
for (j in 1:n)
   plot(x, x^j, main = substitute(x^ exp, list(exp = j)), type = "l",
   col = "blue")

sapply(1:10, n2mfrow)
}
\keyword{dplot}
\keyword{utilities}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/n2mfrow.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{n2mfrow}
%\alias{n2mfrow}
%\title{Compute Default mfrow From Number of Plots}
%\description{
%  Easy setup for plotting multiple figures (in a rectangular layout) on
%  one page.  This computes a sensible default for
%  \code{\link{par}(mfrow)}.
%}
%\usage{
%n2mfrow(nr.plots)
%}
%\arguments{
%  \item{nr.plots}{integer; the number of plot figures you'll want to draw.}
%}
%\value{
%  A length two integer vector \code{nr, nc} giving the number of rows
%  and columns, fulfilling \code{nr >= nc >= 1} and \code{nr * nc >= nr.plots}.
%}
%\author{Martin Maechler}
%\seealso{\code{\link{par}}, \code{\link{layout}}.}
%\examples{
%require(graphics)
%
%n2mfrow(8) # 3 x 3
%
%n <- 5 ; x <- seq(-2, 2, len = 51)
%## suppose now that 'n' is not known {inside function}
%op <- par(mfrow = n2mfrow(n))
%for (j in 1:n)
%   plot(x, x^j, main = substitute(x^ exp, list(exp = j)), type = "l",
%   col = "blue")
%
%sapply(1:10, n2mfrow)
%}
%\keyword{dplot}
%\keyword{utilities}
%
%\encoding{UTF-8}
%