% File src/library/grDevices/man/postscriptFonts.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{postscriptFonts}
\title{ポストスクリプトのフォント}
\alias{postscriptFonts}
\alias{pdfFonts}
\concept{fonts}
\concept{encoding}
%%\title{PostScript and PDF Font Families}
\description{
  これらの関数は
  \R のグラフィックスフォントファミリの名前の
  ポストスクリプトまたは PDF のフォント記述への翻訳を処理し，
  \code{\link{postscript}} 又は \code{\link{pdf}} グラフィックスデバイス
  により使われる．
}
\usage{
postscriptFonts(\dots)
pdfFonts(\dots)
}
\arguments{
  \item{\dots}{表示するマッピングを命名する文字列か，
    加えるか変更するマッピングを指定する名前付き引数．}
}
\details{
  もしこれらの関数が引数無しで呼ばれると既存のマッピングをリストし，
  他方で名前付きの引数で呼び出されるとマッピングを追加(又は変更)する．

  ポストスクリプト又は PDF デバイスは既定のフォントファミリで
  作られるが
  (\code{\link{postscript}} に対するドキュメントを見よ)，
  デバイスで描画する際にフォントファミリを指定することも可能である
  (例えば，\code{\link{par}} 中の
  \code{"family"} 対するドキュメントと
  \pkg{grid} パッケージ中の \code{\link{gpar}} 中の
  \code{"fontfamily"} に対するドキュメントを見よ)．

  デバイスに送られるフォントファミリは単純な文字列で，これは
  ポストスクリプトフォントのセットにマップされなければならない．
  \code{postscript} と \code{pdf} デバイスに対するマッピングの別個のリスト
  が現在の \R セッション用に保持されておりユーザにより付け加えることが出来る．

  \code{postscriptFonts} と \code{pdfFonts} 関数は
  既存のマッピングをリストしたり新しいマッピングを定義するのに使うことが出来る．
  \code{xxxFonts} 関数がそれらをデータベースに加えるのに使われる時，
  \code{\link{Type1Font}} と \code{\link{CIDFont}} 関数は
  新しいマッピングを定義するのに使うことが出来る．

  三つのデバイス独立のファミリ名に対して既定のマッピングが提供されている：
  sans-serif フォントに対して \code{"sans"} (\code{"Helvetica"} 用)，
  serif フォントに対して \code{"serif"} (\code{"Times"} 用) そして
  monospaced フォントに対して \code{"mono"}
  (\code{"Courier"} 用)．

  幾つかの標準の Adobe フォント(そして URW の同値物)に対する
  マッピングがまた提供されている：
  \code{"AvantGarde"},
  \code{"Bookman"}, \code{"Courier"}, \code{"Helvetica"},
  \code{"Helvetica-Narrow"}, \code{"NewCenturySchoolbook"},
  \code{"Palatino"} そして \code{"Times"}；
  \code{"URWGothic"}, \code{"URWBookman"}, \code{"NimbusMon"},
  \code{"NimbusSan"} (\code{"URWHelvetica"} の同義語),
  \code{"NimbusSanCond"}, \code{"CenturySch"}, \code{"URWPalladio"} そして
  \code{"NimbusRom"} (\code{"URWTimes"} の同義語)．

  更に
  \code{"ComputerModern"},
  \code{"ComputerModernItalic"} そして，\R 3.1.0 以来，\code{"ArialMT"}
  (Monotype Arial)に対するマッピングがある．

  最後に，別の節で説明される東アジアロケール用の
  既定マッピングが幾つかある．

  フォントメトリックとエンコーディングの指定は
  \code{\link{postscript}} 関数のヘルプ中に説明されている．

  フォントは結果の
  ポストスクリプトや PDF ファイル中に埋め込まれないので，
  ポストスクリプトや PDF プロットファイルを含むソフトウェアは
  フォントのアウトラインを埋め込むべきである
  (普通 \file{.pfb} か \file{.pfa} ファイルから)．
  又はプリンターのスプーラ―に指示する
  DSC コメントかそれを行うアプリケーションを含める
  (\code{\link{embedFonts}} も見よ)．

  フォントファミリは
  \code{postscriptFonts} が呼び出された時に使われる引数名である \R レベルの名前と，
  \code{family} 成分である内部名の両方を持つ．
  これら二つの名前は全ての予め定義されているフォントファミリに
  対して同じである．

  フォントファミリが一旦使われるとそれは変更できない．
  \sQuote{使用中}とは既に \R セッション中にあるのと同じグラフィックスデバイス
  の起動に
  \code{family} 又は \code{fonts} 引数を使って指定されたことを意味する．
  (これらの目的のためには \code{xfig} は
  \code{postscript} と同様であるが
  が予め定義されたマッピングの幾つかだけを使用する．)
}
\section{東アジアのフォント}{
  東アジアロケールに対する幾つかの既定マッピングがある：\cr
  日本語に対しては \code{"Japan1"}, \code{"Japan1HeiMin"}, \code{"Japan1GothicBBB"},
  と \code{"Japan1Ryumin"}；
  韓国語に対しては \code{"Korea1"} と \code{"Korea1deb"}；
  中国本土とシンガポールに対する(簡体中国語) \code{"GB1"}；
  香港と台湾に対する(繁体中国語) \code{"CNS1"}．

  これらは以下のフォントを参照する
  \tabular{ll}{
    Japan1 (PS) \tab \code{HeiseiKakuGo-W5}\cr \tab ライノタイプ用日本語プリンターフォント\cr
    Japan1 (PDF) \tab \code{KozMinPro-Regular-Acro}\cr \tab Adobe Reader 7.0 からのフォントパック\cr
    Japan1HeiMin (PS) \tab \code{HeiseiMin-W3}\cr \tab ライノタイプ用日本語プリンターフォント\cr
    Japan1HeiMin (PDF) \tab \code{HeiseiMin-W3-Acro}\cr \tab Adobe Reader 7.0 からの日本語フォントパック\cr
    Japan1GothicBBB \tab \code{GothicBBB-Medium}\cr \tab 日本の商用ポストスクリプトプリンターフォント\cr
    Japan1Ryumin \tab \code{Ryumin-Light}\cr \tab 日本の商用ポストスクリプトプリンターフォント\cr
    Korea1 (PS) \tab \code{Baekmuk-Batang}\cr  \tab ある種の Linux で見られる TrueType フォント\cr
    Korea1 (PDF) \tab \code{HYSMyeongJoStd-Medium-Acro}\cr  \tab Adobe Reader 7.0 からの韓国語フォントパック\cr
    Korea1deb (PS) \tab \code{Batang-Regular}\cr  \tab Baekmuk-Batang の別名\cr
    Korea1deb (PDF) \tab \code{HYGothic-Medium-Acro}\cr  \tab Adobe Reader 4.0 からの韓国語フォント\cr
    GB1 (PS) \tab \code{BousungEG-Light-GB}\cr  \tab ある種の Linux で見られる TrueType フォント\cr
    GB1 (PDF) \tab \code{STSong-Light-Acro}\cr  \tab Adobe Reader 7.0 からの簡体中国語フォントパック\cr
    CNS1 (PS) \tab \code{MOESung-Regular}\cr \tab Ken Lunde の CJKV リソース\cr
    CNS1 (PDF) \tab \code{MSungStd-Light-Acro}\cr  \tab Adobe Reader 7.0 からの繁体中国語フォントパック\cr
  }
%  \code{Baekmuk-Batang} Can be found at \url{ftp://ftp.mizi.com/pub/baekmuk/}.
  \code{BousungEG-Light-GB} は
  \url{ftp://ftp.gnu.org/pub/non-gnu/chinese-fonts-truetype/} にある．
  Ken Lunde の CJKV リソースは次にある
  \url{ftp://ftp.oreilly.com/pub/examples/nutshell/cjkv/adobe/samples/}．
  これらはインストールされる必要がある，又はさもなければ
  ghostscript のようなポストスクリプト/PDF インタプリタ―がそれらを利用できなければならない
  (そしてあらゆるインタプリタが
  TrueType フォントを処理できるわけではない)．

  自分のポストスクリプト/PDF インタプリタがこれらの多くのフォントに対する
  別名を提供するように設定されていることを気づくかもしれない．
  例えば，
  Windows 上の ghostscript は
  普通の東アジアのフォント名を TrueType フォントにマップするように
  オプションでインストールできる．
  (同様に
  \code{-Acro} バージョンも付け加えたくなるであろう．)

  CID-keyed フォントに対するマッピングをくわえることは
  熟練者向けである．
}
\value{
  一つ又は複数のフォントマッピングのリスト．
}
\seealso{
  \code{\link{postscript}} と \code{\link{pdf}}；
  新しいフォントマッピングを指定するには \code{\link{Type1Font}}
  と \code{\link{CIDFont}}．
}
\author{
  Computer Modern フォントのサポートは
  Brian D'Urso % formerly \email{durso@hussle.harvard.edu}
  の貢献による．
}
\examples{
postscriptFonts()
## これは "ComputerModernItalic" を重複する．
CMitalic <- Type1Font("ComputerModern2",
                      c("CM_regular_10.afm", "CM_boldx_10.afm",
                        "cmti10.afm", "cmbxti10.afm",
                         "CM_symbol_10.afm"),
                      encoding = "TeXtext.enc")
postscriptFonts(CMitalic = CMitalic)

## 日本語に対する CID フォントは異なった CMap と
## 対応する cmapEncoding を使う．
`Jp_UCS-2` <- CIDFont("TestUCS2",
                  c("Adobe-Japan1-UniJIS-UCS2-H.afm",
                    "Adobe-Japan1-UniJIS-UCS2-H.afm",
                    "Adobe-Japan1-UniJIS-UCS2-H.afm",
                    "Adobe-Japan1-UniJIS-UCS2-H.afm"),
                  "UniJIS-UCS2-H", "UCS-2")
pdfFonts(`Jp_UCS-2` = `Jp_UCS-2`)
names(pdfFonts())
}
\keyword{device}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/postscriptFonts.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{postscriptFonts}
%\alias{postscriptFonts}
%\alias{pdfFonts}
%\concept{fonts}
%\concept{encoding}
%\title{PostScript and PDF Font Families}
%\description{
%  These functions handle the translation of a \R graphics
%  font family name to a PostScript or PDF font description, used by the
%  \code{\link{postscript}} or \code{\link{pdf}} graphics devices.
%}
%\usage{
%postscriptFonts(\dots)
%pdfFonts(\dots)
%}
%\arguments{
%  \item{\dots}{either character strings naming mappings to display,
%    or named arguments specifying mappings to add or change.}
%}
%\details{
%  If these functions are called with no argument they list all the
%  existing mappings, whereas if they are called with named arguments
%  they add (or change) mappings.
%
%  A PostScript or PDF device is created with a default font family (see the
%  documentation for \code{\link{postscript}}), but it is also possible
%  to specify a font family when drawing to the device (for example, see
%  the documentation for \code{"family"} in \code{\link{par}} and for
%  \code{"fontfamily"} in \code{\link{gpar}} in the \pkg{grid} package).
%
%  The font family sent to the device is a simple string name, which must be
%  mapped to a set of PostScript fonts.  Separate lists of mappings for
%  \code{postscript} and \code{pdf} devices are  maintained for the
%  current \R session and can be added to by the user.
%
%  The \code{postscriptFonts} and \code{pdfFonts} functions can be used
%  to list existing mappings and to define new mappings.  The
%  \code{\link{Type1Font}} and \code{\link{CIDFont}} functions can be
%  used to create new mappings, when the \code{xxxFonts} function is used
%  to add them to the database.  See the examples.
%
%  Default mappings are provided for three device-independent family
%  names: \code{"sans"} for a sans-serif font (to \code{"Helvetica"}),
%  \code{"serif"} for a serif font (to \code{"Times"}) and \code{"mono"}
%  for a monospaced font (to \code{"Courier"}).
%
%  Mappings for a number of standard Adobe fonts (and URW equivalents)
%  are also provided: \code{"AvantGarde"},
%  \code{"Bookman"}, \code{"Courier"}, \code{"Helvetica"},
%  \code{"Helvetica-Narrow"}, \code{"NewCenturySchoolbook"},
%  \code{"Palatino"} and \code{"Times"};
%  \code{"URWGothic"}, \code{"URWBookman"}, \code{"NimbusMon"},
%  \code{"NimbusSan"} (synonym \code{"URWHelvetica"}),
%  \code{"NimbusSanCond"}, \code{"CenturySch"}, \code{"URWPalladio"} and
%  \code{"NimbusRom"} (synonym \code{"URWTimes"}).
%
%  There are also mappings for \code{"ComputerModern"},
%  \code{"ComputerModernItalic"} and, as from \R 3.1.0, \code{"ArialMT"}
%  (Monotype Arial).
%
%  Finally, there are some default mappings for East Asian locales
%  described in a separate section.
%
%  The specification of font metrics and encodings is described in the help
%  for the \code{\link{postscript}} function.
%
%  The fonts are not embedded in the resulting PostScript or PDF file, so
%  software including the PostScript or PDF plot file should either embed
%  the font outlines (usually from \file{.pfb} or \file{.pfa} files) or
%  use DSC comments to instruct the print spooler or including
%  application to do so (see also \code{\link{embedFonts}}).
%
%  A font family has both an \R-level name, the argument name used when
%  \code{postscriptFonts} was called, and an internal name, the
%  \code{family} component.  These two names are the same for all the
%  pre-defined font families.
%
%  Once a font family is in use it cannot be changed.  \sQuote{In use}
%  means that it has been specified \emph{via} a \code{family} or
%  \code{fonts} argument to an invocation of the same graphics device
%  already in the \R session.  (For these purposes \code{xfig} counts the
%  same as \code{postscript} but only uses some of the predefined mappings.)
%}
%\section{East Asian fonts}{
%  There are some default mappings for East Asian locales:\cr
%  \code{"Japan1"}, \code{"Japan1HeiMin"}, \code{"Japan1GothicBBB"},
%  and \code{"Japan1Ryumin"} for Japanese;
%  \code{"Korea1"} and \code{"Korea1deb"} for Korean;
%  \code{"GB1"} (Simplified Chinese) for mainland China and Singapore;
%  \code{"CNS1"} (Traditional Chinese) for Hong Kong and Taiwan.
%
%  These refer to the following fonts
%  \tabular{ll}{
%    Japan1 (PS) \tab \code{HeiseiKakuGo-W5}\cr \tab Linotype Japanese printer font\cr
%    Japan1 (PDF) \tab \code{KozMinPro-Regular-Acro}\cr \tab from Adobe Reader 7.0 Japanese Font Pack\cr
%    Japan1HeiMin (PS) \tab \code{HeiseiMin-W3}\cr \tab Linotype Japanese printer font\cr
%    Japan1HeiMin (PDF) \tab \code{HeiseiMin-W3-Acro}\cr \tab from Adobe Reader 7.0 Japanese Font Pack\cr
%    Japan1GothicBBB \tab \code{GothicBBB-Medium}\cr \tab Japanese-market PostScript printer font\cr
%    Japan1Ryumin \tab \code{Ryumin-Light}\cr \tab Japanese-market PostScript printer font\cr
%    Korea1 (PS) \tab \code{Baekmuk-Batang}\cr  \tab TrueType font found on some Linux systems\cr
%    Korea1 (PDF) \tab \code{HYSMyeongJoStd-Medium-Acro}\cr  \tab from Adobe Reader 7.0 Korean Font Pack\cr
%    Korea1deb (PS) \tab \code{Batang-Regular}\cr  \tab another name for Baekmuk-Batang\cr
%    Korea1deb (PDF) \tab \code{HYGothic-Medium-Acro}\cr  \tab from Adobe Reader 4.0 Korean Font Pack\cr
%    GB1 (PS) \tab \code{BousungEG-Light-GB}\cr  \tab TrueType font found on some Linux systems\cr
%    GB1 (PDF) \tab \code{STSong-Light-Acro}\cr  \tab from Adobe Reader 7.0 Simplified Chinese Font Pack\cr
%    CNS1 (PS) \tab \code{MOESung-Regular}\cr \tab Ken Lunde's CJKV resources\cr
%    CNS1 (PDF) \tab \code{MSungStd-Light-Acro}\cr  \tab from Adobe Reader 7.0 Traditional Chinese Font Pack\cr
%  }
%%  \code{Baekmuk-Batang} Can be found at \url{ftp://ftp.mizi.com/pub/baekmuk/}.
%  \code{BousungEG-Light-GB} can be found at
%  \url{ftp://ftp.gnu.org/pub/non-gnu/chinese-fonts-truetype/}.
%  Ken Lunde's CJKV resources are at
%  \url{ftp://ftp.oreilly.com/pub/examples/nutshell/cjkv/adobe/samples/}.
%  These will need to be installed or otherwise made available to the
%  postscript/PDF interpreter such as ghostscript (and not all
%  interpreters can handle TrueType fonts).
%
%  You may well find that your postscript/PDF interpreters has been set
%  up to provide aliases for many of these fonts.  For example,
%  ghostscript on Windows can optionally be installed to map common East
%  Asian fonts names to Windows TrueType fonts.  (You may want to add the
%  \code{-Acro} versions as well.)
%
%  Adding a mapping for a CID-keyed font is for gurus only.
%}
%\value{
%  A list of one or more font mappings.
%}
%\seealso{
%  \code{\link{postscript}} and \code{\link{pdf}};  \code{\link{Type1Font}}
%  and \code{\link{CIDFont}} for specifying new font mappings.
%}
%\author{
%  Support for Computer Modern fonts is based on a contribution by
%  Brian D'Urso.% formerly \email{durso@hussle.harvard.edu}.
%}
%\examples{
%postscriptFonts()
%## This duplicates "ComputerModernItalic".
%CMitalic <- Type1Font("ComputerModern2",
%                      c("CM_regular_10.afm", "CM_boldx_10.afm",
%                        "cmti10.afm", "cmbxti10.afm",
%                         "CM_symbol_10.afm"),
%                      encoding = "TeXtext.enc")
%postscriptFonts(CMitalic = CMitalic)
%
%## A CID font for Japanese using a different CMap and
%## corresponding cmapEncoding.
%`Jp_UCS-2` <- CIDFont("TestUCS2",
%                  c("Adobe-Japan1-UniJIS-UCS2-H.afm",
%                    "Adobe-Japan1-UniJIS-UCS2-H.afm",
%                    "Adobe-Japan1-UniJIS-UCS2-H.afm",
%                    "Adobe-Japan1-UniJIS-UCS2-H.afm"),
%                  "UniJIS-UCS2-H", "UCS-2")
%pdfFonts(`Jp_UCS-2` = `Jp_UCS-2`)
%names(pdfFonts())
%}
%\keyword{device}
%
%\encoding{UTF-8}
%