% File src/library/grDevices/man/recordGraphics.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{recordGraphics}
\title{グラフィックス操作を記録する}
\alias{recordGraphics}
%%\title{Record Graphics Operations}
\description{
  任意のコードをグラフィックスエンジンの表示リストに記録する．
  計算に依存するグラフィカルな出力を持つ計算を
  カプセル化するのに便利である．
  エキスパート使用\emph{だけ}を意図している．
}
\usage{
recordGraphics(expr, list, env)
}
\arguments{
  \item{expr}{モード \code{\link{expression}} か \code{call} か
    未評価表現式のオブジェクト．}
  \item{list}{その中で \code{expr} が評価されるべき環境を定義するリスト．}
  \item{env}{\R が \code{envir} 中に見つからないオブジェクトをどこで探すかを
    指定する環境．}
}
\value{
  \code{expr} の評価からの値．
}
\details{
  \code{expr} 中のコードが
  \code{list} から構成された環境中で評価され，
  \code{env} がその環境の親環境とされる．

  全ての三つの引数はグラフィックスエンジンの表示リストに保存されるので，
  デバイスがサイズ変更されてもデバイス間でコピーされても
  オリジナルの評価環境が再生成され
  コードはグラフィカルな出力を再生成できる．
}
\section{警告}{
  この関数は一般的使用を意図していない．
  この関数の不正確か不正な使用は
  意図しない and/or 期待していない結果に導く可能性がある．

  許容できる例はグラフィックスデバイスやグラフィックスシステム
  の設定の現在の状態を問い合わせそれから
  グラフィックス関数を呼び出すことである．

  不正な使用の例は大局的環境中での付値を実行する
  \code{assign} 関数の呼び出しである．
}
\seealso{\code{\link{eval}} }
\examples{
require(graphics)

plot(1:10)
# この長方形はデバイスがサイズ変更されても1インチ幅のまま
recordGraphics(
  {
    rect(4, 2,
         4 + diff(par("usr")[1:2])/par("pin")[1], 3)
  },
  list(),
  getNamespace("graphics"))
}
\keyword{ device }

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/recordGraphics.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{recordGraphics}
%\alias{recordGraphics}
%\title{Record Graphics Operations}
%\description{
%  Records arbitrary code on the graphics engine display list.
%  Useful for encapsulating calculations with graphical output
%  that depends on the calculations.
%  Intended \emph{only} for expert use.
%}
%\usage{
%recordGraphics(expr, list, env)
%}
%\arguments{
%  \item{expr}{object of mode \code{\link{expression}} or \code{call} or
%    an unevaluated expression.}
%  \item{list}{a list defining the environment in which \code{expr} is to
%    be evaluated.}
%  \item{env}{An \code{\link{environment}} specifying
%    where \R looks for objects not found in
%    \code{envir}.}
%}
%\value{
%  The value from evaluating \code{expr}.
%}
%\details{
%  The code in \code{expr} is evaluated in an environment constructed
%  from \code{list}, with \code{env} as the parent of that environment.
%
%  All three arguments are saved on the graphics engine display list
%  so that on a device resize or copying between devices, the original
%  evaluation environment can be recreated and the code can be
%  re-evaluated to reproduce the graphical output.
%}
%\section{Warning}{
%  This function is not intended for general use.  Incorrect or
%  improper use of this function could lead to unintended and/or
%  undesirable results.
%
%  An example of acceptable use is querying the current state
%  of a graphics device or graphics system setting and then
%  calling a graphics function.
%
%  An example of improper use would be calling the \code{assign} function
%  to performing assignments in the global environment.
%}
%\seealso{\code{\link{eval}} }
%\examples{
%require(graphics)
%
%plot(1:10)
%# This rectangle remains 1inch wide when the device is resized
%recordGraphics(
%  {
%    rect(4, 2,
%         4 + diff(par("usr")[1:2])/par("pin")[1], 3)
%  },
%  list(),
%  getNamespace("graphics"))
%}
%\keyword{ device }
%
%\encoding{UTF-8}
%