% File src/library/grDevices/man/unix/png.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{png}
\title{ビットマップ用グラフィックスデバイス}
\alias{png}
\alias{jpeg}
\alias{tiff}
\alias{bmp}
%%\title{BMP, JPEG, PNG and TIFF graphics devices}
\encoding{UTF-8}
\description{
  BMP, JPEG, PNG そして TIFF 書式のビットマップファイルに対する
  グラフィックスデバイス．
}
\usage{
bmp(filename = "Rplot\%03d.bmp",
    width = 480, height = 480, units = "px", pointsize = 12,
    bg = "white", res = NA, \dots,
    type = c("cairo", "Xlib", "quartz"), antialias)

jpeg(filename = "Rplot\%03d.jpeg",
     width = 480, height = 480, units = "px", pointsize = 12,
     quality = 75,
     bg = "white", res = NA, \dots,
     type = c("cairo", "Xlib", "quartz"), antialias)

png(filename = "Rplot\%03d.png",
    width = 480, height = 480, units = "px", pointsize = 12,
     bg = "white",  res = NA, \dots,
    type = c("cairo", "cairo-png", "Xlib", "quartz"), antialias)

tiff(filename = "Rplot\%03d.tiff",
     width = 480, height = 480, units = "px", pointsize = 12,
     compression = c("none", "rle", "lzw", "jpeg", "zip", "lzw+p", "zip+p"),
     bg = "white", res = NA,  \dots,
     type = c("cairo", "Xlib", "quartz"), antialias)
}
\arguments{
  \item{filename}{出力ファイルの名前．
    既定のようにもし C の整数書式が文字列に含まれるとページ番号が
    代入される．(結果は長さが
    \code{PATH_MAX} 文字以下でなければならず，もしそうでなければ
    打ち切られる．より詳細は \code{\link{postscript}} を見よ．)
    プラットフォームがサポートすればチルド展開が行われる．}
  \item{width}{デバイスの幅．}
  \item{height}{デバイスの高さ．}
  \item{units}{
    \code{height} と \code{width} が与えられる単位．
    \code{px} (ピクセル，既定値)，\code{in} (インチ)，
    \code{cm} 又は \code{mm}．}
  \item{pointsize}{プロットされるテキストの既定サイズ，
    \code{res} ppi でビッグポイント(1/72 インチ)と解釈される．}
  \item{bg}{初期背景色：par("bg") の設定で上書きされる．}
  \item{quality}{パーセンテージでの JPEG イメージの\sQuote{品質}．
    より小さな値はより大きな圧縮を行うがイメージはより劣化する．}
  \item{compression}{使用される圧縮のタイプ．
     もし \code{type = "quartz"} なら無視される．}
  \item{res}{もし正整数ならばビットマップに記録される ppi 単位の
    名目上の解像度．
    また既定以外の \code{units} に対してや
    ポイントをピクセルに変換するのにも使われる．}
  \item{\dots}{\code{type = "Xlib"} の時のみ，
    \code{fonts} や \code{family} のような
    基礎にある \code{\link{X11}} デバイスへの追加引数

    タイプ \code{"cairo"} と \code{"quartz"} に対しては，\code{family}
    引数を提供できる．\code{\link{X11}} に対するヘルプの
    \sQuote{Cairo フォント}節を見よ．}

  \item{type}{文字列，
    \code{"Xlib"} 又は \code{"quartz"} (ある種の OS X ビルド)又は
    \code{"cairo"} の一つ．後者はシステムが cairo のサポート
    付きでコンパイルされた時だけ利用できる
    --
    さもなければ \code{"Xlib"} が使われる．
    既定は
    \code{\link{getOption}("bitmapType")} で設定される --
    \sQuote{そのままで動作する}既定は利用できれば
    \code{"quartz"} か \code{"cairo"}，
    さもなければ \code{"Xlib"}．}

  \item{antialias}{\code{type = "cairo"} に対して，
    フォントと線に使われるアンチエイリアシング(もしあれば)のタイプ．
    \code{\link{X11}} を見よ．既定は
    \code{\link{X11.options}} で設定される．また 
    \code{type = "quartz"} に対しても同様で， 
    \code{antialias = "none"} で無い限りアンチエイリアシングが
    使われる．}
}
\details{
  PNG と JPEG 書式のプロットは容易に他のビットマップ書式に変換でき，
  どちらも現代のウェッブブラウザで表示できる．
  PNG 書式は無劣化であり線図式や色ブロックに対して最良である．
  JPEG 書式は劣化しやすいが，
  例えばイメージプロットには有用かもしれない．
  BMP は Windows では標準の書式である．
  TIFF はメタ書式である：
  \code{tiff} で書かれる既定の書式は劣化が無く RGB 値
  (適切であればアルファ値も)
  は無圧縮である --- そうしたファイルは広く受け入れられ，
  それがそれらの  PNG に対する主な長所である．

  \code{png} は透明な背景をサポートする：
  \code{bg = "transparent"} を使う．
  (全ての PNG ビューアーが透明性を正しく表示するわけではない．)
  \code{type = "Xlib"} の変種で透明性が使われると
  非常に明るいグレイが背景として使われるので，
  プロットで使われると透明のように見える．

  これは例におけるように不透明な白を使うことを許す．
  \code{type = "cairo"}, \code{type = "cairo-png"} そして
  \code{type = "quartz"} の変種は半透明色を許し，
  透明や半透明な背景を含む．

  タイプ \code{"cairo"} と \code{"quartz"} の
  \code{tiff} は半透明色をサポートし，
  透明や半透明な背景を含む．
  圧縮タイプ \code{"zip"} は
  \sQuote{deflate (Adobe スタイル)} である．
  圧縮タイプ \code{"lzw+p"} と \code{"zip+p"} は
  圧縮法との組み合わせで水平の階差
  (\sQuote{階差予測}，TIFF 仕様の14節)を使うが，
  これは連続イメージに対して有効で，特に色付きの場合がそうである．

  \R はこれらのデバイスの各々に対し
  幾つか又は全てのタイプに対するサポート無しでコンパイルできる：
  これらがサポートされていないシステム上で
  それらを使おうとすると報告がされる．
  \code{type = "Xlib"} に対しては
  X11 ディスプレイが \R プロセスの所有者でない限り
  それらは使用できないかもしれない．
  \code{type = "cairo"} は cairo 1.2 又はそれ以降を必要とする．
  \code{type = "quartz"} は \code{\link{quartz}} デバイスを使うので，
  それが使える場合だけ利用できる
  (ある種の OS X ビルド：\code{\link{capabilities}("aqua")} を見よ)．

  既定では BMP を除いて如何なる解像度もファイルには記録されない．
  記録がない場合ビューアーはしばしば解像度
  72 ppi を仮定する．
  PNG ファイル中の解像度はピクセル/メートルで記録されるので，
  報告される ppi 値は少し変更される．

  インチ単位の次元を使うグラフィックスパラメータに対しては
  (ポイント単位のフォントサイズを含む)使われる解像度は \code{res}
  (又は未設定なら 72 ppi)である．

  \code{png} はページに256未満の色があるならば普通パレットを使い，
  さもなければ24ビットの RGB ファイルを使う
  (又は \code{type = "cairo"} で不透明でない色が使われれば
  32ビットの ARGB ファイルが使われる)．
  しかしながら \code{type = "cairo-png"} は cairographics の PNG
  バックエンドを使い，これは決してパレットを使わず普通
  より大きな 32 ビットの ARGB ファイルを作る ---
  これは半透明色を用いたスペシャリスト用途に対して
  より良く動作するかもしれない．

  透明な背景を持つ Quartz 製の PNG と TIFF プロットは
  暗いグレイの艶消しで記録され，
  これは OS X の \command{Preview} を含むある種のビューアー中で表示される． 
  
  \R 3.0.3 以前では
  BMP ファイル中の未知の解像度は不正確に記録されていた：
  それらは今では 72 ppi で記録される．
}

\value{
  プロット用のデバイスが開かれる：
  \R インタプリタには何も返されない．
}

\section{警告}{
  既定では \code{width} と \code{height} の値の単位はピクセルであり
  インチではないことを注意する．もし両者が20以下なら警告が出る．

  もしこれらのデバイス上で一つよりも多いプロットを行い
  \code{file} 中に系列番号に対する \code{\%d} の様なものを含めなければ，
  ファイルはプロットされた最後のページを含む．
}

\section{OS 間の違い}{
  これらの関数は三つ又はそれ以上の基礎にあるデバイスへのインタフェイスである．
  \itemize{
    \item Windows ではデバイスは
    Windows の GDI 呼び出しを用いた隠れたスクリーンへのプロットに
    基づいている．

    \item X11 に対するサポートを持つプラットフォームでは，
    隠れた X11 ディスプレイへのプロットを使う．

    \item OS X ではコンソールで作業しており
    \R が適当なサポート付きでコンパイルされていると，
    Apple の Quartz プロットシステムを使う．

    \item cairo グラフィックスに対するサポートがコンパイルされていれば，
    cairo サーフィスへのプロットを使う．
    これはフォントに対するネイティブなプラットフォームのサポートを
    使うかもしれない．又は広範囲のフォントをサポートするために
    \code{fontconfig} を使うかもしれない．
    (これは Windows では \R 2.14.0 で始めて使えるようになった．)
  }
  
  サポートされるオプションと作られる出力には違いが避けられない．
  恐らく最も重要なものはアンチエイリアシングされたフォントと半透明色であろう：
  最良の結果はもし使えるのならば
  cairo 又は Quartz に基づくデバイスであろう．

  既定の拡張子は Windows では \file{.jpg} と \file{.tif} で，そして
  ほかでは \file{.jpeg} と \file{.tiff} である．
}

\note{
  \code{type = "Xlib"} に対してはこれらのデバイスは
  \code{\link{X11}} デバイスに基づいている．使われる色モデルは
  最初の Xlib に基づくデバイスが開かれた時に
  \code{X11.options} により設定される
  (又はそれらのデバイスの全てが閉じられた後の最初に)．
}

\author{Guido Masarotto と Brian Ripley}

\references{
  PNG の仕様は \url{http://www.w3.org/TR/PNG/}．
  
  拡張を含む TIFF の仕様は
  \url{https://partners.adobe.com/public/developer/tiff/}．
}
\seealso{
  \code{\link{Devices}}, \code{\link{dev.print}}

  これらのデバイスそして \code{type = "cairo"} がこの
  \R のビルドでサポートされているかどうかを
  見るには \code{\link{capabilities}}．

  \code{\link{bitmap}} は多くのビットマップ書式のプロットを
  生成する別の方法を提供する．これは
  X11 ディスプレイへのアクセスには依存しないが
  GhostScript がインストールされている必要がある．
}

\section{慣例}{
  この節は \dQuote{R Internals Manual} で設定されている
  グラフィックスデバイスに対する慣例の実装を説明する．

  \itemize{
    \item 既定のデバイスのサイズはピクセル単位である．
    \item フォントサイズはビッグポイントで
      \code{res} ppi で解釈される．
    \item 既定のフォントファミリは Helvetica．
    \item 線幅は 1/96 インチ単位(\code{res} ppi で解釈される)，
      \code{type = "Xlib"} に対する最少ピクセルで，
      \code{type = "cairo"} に対しては 0.01．
    \item \code{type = "Xlib"} に対しては円半径はピクセル単位で最小値は 1．
    \item 色は眺めるアプリケーションにより解釈される．
  }

  \code{type = "quartz"} に対しては  \code{\link{quartz}} のヘルプを見よ．
}

\examples{
## これらの例はデバイスが利用でき， cairo 又は X11 ディスプレイ
## 又は OS X ディスプレイが利用できる時だけ動作する．

## 現在のプロットを(大きな) PNG ファイルにコピー
\dontrun{dev.print(png, file = "myplot.png", width = 1024, height = 768)}
\donttest{
png(file = "myplot.png", bg = "transparent")
plot(1:10)
rect(1, 5, 3, 7, col = "white")
dev.off()

## myplot1.jpeg と myplot2.jpeg が出来る
jpeg(file = "myplot\%d.jpeg")
example(rect)
dev.off()
}}
\keyword{device}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/unix/png.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{png}
%\alias{png}
%\alias{jpeg}
%\alias{tiff}
%\alias{bmp}
%\title{BMP, JPEG, PNG and TIFF graphics devices}
%\description{
%  Graphics devices for BMP, JPEG, PNG and TIFF format bitmap files.
%}
%\usage{
%bmp(filename = "Rplot\%03d.bmp",
%    width = 480, height = 480, units = "px", pointsize = 12,
%    bg = "white", res = NA, \dots,
%    type = c("cairo", "Xlib", "quartz"), antialias)
%
%jpeg(filename = "Rplot\%03d.jpeg",
%     width = 480, height = 480, units = "px", pointsize = 12,
%     quality = 75,
%     bg = "white", res = NA, \dots,
%     type = c("cairo", "Xlib", "quartz"), antialias)
%
%png(filename = "Rplot\%03d.png",
%    width = 480, height = 480, units = "px", pointsize = 12,
%     bg = "white",  res = NA, \dots,
%    type = c("cairo", "cairo-png", "Xlib", "quartz"), antialias)
%
%tiff(filename = "Rplot\%03d.tiff",
%     width = 480, height = 480, units = "px", pointsize = 12,
%     compression = c("none", "rle", "lzw", "jpeg", "zip", "lzw+p", "zip+p"),
%     bg = "white", res = NA,  \dots,
%     type = c("cairo", "Xlib", "quartz"), antialias)
%}
%\arguments{
%  \item{filename}{the name of the output file.
%    The page number is substituted if a C integer format is included in
%    the character string, as in the default.  (The result must be less
%    than \code{PATH_MAX} characters long, and may be truncated if not.
%    See \code{\link{postscript}} for further details.)  Tilde expansion
%    is performed where supported by the platform.}
%  \item{width}{the width of the device.}
%  \item{height}{the height of the device.}
%  \item{units}{The units in which \code{height} and \code{width} are
%    given.  Can be \code{px} (pixels, the default), \code{in} (inches),
%    \code{cm} or \code{mm}.}
%  \item{pointsize}{the default pointsize of plotted text, interpreted as
%    big points (1/72 inch) at \code{res} ppi.}
%  \item{bg}{the initial background colour: can be overridden by setting
%    par("bg").}
%  \item{quality}{the \sQuote{quality} of the JPEG image, as a
%    percentage.  Smaller values will give more compression but also more
%    degradation of the image.}
%  \item{compression}{the type of compression to be used.  Ignored for
%     \code{type = "quartz"}.}
%  \item{res}{The nominal resolution in ppi which will be recorded in the
%    bitmap file, if a positive integer.  Also used for \code{units}
%    other than the default, and to convert points to pixels.}
%  \item{\dots}{for \code{type = "Xlib"} only, additional arguments to
%    the underlying \code{\link{X11}} device such as \code{fonts} or
%     \code{family}.
%
%    For types \code{"cairo"} and \code{"quartz"}, the \code{family}
%    argument can be supplied.  See the \sQuote{Cairo fonts}
%    section in the help for \code{\link{X11}}.}
%
%  \item{type}{character string, one of \code{"Xlib"} or \code{"quartz"}
%    (some OS X builds) or \code{"cairo"}.  The latter will only be
%    available if the system was compiled with support for cairo --
%    otherwise \code{"Xlib"} will be used.  The default is set by
%    \code{\link{getOption}("bitmapType")} -- the \sQuote{out of the box}
%    default is \code{"quartz"} or \code{"cairo"} where available,
%    otherwise \code{"Xlib"}.}
%
%  \item{antialias}{for \code{type = "cairo"}, giving the type of
%    anti-aliasing (if any) to be used for fonts and lines (but not
%    fills). See \code{\link{X11}}.  The default is set by
%    \code{\link{X11.options}}.  Also for \code{type = "quartz"}, where
%    antialiasing is used unless \code{antialias = "none"}.}
%}
%\details{
%  Plots in PNG and JPEG format can easily be converted to many other
%  bitmap formats, and both can be displayed in modern web
%  browsers.  The PNG format is lossless and is best for line
%  diagrams and blocks of colour.  The JPEG format is lossy,
%  but may be useful for image plots, for example.  BMP is a standard
%  format on Windows.  TIFF is a meta-format: the default format written
%  by \code{tiff} is lossless and stores RGB (and alpha where
%  appropriate) values uncompressed---such files are widely accepted,
%  which is their main virtue over PNG.
%
%  \code{png} supports transparent backgrounds: use \code{bg =
%  "transparent"}.  (Not all PNG viewers render files with transparency
%  correctly.)  When transparency is in use in the \code{type = "Xlib"}
%  variant a very light grey is used as the background and so appears as
%  transparent if used in the plot. This allows opaque white to be used,
%  as in the example.  The \code{type = "cairo"}, \code{type =
%  "cairo-png"} and \code{type = "quartz"} variants allow
%  semi-transparent colours, including on a transparent or
%  semi-transparent background.
%
%  \code{tiff} with types \code{"cairo"} and \code{"quartz"} supports
%  semi-transparent colours, including on a transparent or
%  semi-transparent background.  Compression type \code{"zip"} is
%  \sQuote{deflate (Adobe-style)}.  Compression types \code{"lzw+p"} and
%  \code{"zip+p"} use horizontal differencing (\sQuote{differencing
%  predictor}, section 14 of the TIFF specification) in combination with
%  the compression method, which is effective for continuous-tone images,
%  especially colour ones.
%
%  \R can be compiled without support for some or all of the types for
%  each of these devices: this will be reported if you attempt to use
%  them on a system where they are not supported.  For \code{type =
%  "Xlib"} they may not be usable unless the X11 display is available to
%  the owner of the \R process.  \code{type = "cairo"} requires cairo 1.2
%  or later.  \code{type = "quartz"} uses the \code{\link{quartz}} device
%  and so is only available where that is (on some OS X builds: see
%  \code{\link{capabilities}("aqua")}).
%
%  By default no resolution is recorded in the file, except for BMP.
%  Viewers will often assume a nominal resolution of 72 ppi when none is
%  recorded.  As resolutions in PNG files are recorded in pixels/metre,
%  the reported ppi value will be changed slightly.
%
%  For graphics parameters that make use of dimensions in inches
%  (including font sizes in points) the resolution used is \code{res} (or
%  72 ppi if unset).
%
%  \code{png} will normally use a palette if there are less than 256
%  colours on the page, and record a 24-bit RGB file otherwise (or a
%  32-bit ARGB file if \code{type = "cairo"} and non-opaque colours are
%  used).  However, \code{type = "cairo-png"} uses cairographics' PNG
%  backend which will never use a palette and normally creates a larger
%  32-bit ARGB file---this may work better for specialist uses with
%  semi-transparent colours.
%
%  Quartz-produced PNG and TIFF plots with a transparent background are
%  recorded with a dark grey matte which will show up in some viewers,
%  including \command{Preview} on OS X.
%  
%  Prior to \R 3.0.3 unknown resolutions in BMP files were sometimes
%  recorded incorrectly: they are now recorded as 72 ppi.
%}
%
%\value{
%  A plot device is opened: nothing is returned to the \R interpreter.
%}
%
%\section{Warnings}{
%  Note that by default the \code{width} and \code{height} values are in
%  pixels not inches.  A warning will be issued if both are less than 20.
%
%  If you plot more than one page on one of these devices and do not
%  include something like \code{\%d} for the sequence number in
%  \code{file}, the file will contain the last page plotted.
%}
%
%\section{Differences between OSes}{
%  These functions are interfaces to three or more different underlying
%  devices.
%  \itemize{
%    \item On Windows, devices based on plotting to a hidden screen using
%    Windows' GDI calls.
%
%    \item On platforms with support for X11, plotting to a hidden X11
%    display.
%
%    \item On OS X when working at the console and when \R is
%    compiled with suitable support, using Apple's Quartz plotting
%    system.
%
%    \item Where support has been compiled in for cairographics, plotting
%    on cairo surfaces.  This may use the native platform support for
%    fonts, or it may use \code{fontconfig} to support a wide range of
%    font formats.  (This was first available on Windows in \R 2.14.0.)
%  }
%  Inevitably there will be differences between the options supported and
%  output produced.  Perhaps the most important are support for
%  antialiased fonts and semi-transparent colours: the best results are
%  likely to be obtained with the cairo- or Quartz-based devices where
%  available.
%
%  The default extensions are \file{.jpg} and \file{.tif} on Windows, and
%  \file{.jpeg} and \file{.tiff} elsewhere.
%}
%
%\note{
%  For \code{type = "Xlib"} these devices are based on the \code{\link{X11}}
%  device.  The colour model used will be that set up by
%  \code{X11.options} at the time the first Xlib-based devices was opened
%  (or the first after all such devices have been closed).
%}
%
%\author{Guido Masarotto and Brian Ripley}
%
%\references{
%  The PNG specification, \url{http://www.w3.org/TR/PNG/}.
%  
%  The TIFF specification, including extensions, at
%  \url{https://partners.adobe.com/public/developer/tiff/}.
%}
%\seealso{
%  \code{\link{Devices}}, \code{\link{dev.print}}
%
%  \code{\link{capabilities}} to see if these devices are
%  supported by this build of \R, and if \code{type = "cairo"} is supported.
%
%  \code{\link{bitmap}} provides an alternative way to generate plots in many
%  bitmap formats that does not depend on accessing the X11 display but does
%  depend on having GhostScript installed.
%}
%
%\section{Conventions}{
%  This section describes the implementation of the conventions for
%  graphics devices set out in the \dQuote{R Internals Manual}.
%
%  \itemize{
%    \item The default device size is in pixels.
%    \item Font sizes are in big points interpreted at \code{res} ppi.
%    \item The default font family is Helvetica.
%    \item Line widths in 1/96 inch (interpreted at \code{res} ppi),
%    minimum one pixel for \code{type = "Xlib"}, 0.01 for \code{type =
%      "cairo"}.
%    \item For \code{type = "Xlib"} circle radii are in pixels with
%    minimum one.
%    \item Colours are interpreted by the viewing application.
%  }
%
%  For \code{type = "quartz"} see the help for \code{\link{quartz}}.
%}
%
%\examples{
%## these examples will work only if the devices are available
%## and cairo or an X11 display or an OS X display is available.
%
%## copy current plot to a (large) PNG file
%\dontrun{dev.print(png, file = "myplot.png", width = 1024, height = 768)}
%\donttest{
%png(file = "myplot.png", bg = "transparent")
%plot(1:10)
%rect(1, 5, 3, 7, col = "white")
%dev.off()
%
%## will make myplot1.jpeg and myplot2.jpeg
%jpeg(file = "myplot\%d.jpeg")
%example(rect)
%dev.off()
%}}
%\keyword{device}
%
