% File src/library/grDevices/man/xy.coords.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{xy.coords}
%%\title{Extracting Plotting Structures}
\description{
  \code{xy.coords} はプロット用の
  x と y 座標を得るために多くの関数により使われる．
  関連する全ての \R 関数を縦断するこの共通機構の使用は一貫性の目安を生み出す．
}
\usage{
xy.coords(x, y = NULL, xlab = NULL, ylab = NULL, log = NULL,
          recycle = FALSE)
}
\title{プロット構造の取り出し}
\alias{xy.coords}
\arguments{
  \item{x, y}{点の集合の x と y 座標．
    もしくは単一の引数 \code{x} を与えることが出来る．}
  \item{xlab, ylab}{取り出される x と y 変数．}
  \item{log}{文字列，\code{\link{plot}} に対するような
    \code{"x"}, \code{"y"} 又は双方．
    \code{\link{NA}} に負の値を設定し警告を与える．}
  \item{recycle}{論理値；もし \code{TRUE} なら
    もし長さが異なれば
    \code{x} か \code{y} の短い方はリサイクル(\code{\link{rep}})される．}
}
\details{
  引数 \code{x} と \code{y} は二変量プロット
  (又は他の二変量手法)に相応しいように解釈する努力がされる．

  \describe{
    \item{公式：}{形式 \code{yvar ~ xvar}．\code{xvar} と
      \code{yvar} は x と y 変数として使われる．.}

    \item{リスト：}{
      成分 \code{x} と \code{y} を含む，これらはプロット座標として
      使われる．}

    \item{時系列：}{x 値は
      \code{\link{time}(x)}，y 値は時系列とされる．}

    \item{二つもしくはそれ以上の列を持つ行列又はデータフレーム：}{
      最初は x 値を二番目は y 値を含むと仮定される．
      これは又 \code{x} が名前が
      \code{"x"} と \code{"y"} である列を持つ時も正しいことを
      \emph{注意}する；これらの名前はここでは無関係である．}
  }
  他の任意のケースでは，\code{x} 引数はベクトルに強制変換され，
  そして
  \bold{y} 成分として返される，ここで結果の \code{x} は
  単に添字ベクトル \code{1:n} になる．この場合，
  結果の \code{xlab} 成分は \code{"Index"} に設定される．

  もし \code{x} (上のような変換後)がクラス
  \code{"POSIXt"} を継承すればクラス \code{"POSIXct"} に強制変換される．
}
\value{
  次の成分を持つリスト
  \item{x}{数値 (つまり，横座標の \code{"double"}) ベクトル．}
  \item{y}{\code{x} と同じ長さの数値ベクトル．}
  \item{xlab}{\code{character(1)} 又は \code{NULL}，
    \code{x} の\sQuote{ラベル}．}
  \item{ylab}{\code{character(1)} 又は \code{NULL}，
    \code{y} の\sQuote{ラベル}．}
}
\seealso{
  \code{\link{plot.default}}, \code{\link{lines}}, \code{\link{points}}
  そして \code{\link{lowess}} はこの機構を使う関数の例である．
}
\examples{
xy.coords(stats::fft(c(1:9)), NULL)

with(cars, xy.coords(dist ~ speed, NULL)$xlab ) # = "speed"

xy.coords(1:3, 1:2, recycle = TRUE)
xy.coords(-2:10, NULL, log = "y")
##> warning: 3 y values <= 0 omitted ..
}
\keyword{dplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/xy.coords.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{xy.coords}
%\title{Extracting Plotting Structures}
%\description{
%  \code{xy.coords} is used by many functions to obtain
%  x and y coordinates for plotting.  The use of this common mechanism
%  across all relevant \R functions produces a measure of consistency.
%}
%\usage{
%xy.coords(x, y = NULL, xlab = NULL, ylab = NULL, log = NULL,
%          recycle = FALSE)
%}
%\alias{xy.coords}
%\arguments{
%  \item{x, y}{the x and y coordinates of a set of points.
%    Alternatively, a single argument \code{x} can be provided.}
%  \item{xlab, ylab}{names for the x and y variables to be extracted.}
%  \item{log}{character, \code{"x"}, \code{"y"} or both, as for
%    \code{\link{plot}}.  Sets negative values to \code{\link{NA}} and
%    gives a warning.}
%  \item{recycle}{logical; if \code{TRUE}, recycle (\code{\link{rep}})
%    the shorter of \code{x} or \code{y} if their lengths differ.}
%}
%\details{
%  An attempt is made to interpret the arguments \code{x} and \code{y} in
%  a way suitable for bivariate plotting (or other bivariate procedures).
%
%  If \code{y} is \code{NULL} and \code{x} is a
%  \describe{
%    \item{formula:}{of the form \code{yvar ~ xvar}. \code{xvar} and
%      \code{yvar} are used as x and y variables.}
%
%    \item{list:}{containing components \code{x} and \code{y}, these are
%      used to define plotting coordinates.}
%
%    \item{time series:}{the x values are taken to be
%      \code{\link{time}(x)} and the y values to be the time series.}
%
%    \item{matrix or \code{\link{data.frame}} with two or more
%      columns:}{the first is assumed to contain the x values and the
%      second the y values.  \emph{Note} that is also true if \code{x}
%      has columns named \code{"x"} and \code{"y"}; these names will be
%      irrelevant here.}
%  }
%  In any other case, the \code{x} argument is coerced to a vector and
%  returned as \bold{y} component where the resulting \code{x} is just
%  the index vector \code{1:n}.  In this case, the resulting \code{xlab}
%  component is set to \code{"Index"}.
%
%  If \code{x} (after transformation as above) inherits from class
%  \code{"POSIXt"} it is coerced to class \code{"POSIXct"}.
%}
%\value{
%  A list with the components
%  \item{x}{numeric (i.e., \code{"double"}) vector of abscissa values.}
%  \item{y}{numeric vector of the same length as \code{x}.}
%  \item{xlab}{\code{character(1)} or \code{NULL}, the \sQuote{label} of
%    \code{x}.}
%  \item{ylab}{\code{character(1)} or \code{NULL}, the \sQuote{label} of
%    \code{y}.}
%}
%\seealso{
%  \code{\link{plot.default}}, \code{\link{lines}}, \code{\link{points}}
%  and \code{\link{lowess}} are examples of functions which use this mechanism.
%}
%\examples{
%xy.coords(stats::fft(c(1:9)), NULL)
%
%with(cars, xy.coords(dist ~ speed, NULL)$xlab ) # = "speed"
%
%xy.coords(1:3, 1:2, recycle = TRUE)
%xy.coords(-2:10, NULL, log = "y")
%##> warning: 3 y values <= 0 omitted ..
%}
%\keyword{dplot}
%
%\encoding{UTF-8}
%