% File src/library/grDevices/man/xyz.coords.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{xyz.coords}
\title{三次元のプロット構造を取り出す}
\alias{xyz.coords}
%%\title{Extracting Plotting Structures}
\description{
  三次元(3D)プロット用の
  一貫性のある x, y そして z 座標とラベルを得るユーティリティ．
}
\usage{
xyz.coords(x, y = NULL, z = NULL,
           xlab = NULL, ylab = NULL, zlab = NULL,
           log = NULL, recycle = FALSE)
}
\arguments{
  \item{x, y, z}{点集合の x, y そして z 座標．
    \code{y} と \code{z} は共に \code{NULL} のままで良い．この場合
    \code{x} はプロットに相応しい仕方で解釈することが試みられる．

    もし引数が公式 \code{zvar ~ xvar + yvar} ならば，
    \code{xvar}, \code{yvar} そして \code{zvar} が x, y そして z
    変数とされる；
    もし引数が成分 \code{x}, \code{y} そして \code{z} を含めば，
    これらはプロット座標を定義すると仮定される；
    もし引数が三列の行列又は \code{\link{data.frame}} ならば，
    最初が x 値，二番目が y 値，そして三番目が
    z 値とされる --
    \code{x} が持つかもしれない列名とは無関係である．

    別の方法として二つの \code{x} と \code{y} を与えることが出来る
    (\code{z = NULL} とする)．一つは実数で他方が複素数；
    他の任意のケースでは，引数はベクトルに強制変換され
    値は他の添字に対してプロットされる．
  }
  \item{xlab, ylab, zlab}{取り出される x, y そして z 変数のラベル．}
  \item{log}{文字列，\code{"x"}, \code{"y"}, \code{"z"} 又は組み合わせ．
    \code{\link{NA}} に負の値を設定し警告を与える．}
  \item{recycle}{論理値；もし \code{TRUE} なら，
    もし長さが異なれば \code{x}, \code{y} 又は \code{z} のより短いものは
    リサイクルされる(\code{\link{rep}})．}
}
\value{
  次の成分を持つリスト
  \item{x}{横座標値の数値(つまり \code{\link{double}})ベクトル．}
  \item{y}{\code{x} と同じ長さの数値ベクトル．}
  \item{z}{\code{x} と同じ長さの数値ベクトル．}
  \item{xlab}{\code{character(1)} 又は \code{NULL}，\code{x} の軸ラベル．}
  \item{ylab}{\code{character(1)} 又は \code{NULL}，\code{y} の軸ラベル．}
  \item{zlab}{\code{character(1)} 又は \code{NULL}，\code{z} の軸ラベル．}
}
\author{Uwe Ligges と Martin Maechler}
\seealso{二次元には \code{\link{xy.coords}}．}
\examples{
xyz.coords(data.frame(10*1:9, -4), y = NULL, z = NULL)

xyz.coords(1:5, stats::fft(1:5), z = NULL, xlab = "X", ylab = "Y")

y <- 2 * (x2 <- 10 + (x1 <- 1:10))
xyz.coords(y ~ x1 + x2, y = NULL, z = NULL)

xyz.coords(data.frame(x = -1:9, y = 2:12, z = 3:13), y = NULL, z = NULL,
           log = "xy")
##> Warning message: 2 x values <= 0 omitted ...
}
\keyword{dplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/xyz.coords.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{xyz.coords}
%\alias{xyz.coords}
%\title{Extracting Plotting Structures}
%\description{
%  Utility for obtaining consistent x, y and z coordinates and labels
%  for three dimensional (3D) plots.
%}
%\usage{
%xyz.coords(x, y = NULL, z = NULL,
%           xlab = NULL, ylab = NULL, zlab = NULL,
%           log = NULL, recycle = FALSE)
%}
%\arguments{
%  \item{x, y, z}{the x, y and z coordinates of a set of points.
%    Both \code{y} and \code{z} can be left at \code{NULL}.  In this
%    case, an attempt is made to interpret \code{x} in a way suitable for
%    plotting.
%
%    If the argument is a formula \code{zvar ~ xvar + yvar},
%    \code{xvar}, \code{yvar} and \code{zvar} are used as x, y and z
%    variables;
%    if the argument is a list containing components \code{x},
%    \code{y} and \code{z}, these are assumed to define plotting coordinates;
%    if the argument is a matrix or \code{\link{data.frame}} with three
%    or more columns, the first is
%    assumed to contain the x values, the 2nd the y ones, and the 3rd the
%    z ones -- independently of any column names that \code{x} may have.
%
%    Alternatively two arguments \code{x} and \code{y} can be provided
%    (leaving \code{z = NULL}).  One may be real, the other complex;
%    in any other case, the arguments are coerced to vectors
%    and the values plotted against their indices.
%  }
%  \item{xlab, ylab, zlab}{names for the x, y and z variables to be extracted.}
%  \item{log}{character, \code{"x"}, \code{"y"}, \code{"z"} or combinations.
%    Sets negative values to \code{\link{NA}} and gives a warning.}
%  \item{recycle}{logical; if \code{TRUE}, recycle (\code{\link{rep}}) the
%    shorter ones of \code{x}, \code{y} or \code{z} if their lengths differ.}
%}
%\value{
%  A list with the components
%  \item{x}{numeric (i.e., \code{\link{double}}) vector of abscissa values.}
%  \item{y}{numeric vector of the same length as \code{x}.}
%  \item{z}{numeric vector of the same length as \code{x}.}
%  \item{xlab}{\code{character(1)} or \code{NULL}, the axis label of \code{x}.}
%  \item{ylab}{\code{character(1)} or \code{NULL}, the axis label of \code{y}.}
%  \item{zlab}{\code{character(1)} or \code{NULL}, the axis label of \code{z}.}
%}
%\author{Uwe Ligges and Martin Maechler}
%\seealso{\code{\link{xy.coords}} for 2D.}
%\examples{
%xyz.coords(data.frame(10*1:9, -4), y = NULL, z = NULL)
%
%xyz.coords(1:5, stats::fft(1:5), z = NULL, xlab = "X", ylab = "Y")
%
%y <- 2 * (x2 <- 10 + (x1 <- 1:10))
%xyz.coords(y ~ x1 + x2, y = NULL, z = NULL)
%
%xyz.coords(data.frame(x = -1:9, y = 2:12, z = 3:13), y = NULL, z = NULL,
%           log = "xy")
%##> Warning message: 2 x values <= 0 omitted ...
%}
%\keyword{dplot}
%
%\encoding{UTF-8}
%