% File src/library/graphics/man/barplot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{barplot}
\alias{barplot}
\alias{barplot.default}
\title{Bar Plots}
\description{
  垂直と水平のバーを持つバープロットを作る．
}
\usage{
barplot(height, \dots)

\method{barplot}{default}(height, width = 1, space = NULL,
        names.arg = NULL, legend.text = NULL, beside = FALSE,
        horiz = FALSE, density = NULL, angle = 45,
        col = NULL, border = par("fg"),
        main = NULL, sub = NULL, xlab = NULL, ylab = NULL,
        xlim = NULL, ylim = NULL, xpd = TRUE, log = "",
        axes = TRUE, axisnames = TRUE,
        cex.axis = par("cex.axis"), cex.names = par("cex.axis"),
        inside = TRUE, plot = TRUE, axis.lty = 0, offset = 0,
        add = FALSE, args.legend = NULL, \dots)
}
\arguments{
  \item{height}{プロットを作り上げるバーを記述する値のベクトルか行列．
    もし \code{height} がベクトルならば，プロットは
    ベクトル中の値で与えられる高さの矩形のバーの系列からなる．
    もし \code{height} が行列で \code{beside} が \code{FALSE} なら
    プロットの各バーは \code{height} の列に対応し，列中の値は
    バーを組み立てる積み立てられた副バーの高さを与える．
    もし \code{height} が行列で \code{beside} が \code{TRUE}
    ならば，各列中の値は積み重ねられる代わりに並置される．}
  \item{width}{バーの幅のオプションのベクトル．描かれるバーの数の長さに
    リサイクルされる．単一の値を指定するのは \code{xlim} が指定されていない限り
    目に見える効果はない．}
  \item{space}{各バーの前に残されるスペース量
    (バー幅の平均の割合として)．単一の数として与えたり
    バー毎に与えることが出来る．もし \code{height} が行列で
    \code{beside} が \code{TRUE} ならば，\code{space} は
    二つの数で指定されるかもしれない．ここで最初は同じグループ中の
    バーの間のスペースで，二番目はグループ間のスペースである．
    もし明示的に与えられなければ，その既定値は，もし\code{height} が
    行列で \code{beside} が \code{TRUE} ならば，\code{c(0,1)}
    になる．さもなければ 0.2 になる．}
  \item{names.arg}{各バーかバーのグループの下にプロットされる名前のベクトル．
    もしこの引数が省略されると，もし \code{height} がベクトルならば
    名前はその \code{names} 属性から取られ，もしそれが行列なら
    列名から取られる．}
  \item{legend.text}{プロットに対する凡例を構成するために使われるテキストのベクトル，
    または凡例を含めるべきかどうかを指示する論理値．
    これは \code{height} が行列の時だけ役に立つ．
    その場合与えられた凡例ラベルは \code{height} の行に対応すべきである；
    もし \code{legend.text} が真なら \code{height} の列名は
    それらが null で無い限りラベルとして使われる．}
  \item{beside}{論理値．もし \code{FALSE} なら，
    \code{height} の列は積み重ねたバーとなり，そしてもし \code{TRUE}
    ならば列は並置されたバーとなる．}
  \item{horiz}{論理値．もし \code{FALSE} なら，バーは最初が
    左側になるように垂直に描かれる．もし \code{TRUE} なら，バーは
    最初が底になるように水平に描かれる．}
  \item{density}{バーもしくはバー成分に対する陰影線の密度を与えるベクトル．
    単位はインチあたりの線数．
    既定値 \code{NULL} は陰影線を描かないことを意味する．
    正でない \code{density} の値も陰影線を描かない．}
  \item{angle}{バーもしくはバー成分に対して影を付ける線の傾きで度単位の角度
    (反時計回り)で与えられる．}
  \item{col}{バー又はバー成分に対する色のベクトル．
    既定ではもし \code{height} がベクトルなら灰色が使われ，
    \code{height} が行列ならガンマ補正された灰色のパレットが使われる．}
  \item{border}{バーの輪郭に使われる色．
    輪郭を描かないためには \code{border = NA} を使う．もし陰影線があれば，
    \code{border = TRUE} は陰影線と同じ色を輪郭線に使うことを意味する．}
  \item{main,sub}{プロットの全体とサブのタイトル．}
  \item{xlab}{x 軸に対するラベル．}
  \item{ylab}{y 軸に対するラベル．}
  \item{xlim}{x 軸に対する限界．}
  \item{ylim}{y 軸に対する限界．}
  \item{xpd}{論理値．バーが領域の外に出ても良いか?}
  \item{log}{軸のスケールを対数メモリにするかどうかを指定する文字列；
    \code{\link{plot.default}} を見よ．}
  \item{axes}{論理値．もし \code{TRUE} なら垂直
    (又はもし \code{horiz} が真なら水平)軸が描かれる．}
  \item{axisnames}{論理値．もし \code{TRUE} で，もし
    \code{names.arg} (上を見よ)があれば，他の軸が描かれ
    (\code{lty = 0} で)ラベルが付けられる．}
  \item{cex.axis}{数値軸ラベルに対する拡大因子．}
  \item{cex.names}{軸名(バーラベル)に対する拡大因子．}
  \item{inside}{論理値．もし \code{TRUE} なら，隣り合った
    (積み重ねられたものではない!)バーを分割する線が描かれる．
    \code{space = 0} の時
    (\code{beside = TRUE} の時は部分的にそうなる)
    だけ適用される．}
%  \item{inside}{logical.  If \code{TRUE}, the lines which divide
%    adjacent (non-stacked!) bars will be drawn.  Only applies when
%    \code{space = 0} (which it partly is when \code{beside = TRUE}).}
%MM: we still have "NotYetUsed" -- the above describes S-plus 6.1 (not
% precisely documented!) behavior!
  \item{plot}{論理値．もし \code{FALSE} なら何もプロットされない．}
  \item{axis.lty}{カテゴリカル(既定では水平)な軸の軸とチックマーク
    に適用されるグラフィックパラメータ \code{lty}．既定では
    軸は描かれないことを注意しよう．}
  \item{offset}{バーが x 軸に対してどれだけシフトされるべきかを指示するベクトル．}
  \item{add}{バーが既にあるプロットに加えられるべきかどうかを指示する
    論理値；既定では \code{FALSE}．}
  \item{args.legend}{\code{\link{legend}()} に渡される追加引数のリスト；
    リストの名前は引数名として使われる．
    \code{legend.text} が与えられた時だけ使われる．}
  \item{\dots}{他のメソッドに・から渡される追加の引数．
    既定のメソッドに対しては，これらは
    \code{\link{plot.window}()}, \code{\link{title}()} そして
    \code{\link{axis}} に渡される追加の引数
    (\code{axes}, \code{asp} そして \code{main}) やグラフィックパラメータ
    (\code{\link{par}} 見よ) を含むことが出来る．}
}
\details{
  これは総称的関数であり，現在既定のメソッドだけを持つ．
  いつか公式インタフェイスが加えられるかもしれない．
}
\value{
  数値ベクトル(又は \code{beside = TRUE} の時は行列)，
  例えば \code{mp} とする，で描かれる全てのバーの中点の座標を与え，
  グラフに付け加えるのに有用である．

  もし \code{beside} が真ならバーの各\emph{グループ}の
  中点として \code{colMeans(mp)} を使う，例を見よ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
}
\seealso{
  \code{\link{plot}(\dots, type = "h")}, \code{\link{dotchart}},
  \code{\link{hist}}.
}
\examples{
require(grDevices) # 色のために
tN <- table(Ni <- stats::rpois(100, lambda = 5))
r <- barplot(tN, col = rainbow(20))
#- type = "h" plotting *is* 'bar'plot
lines(r, tN, type = "h", col = "red", lwd = 2)

barplot(tN, space = 1.5, axisnames = FALSE,
        sub = "barplot(..., space= 1.5, axisnames = FALSE)")

barplot(VADeaths, plot = FALSE)
barplot(VADeaths, plot = FALSE, beside = TRUE)

mp <- barplot(VADeaths) # 既定
tot <- colMeans(VADeaths)
text(mp, tot + 3, format(tot), xpd = TRUE, col = "blue")
barplot(VADeaths, beside = TRUE,
        col = c("lightblue", "mistyrose", "lightcyan",
                "lavender", "cornsilk"),
        legend = rownames(VADeaths), ylim = c(0, 100))
title(main = "Death Rates in Virginia", font.main = 4)

hh <- t(VADeaths)[, 5:1]
mybarcol <- "gray20"
mp <- barplot(hh, beside = TRUE,
        col = c("lightblue", "mistyrose",
                "lightcyan", "lavender"),
        legend = colnames(VADeaths), ylim = c(0,100),
        main = "Death Rates in Virginia", font.main = 4,
        sub = "Faked upper 2*sigma error bars", col.sub = mybarcol,
        cex.names = 1.5)
segments(mp, hh, mp, hh + 2*sqrt(1000*hh/100), col = mybarcol, lwd = 1.5)
stopifnot(dim(mp) == dim(hh))  # corresponding matrices
mtext(side = 1, at = colMeans(mp), line = -2,
      text = paste("Mean", formatC(colMeans(hh))), col = "red")

# 陰影付きのバーの例
barplot(VADeaths, angle = 15+10*1:5, density = 20, col = "black",
        legend = rownames(VADeaths))
title(main = list("Death Rates in Virginia", font = 4))

# 輪郭：
barplot(VADeaths, border = "dark blue") % lwd = 2 << not passed
%notyet barplot(VADeaths, inside = FALSE, main = "barplot(*, inside = FALSE)")

# 対数スケール(ここではあまり意味がない)：
barplot(tN, col = heat.colors(12), log = "y")
barplot(tN, col = gray.colors(20), log = "xy")

# args.legend
barplot(height = cbind(x = c(465, 91) / 465 * 100,
                       y = c(840, 200) / 840 * 100,
                       z = c(37, 17) / 37 * 100),
        beside = FALSE,
        width = c(465, 840, 37),
        col = c(1, 2),
        legend.text = c("A", "B"),
        args.legend = list(x = "topleft"))
}
\keyword{hplot}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/barplot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{barplot}
%\alias{barplot}
%\alias{barplot.default}
%\title{Bar Plots}
%\description{
%  Creates a bar plot with vertical or horizontal bars.
%}
%\usage{
%barplot(height, \dots)
%
%\method{barplot}{default}(height, width = 1, space = NULL,
%        names.arg = NULL, legend.text = NULL, beside = FALSE,
%        horiz = FALSE, density = NULL, angle = 45,
%        col = NULL, border = par("fg"),
%        main = NULL, sub = NULL, xlab = NULL, ylab = NULL,
%        xlim = NULL, ylim = NULL, xpd = TRUE, log = "",
%        axes = TRUE, axisnames = TRUE,
%        cex.axis = par("cex.axis"), cex.names = par("cex.axis"),
%        inside = TRUE, plot = TRUE, axis.lty = 0, offset = 0,
%        add = FALSE, args.legend = NULL, \dots)
%}
%\arguments{
%  \item{height}{either a vector or matrix of values describing the
%    bars which make up the plot.  If \code{height} is a vector, the
%    plot consists of a sequence of rectangular bars with heights
%    given by the values in the vector.  If \code{height} is a matrix
%    and \code{beside} is \code{FALSE} then each bar of the plot
%    corresponds to a column of \code{height}, with the values in the
%    column giving the heights of stacked sub-bars making up the
%    bar.  If \code{height} is a matrix and \code{beside} is
%    \code{TRUE}, then the values in each column are juxtaposed
%    rather than stacked.}
%  \item{width}{optional vector of bar widths. Re-cycled to length the
%    number of bars drawn.  Specifying a single value will have no
%    visible effect unless \code{xlim} is specified.}
%  \item{space}{the amount of space (as a fraction of the average bar
%    width) left before each bar.  May be given as a single number or
%    one number per bar.  If \code{height} is a matrix and
%    \code{beside} is \code{TRUE}, \code{space} may be specified by
%    two numbers, where the first is the space between bars in the
%    same group, and the second the space between the groups.  If not
%    given explicitly, it defaults to \code{c(0,1)} if \code{height}
%    is a matrix and \code{beside} is \code{TRUE}, and to 0.2
%    otherwise.}
%  \item{names.arg}{a vector of names to be plotted below each bar or
%    group of bars.  If this argument is omitted, then the names are
%    taken from the \code{names} attribute of \code{height} if this
%    is a vector, or the column names if it is a matrix.}
%  \item{legend.text}{a vector of text used to construct a legend for
%    the plot, or a logical indicating whether a legend should be
%    included.  This is only useful when \code{height} is a matrix.
%    In that case given legend labels should correspond to the rows of
%    \code{height}; if \code{legend.text} is true, the row names of
%    \code{height} will be used as labels if they are non-null.}
%  \item{beside}{a logical value.  If \code{FALSE}, the columns of
%    \code{height} are portrayed as stacked bars, and if \code{TRUE}
%    the columns are portrayed as juxtaposed bars.}
%  \item{horiz}{a logical value.  If \code{FALSE}, the bars are drawn
%    vertically with the first bar to the left.  If \code{TRUE}, the
%    bars are drawn horizontally with the first at the bottom.}
%  \item{density}{a vector giving the density of shading lines, in
%    lines per inch, for the bars or bar components.
%    The default value of \code{NULL} means that no shading lines
%    are drawn. Non-positive values of \code{density} also inhibit the
%    drawing of shading lines.}
%  \item{angle}{the slope of shading lines, given as an angle in
%    degrees (counter-clockwise), for the bars or bar components.}
%  \item{col}{a vector of colors for the bars or bar components.
%    By default, grey is used if \code{height} is a vector, and a
%    gamma-corrected grey palette if \code{height} is a matrix.}
%  \item{border}{the color to be used for the border of the bars.
%    Use \code{border = NA} to omit borders.  If there are shading
%    lines, \code{border = TRUE} means use the same colour for
%    the border as for the shading lines.}
%  \item{main,sub}{overall and sub title for the plot.}
%  \item{xlab}{a label for the x axis.}
%  \item{ylab}{a label for the y axis.}
%  \item{xlim}{limits for the x axis.}
%  \item{ylim}{limits for the y axis.}
%  \item{xpd}{logical. Should bars be allowed to go outside region?}
%  \item{log}{string specifying if axis scales should be logarithmic; see
%    \code{\link{plot.default}}.}
%  \item{axes}{logical.  If \code{TRUE}, a vertical (or horizontal, if
%    \code{horiz} is true) axis is drawn.}
%  \item{axisnames}{logical.  If \code{TRUE}, and if there are
%    \code{names.arg} (see above), the
%    other axis is drawn (with \code{lty = 0}) and labeled.}
%  \item{cex.axis}{expansion factor for numeric axis labels.}
%  \item{cex.names}{expansion factor for axis names (bar labels).}
%  \item{inside}{logical.  If \code{TRUE}, the lines which divide
%    adjacent (non-stacked!) bars will be drawn.  Only applies when
%    \code{space = 0} (which it partly is when \code{beside = TRUE}).}
%%MM: we still have "NotYetUsed" -- the above describes S-plus 6.1 (not
%% precisely documented!) behavior!
%  \item{plot}{logical.  If \code{FALSE}, nothing is plotted.}
%  \item{axis.lty}{the graphics parameter \code{lty} applied to the axis
%    and tick marks of the categorical (default horizontal) axis.  Note
%    that by default the axis is suppressed.}
%  \item{offset}{a vector indicating how much the bars should be shifted
%    relative to the x axis.}
%  \item{add}{logical specifying if bars should be added to an already
%    existing plot; defaults to \code{FALSE}.}
%  \item{args.legend}{list of additional arguments to pass to
%    \code{\link{legend}()}; names of the list are used as argument
%    names.  Only used if \code{legend.text} is supplied.}
%  \item{\dots}{arguments to be passed to/from other methods.  For the
%    default method these can include further arguments (such as
%    \code{axes}, \code{asp} and \code{main}) and
%    \link{graphical parameters} (see \code{\link{par}}) which are passed to
%    \code{\link{plot.window}()}, \code{\link{title}()} and
%    \code{\link{axis}}.}
%}
%\details{
%  This is a generic function, it currently only has a default method.
%  A formula interface may be added eventually.
%}
%\value{
%  A numeric vector (or matrix, when \code{beside = TRUE}), say
%  \code{mp}, giving the coordinates of \emph{all} the bar midpoints
%  drawn, useful for adding to the graph.
%
%  If \code{beside} is true, use \code{colMeans(mp)} for the
%  midpoints of each \emph{group} of bars, see example.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
%}
%\seealso{
%  \code{\link{plot}(\dots, type = "h")}, \code{\link{dotchart}},
%  \code{\link{hist}}.
%}
%\examples{
%require(grDevices) # for colours
%tN <- table(Ni <- stats::rpois(100, lambda = 5))
%r <- barplot(tN, col = rainbow(20))
%#- type = "h" plotting *is* 'bar'plot
%lines(r, tN, type = "h", col = "red", lwd = 2)
%
%barplot(tN, space = 1.5, axisnames = FALSE,
%        sub = "barplot(..., space= 1.5, axisnames = FALSE)")
%
%barplot(VADeaths, plot = FALSE)
%barplot(VADeaths, plot = FALSE, beside = TRUE)
%
%mp <- barplot(VADeaths) # default
%tot <- colMeans(VADeaths)
%text(mp, tot + 3, format(tot), xpd = TRUE, col = "blue")
%barplot(VADeaths, beside = TRUE,
%        col = c("lightblue", "mistyrose", "lightcyan",
%                "lavender", "cornsilk"),
%        legend = rownames(VADeaths), ylim = c(0, 100))
%title(main = "Death Rates in Virginia", font.main = 4)
%
%hh <- t(VADeaths)[, 5:1]
%mybarcol <- "gray20"
%mp <- barplot(hh, beside = TRUE,
%        col = c("lightblue", "mistyrose",
%                "lightcyan", "lavender"),
%        legend = colnames(VADeaths), ylim = c(0,100),
%        main = "Death Rates in Virginia", font.main = 4,
%        sub = "Faked upper 2*sigma error bars", col.sub = mybarcol,
%        cex.names = 1.5)
%segments(mp, hh, mp, hh + 2*sqrt(1000*hh/100), col = mybarcol, lwd = 1.5)
%stopifnot(dim(mp) == dim(hh))  # corresponding matrices
%mtext(side = 1, at = colMeans(mp), line = -2,
%      text = paste("Mean", formatC(colMeans(hh))), col = "red")
%
%# Bar shading example
%barplot(VADeaths, angle = 15+10*1:5, density = 20, col = "black",
%        legend = rownames(VADeaths))
%title(main = list("Death Rates in Virginia", font = 4))
%
%# border :
%barplot(VADeaths, border = "dark blue") % lwd = 2 << not passed
%%notyet barplot(VADeaths, inside = FALSE, main = "barplot(*, inside = FALSE)")
%
%# log scales (not much sense here):
%barplot(tN, col = heat.colors(12), log = "y")
%barplot(tN, col = gray.colors(20), log = "xy")
%
%# args.legend
%barplot(height = cbind(x = c(465, 91) / 465 * 100,
%                       y = c(840, 200) / 840 * 100,
%                       z = c(37, 17) / 37 * 100),
%        beside = FALSE,
%        width = c(465, 840, 37),
%        col = c(1, 2),
%        legend.text = c("A", "B"),
%        args.legend = list(x = "topleft"))
%}
%\keyword{hplot}
%
\encoding{UTF8}
