% File src/library/graphics/man/contour.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{contour}
\alias{contour}
\alias{contour.default}
\title{Display Contours}
\description{
  等高線プロットを作る，もしくは既存のプロットに等高線を加える．
}
\usage{
contour(x, \dots)

\method{contour}{default}(x = seq(0, 1, length.out = nrow(z)),
        y = seq(0, 1, length.out = ncol(z)),
        z,
        nlevels = 10, levels = pretty(zlim, nlevels),
        labels = NULL,
        xlim = range(x, finite = TRUE),
        ylim = range(y, finite = TRUE),
        zlim = range(z, finite = TRUE),
        labcex = 0.6, drawlabels = TRUE, method = "flattest",
        vfont, axes = TRUE, frame.plot = axes,
        col = par("fg"), lty = par("lty"), lwd = par("lwd"),
        add = FALSE, \dots)
}
\arguments{
  \item{x, y}{\code{z} 中の値が計測されるグリッド線の位置．
    これらは増加順でなければならない．既定では 0 から 1 までの等間隔な
    値が使われる．もし \code{x} が \code{list} ならば
    その成分 \code{x$x} と \code{x$y} がそれぞれ \code{x} と \code{y} に
    対して使われる．もしリストが成分 \code{z} をもてばこれが
    \code{z} として使われる．}
  \item{z}{プロットされる値を含む行列(\code{NA} が許される)．
    便宜的に \code{x} を \code{z} の代わりに使うことが出来るのを注意しよう．}
  \item{nlevels}{\code{levels} が提供されない時，そしてその時だけ
    期待される等高線レベルの数．}
  \item{levels}{等高線がそこで描かれるレベルの数値ベクトル．}
  \item{labels}{等高線に対するラベルを与えるベクトル．
    もし \code{NULL} ならばレベルがラベルとして使われ，さもなければ
    これは \code{\link{as.character}} で強制変換される．}
  \item{labcex}{等高線のラベル付けのための \code{cex}．これは絶対サイズで
    \code{par("cex")} の倍数ではない．}
  \item{drawlabels}{論理値．もし \code{TRUE} ならば等高線が描かれる．}
  \item{method}{ラベルをどこに置くかを指定する文字列ベクトル．
    可能な値は \code{"simple"}, \code{"edge"} そして \code{"flattest"}
    (既定値)．\sQuote{詳細}節を見よ．}
  \item{vfont}{もし \code{NULL} ならば，現在のフォント族とフェイスが等高線
    ラベルに対して使われる．もし長さ 2 の文字列ベクトルならば
    Hershey ベクトルフォントが等高線ラベルとして使われる．
    ベクトルの最初の要素はタイプフェイスを選択し，二番目の要素は
    フォントインデックスを選択する(より多くの情報は \code{\link{text}} を見よ)．
    既定値は高く機能のテキスト回転を持つグラフィックスデバイス上では
    \code{NULL} で，さもなければ \code{c("sans serif", "plain")} である．}
  \item{xlim, ylim, zlim}{プロットの x, y そして z の限界．}
  \item{axes, frame.plot}{軸や枠を描くかどうかを指示する論理値．
    \code{\link{plot.default}} を見よ．}
  \item{col}{描かれる線の色．}
  \item{lty}{描かれる線の線種．}
  \item{lwd}{描かれる線の幅．}
  \item{add}{論理値．もし \code{TRUE} なら現在のプロットに付け加える．}
  \item{\dots}{\code{\link{plot.window}}, \code{\link{title}}, \code{\link{Axis}}
    そして \code{\link{box}} への追加引数で，典型的には \code{cex.axis} のような
    グラフィカルパラメータ．}
}
\details{
  \code{contour} は基本 \R には既定メソッドだけを持つ総称的関数である．

  等高線上のラベルの位置決め法は \code{"simple"}
  (プロットの端に書き，等高線に重ねる)，
  \code{"edge"} (プロットの端に書き，等高線中に埋め込み，ラベルは重なり合わない)，
  そして \code{"flattest"} (等高線の一番平坦な部分に書き，
  等高線中に埋め込み，ラベルは重なり合わない)．二番目と三番目は全ての
  等高線上にはラベルを書かないかもしれない．

  ベクトルフォントに関する情報については
  \code{\link{text}} と \code{\link{Hershey}} のヘルプを見よ．

  \code{contour} は \code{z} 行列を \code{f(x[i], y[j])} 値のテーブル
  と解釈するので，x 軸は行数で y 軸は列数で，列 1 は下部に対応することを
  注意しよう．つまり通常のテキストレイアウトを逆時計回りに 90 度
  回転する．

  別法として \CRANpkg{lattice} パッケージからの \code{\link[lattice:levelplot]{contourplot}}
  を使う．そこでは \code{\link{formula}} 表記が同じ長さの
  ベクトル \code{x}, \code{y} そして \code{z} が使われる．

  引数 \code{col} を使い軸と枠に対する限定された制御が出来る．
  \code{lwd} と \code{lty} は等高線の線を参照する
  (一般のグラフィカルパラメータとしてではなく)．これ以上の制御には
  等高線をプロットに加えるか，等高線プロットに軸と枠を加える．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  一つの等高線の最大の複雑さに対する \code{\link{options}("max.contour.segments")}．

  色で塗りつぶされた等高線には \code{\link{contourLines}}, \code{\link{filled.contour}}，
  パッケージ \CRANpkg{lattice} からの \code{\link[lattice:levelplot]{contourplot}} (そして
  \code{\link[lattice]{levelplot}})．
  更に \code{\link{image}} と \code{demo(graphics)} で起動できる
  グラフィックスデモ．
}
\examples{
require(grDevices) # 等高線のため
x <- -6:16
op <- par(mfrow = c(2, 2))
contour(outer(x, x), method = "edge", vfont = c("sans serif", "plain"))
z <- outer(x, sqrt(abs(x)), FUN = "/")
image(x, x, z)
contour(x, x, z, col = "pink", add = TRUE, method = "edge",
        vfont = c("sans serif", "plain"))
contour(x, x, z, ylim = c(1, 6), method = "simple", labcex = 1,
        xlab = quote(x[1]), ylab = quote(x[2]))
contour(x, x, z, ylim = c(-6, 6), nlev = 20, lty = 2, method = "simple",
        main = "20 levels; \"simple\" labelling method")
par(op)

## ペルシャ絨毯アート：
x <- y <- seq(-4*pi, 4*pi, len = 27)
r <- sqrt(outer(x^2, y^2, "+"))
opar <- par(mfrow = c(2, 2), mar = rep(0, 4))
for(f in pi^(0:3))
  contour(cos(r^2)*exp(-r/f),
          drawlabels = FALSE, axes = FALSE, frame = TRUE)

rx <- range(x <- 10*1:nrow(volcano))
ry <- range(y <- 10*1:ncol(volcano))
ry <- ry + c(-1, 1) * (diff(rx) - diff(ry))/2
tcol <- terrain.colors(12)
par(opar); opar <- par(pty = "s", bg = "lightcyan")
plot(x = 0, y = 0, type = "n", xlim = rx, ylim = ry, xlab = "", ylab = "")
u <- par("usr")
rect(u[1], u[3], u[2], u[4], col = tcol[8], border = "red")
contour(x, y, volcano, col = tcol[2], lty = "solid", add = TRUE,
        vfont = c("sans serif", "plain"))
title("A Topographic Map of Maunga Whau", font = 4)
abline(h = 200*0:4, v = 200*0:4, col = "lightgray", lty = 2, lwd = 0.1)

## contourLines は contour と同じ等高線を作る
plot(x = 0, y = 0, type = "n", xlim = rx, ylim = ry, xlab = "", ylab = "")
u <- par("usr")
rect(u[1], u[3], u[2], u[4], col = tcol[8], border = "red")
contour(x, y, volcano, col = tcol[1], lty = "solid", add = TRUE,
        vfont = c("sans serif", "plain"))
line.list <- contourLines(x, y, volcano)
invisible(lapply(line.list, lines, lwd=3, col=adjustcolor(2, .3)))
par(opar)
}
\keyword{hplot}
\keyword{aplot}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/contour.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{contour}
%\alias{contour}
%\alias{contour.default}
%\title{Display Contours}
%\description{
%  Create a contour plot, or add contour lines to an existing plot.
%}
%\usage{
%contour(x, \dots)
%
%\method{contour}{default}(x = seq(0, 1, length.out = nrow(z)),
%        y = seq(0, 1, length.out = ncol(z)),
%        z,
%        nlevels = 10, levels = pretty(zlim, nlevels),
%        labels = NULL,
%        xlim = range(x, finite = TRUE),
%        ylim = range(y, finite = TRUE),
%        zlim = range(z, finite = TRUE),
%        labcex = 0.6, drawlabels = TRUE, method = "flattest",
%        vfont, axes = TRUE, frame.plot = axes,
%        col = par("fg"), lty = par("lty"), lwd = par("lwd"),
%        add = FALSE, \dots)
%}
%\arguments{
%  \item{x, y}{locations of grid lines at which the values in \code{z} are
%    measured.  These must be in ascending order.  By default, equally
%    spaced values from 0 to 1 are used.  If \code{x} is a \code{list},
%    its components \code{x$x} and \code{x$y} are used for \code{x}
%    and \code{y}, respectively. If the list has component \code{z} this
%    is used for \code{z}.}
%  \item{z}{a matrix containing the values to be plotted (\code{NA}s are
%    allowed).  Note that \code{x} can be used instead of \code{z} for
%    convenience.}
%  \item{nlevels}{number of contour levels desired \bold{iff}
%    \code{levels} is not supplied.}
%  \item{levels}{numeric vector of levels at which to draw contour
%    lines.}
%  \item{labels}{a vector giving the labels for the contour lines.  If
%    \code{NULL} then the levels are used as labels, otherwise this is
%    coerced by \code{\link{as.character}}.}
%  \item{labcex}{\code{cex} for contour labelling.  This is an absolute
%    size, not a multiple of \code{par("cex")}.}
%  \item{drawlabels}{logical.  Contours are labelled if \code{TRUE}.}
%  \item{method}{character string specifying where the labels will be
%    located. Possible values are \code{"simple"}, \code{"edge"} and
%    \code{"flattest"} (the default).  See the \sQuote{Details} section.}
%  \item{vfont}{if \code{NULL}, the current font family and face are used
%    for the contour labels.  If a character vector of length 2 then
%    Hershey vector fonts are used for the contour labels. The first
%    element of the vector selects a typeface and the second element
%    selects a fontindex (see \code{\link{text}} for more information).
%    The default is \code{NULL} on graphics devices with high-quality
%    rotation of text and \code{c("sans serif", "plain")} otherwise.}
%  \item{xlim, ylim, zlim}{x-, y- and z-limits for the plot.}
%  \item{axes, frame.plot}{logical indicating whether axes or a box
%    should be drawn, see \code{\link{plot.default}}.}
%  \item{col}{color for the lines drawn.}
%  \item{lty}{line type for the lines drawn.}
%  \item{lwd}{line width for the lines drawn.}
%  \item{add}{logical. If \code{TRUE}, add to a current plot.}
%  \item{\dots}{additional arguments to \code{\link{plot.window}},
%    \code{\link{title}}, \code{\link{Axis}} and \code{\link{box}},
%    typically \link{graphical parameters} such as \code{cex.axis}.}
%}
%\details{
%  \code{contour} is a generic function with only a default method in
%  base \R.
%
%  The methods for positioning the labels on contours are \code{"simple"}
%  (draw at the edge of the plot, overlaying the contour line),
%  \code{"edge"} (draw at the edge of the plot, embedded in the contour
%  line, with no labels overlapping) and \code{"flattest"}
%  (draw on the flattest section of the contour, embedded in the
%  contour line, with no labels overlapping).  The second and third may
%  not draw a label on every contour line.
%
%  For information about vector fonts, see the
%  help for \code{\link{text}} and \code{\link{Hershey}}.
%
%  Notice that \code{contour} interprets the \code{z} matrix as a table of
%  \code{f(x[i], y[j])} values, so that the x axis corresponds to row
%  number and the y axis to column number, with column 1 at the bottom,
%  i.e.\sspace{}a 90 degree counter-clockwise rotation of the conventional textual
%  layout.
%
%  Alternatively, use \code{\link[lattice:levelplot]{contourplot}} from the
%  \CRANpkg{lattice} package where the \code{\link{formula}} notation allows
%  to use vectors \code{x}, \code{y}, and \code{z} of the same length.
%
%  There is limited control over the axes and frame as arguments
%  \code{col}, \code{lwd} and \code{lty} refer to the contour lines
%  (rather than being general \link{graphical parameters}).  For more control,
%  add contours to a plot, or add axes and frame to a contour plot.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{options}("max.contour.segments")} for the maximal
%  complexity of a single contour line.
%
%  \code{\link{contourLines}}, \code{\link{filled.contour}}
%  for color-filled contours,
%  \code{\link[lattice:levelplot]{contourplot}} (and
%  \code{\link[lattice]{levelplot}}) from package \CRANpkg{lattice}.
%  Further, \code{\link{image}} and the graphics demo which can be
%  invoked as \code{demo(graphics)}.
%}
%\examples{
%require(grDevices) # for colours
%x <- -6:16
%op <- par(mfrow = c(2, 2))
%contour(outer(x, x), method = "edge", vfont = c("sans serif", "plain"))
%z <- outer(x, sqrt(abs(x)), FUN = "/")
%image(x, x, z)
%contour(x, x, z, col = "pink", add = TRUE, method = "edge",
%        vfont = c("sans serif", "plain"))
%contour(x, x, z, ylim = c(1, 6), method = "simple", labcex = 1,
%        xlab = quote(x[1]), ylab = quote(x[2]))
%contour(x, x, z, ylim = c(-6, 6), nlev = 20, lty = 2, method = "simple",
%        main = "20 levels; \"simple\" labelling method")
%par(op)
%
%## Persian Rug Art:
%x <- y <- seq(-4*pi, 4*pi, len = 27)
%r <- sqrt(outer(x^2, y^2, "+"))
%opar <- par(mfrow = c(2, 2), mar = rep(0, 4))
%for(f in pi^(0:3))
%  contour(cos(r^2)*exp(-r/f),
%          drawlabels = FALSE, axes = FALSE, frame = TRUE)
%
%rx <- range(x <- 10*1:nrow(volcano))
%ry <- range(y <- 10*1:ncol(volcano))
%ry <- ry + c(-1, 1) * (diff(rx) - diff(ry))/2
%tcol <- terrain.colors(12)
%par(opar); opar <- par(pty = "s", bg = "lightcyan")
%plot(x = 0, y = 0, type = "n", xlim = rx, ylim = ry, xlab = "", ylab = "")
%u <- par("usr")
%rect(u[1], u[3], u[2], u[4], col = tcol[8], border = "red")
%contour(x, y, volcano, col = tcol[2], lty = "solid", add = TRUE,
%        vfont = c("sans serif", "plain"))
%title("A Topographic Map of Maunga Whau", font = 4)
%abline(h = 200*0:4, v = 200*0:4, col = "lightgray", lty = 2, lwd = 0.1)
%
%## contourLines produces the same contour lines as contour
%plot(x = 0, y = 0, type = "n", xlim = rx, ylim = ry, xlab = "", ylab = "")
%u <- par("usr")
%rect(u[1], u[3], u[2], u[4], col = tcol[8], border = "red")
%contour(x, y, volcano, col = tcol[1], lty = "solid", add = TRUE,
%        vfont = c("sans serif", "plain"))
%line.list <- contourLines(x, y, volcano)
%invisible(lapply(line.list, lines, lwd=3, col=adjustcolor(2, .3)))
%par(opar)
%}
%\keyword{hplot}
%\keyword{aplot}
%
\encoding{UTF8}
