% File src/library/graphics/man/image.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{image}
\alias{image}
\alias{image.default}
\title{Display a Color Image}
\usage{
image(x, \dots)

\method{image}{default}(x, y, z, zlim, xlim, ylim, col = heat.colors(12),
      add = FALSE, xaxs = "i", yaxs = "i", xlab, ylab,
      breaks, oldstyle = FALSE, useRaster, \dots)
}
\arguments{
  \item{x, y}{\code{z} 中の値が測られるグリッド線の位置．
    有限で，欠損値はなく，(狭義に)増加である必要がある．
    既定では 0 から 1 までの等間隔の値が使われる．
    もし \code{x} が \code{list} ならば，その成分
    \code{x$x} と \code{x$y} がそれぞれ \code{x} と \code{y} として
    使われる．もし成分 \code{z} を持てばそれが \code{z}
    として使われる．}
  \item{z}{プロットされる値を含む数値もしくは論理値行列
    (\code{NA} が許される)．
    便宜のために \code{z} の代わりに \code{x} を使うことが出来る．}
  \item{zlim}{色をプロットすべき \code{z} 値の最小値と最大値で，
    既定では \code{z} の有限値の範囲．
    与えられた色の各々がこの範囲の等間隔な区間に色を付けるために
    使われる．区間の\emph{中点}が範囲をカバーするので，
    範囲のすぐ外にある値はプロットされる．}
  \item{xlim, ylim}{プロットされた \code{x} と \code{y} の値の範囲で，
    既定では \code{x} と \code{y} の範囲．}
  \item{col}{\code{\link{rainbow}}, \code{\link{heat.colors}},
    \code{\link{topo.colors}}, \code{\link{terrain.colors}} 又は
    類似の関数で生成された色のリスト．}
  \item{add}{論理値；もし \code{TRUE} なら現在のプロットに
    付け加える(そして以下の四つの引数を無視する)．
    \code{image} は既存のグラフィックスを\sQuote{塗る}ため
    これは滅多に使われない．}    
  \item{xaxs, yaxs}{x 軸と y 軸のスタイル．既定の \code{"i"} は
    イメージに対して適切である．\code{\link{par}} を見よ．}
  \item{xlab, ylab}{それぞれが x 軸と y 軸に対するラベルを与える文字列．
    既定は \code{x} または \code{y} の\sQuote{呼出し名}，又はこれらが
    指定されていなければ \code{""}．}
  \item{breaks}{色に対する有限な数値分点のセット：
    色よりも一つ多い分点が必要で増加順でなければならない．
    ソートされていないベクトルは警告と共にソートされる．}
  \item{oldstyle}{論理値．もし真なら色区間の中点は等間隔で，
    \code{zlim[1]} と \code{zlim[2]} は中点に取られる．
    to be midpoints.
    既定値は限界間の等しい長さの色区間である．}
  \item{useRaster}{論理値；もし \code{TRUE} なら多角形の代わりに
    イメージをプロットするためにビットマップのラスター使われる．
    plot the image instead of polygons.
    その場合グリッドは規則的で無ければならず，さもなければ
    エラーが起こる．これが指定されていない場合の挙動については
    \sQuote{詳細}を見よ．}
  \item{\dots}{\code{\link{plot}} に対するグラフィックスパラメータは又，
    アスペクト比 \code{asp} と \code{axes} のように，
    又この関数の引数として渡されるかもしれない
    (\code{\link{plot.window}} を見よ)．}
}
\description{
  \code{z} 中の値に対応する色付きかグレイスケールの矩形のグリッドを作る．
  これは\emph{イメージ}としても知られている3次元又は空間的データ
  の表示に使える．これは総称的関数である．

  関数 \code{\link{heat.colors}}, \code{\link{terrain.colors}}
  そして \code{\link{topo.colors}} は，
  希望される色数を与える \code{n} を使い順序のついたデータの
  表示に適した熱スペクトル色(赤から白)と地形図色スキームを作り出す．
}
\details{
  \code{x} の長さは \code{nrow(z)+1} か \code{nrow(z)} に
  等しくなければならない．
  最初のケースでは \code{x} はセルの間の境界を指定する：
  二番目のケースでは \code{x} はセルの中点を指定する．
  同じような説明が \code{y} にも当てはまる．
  恐らく等間隔グリッドの中点を指定するのだけが意味を持つ．
  もし丁度一つの行又は列と長さが1の \code{x} か \code{y}
  を指定すると，対応する方向の全てのユーザ領域が
  埋めるられる．
  対数の \code{x} または \code{y} 軸に対してはセル間の境界が
  指定されなければならない．

  欠損値に対応する矩形はプロットされない
  (従って透明であり(\code{add = TRUE} で無い限り) \code{par("bg")}
  で塗られた既定の背景色が見え，そしてもしこれが透明ならば
  キャンバスの色が見える)．

  もし \code{breaks} が指定されると \code{zlim} は使われず，
  使われるアルゴリズムは  \code{\link{cut}} に従う．
  従って両端で閉じている最下位の区間を除いては，
  区間は右に閉じ左に開いている．

  軸(プロットされる時)は
  \code{xlim} と \code{ylim} のクラスを使う
  (従って既定では \code{x} と \code{y} のクラス)
  ：これは例えば日付はそうしたものとしてラベルが付くことを意味する．
   (\R 3.0.1 以来)

  \code{image} は行列 \code{z} を値
  \code{f(x[i], y[j])} のテーブルと解釈するので，
  x 軸は行番号に y 軸は列番号に対応することを注意しよう．
  列 1 は底になる，つまり通常の行列のプリントレイアウトの
  90度反時計周りになる．

  規則的なグリッド上の大きな \code{z} のイメージは
  \code{useRaster = TRUE} の時により効率的に表現でき，
  稀なアンチエイリアシングによる人工的な物を防ぐことができるが，
  全てのグラフィックスデバイスでサポートされていないかもしれない．
  半透明な色をサポートしないある種のデバイス(\code{postscript} と
  \code{X11(type = "Xlib")} のような)は欠損値を透明ではなく白で
  表現するかもしれず，ラスターイメージのサイズに制限があるかもしれない．
  (少なくともその既定の設定下での，ラスターイメージの表現に関する問題が
  リモートデスクトップでの \code{windows()} デバイスのユーザから
  報告されてきている．)

  PDF と PostScript 形式のグラフィックスファイルはこのオプションの
  下ではかなり小さくなる．

  グリッドは規則的で，
  もし \code{useRaster} が指定されないと，
  \code{\link{getOption}("preferRaster")} が真で，
  \code{\link{dev.capabilities}("rasterImage")$rasterImage} が
  \code{"yes"} であるか，欠損値が無くそれが \code{"non-missing"} で
  あればラスタイメージが使われる．
}

\note{
  Thomas Lumley によるオリジナルな関数に基づく．
}

\seealso{
  より見栄えが良くなるが(しかしよりモジュール化されていない)
  \code{\link{filled.contour}} 又は \code{\link{heatmap}}，
  \code{\link{contour}}；
  \code{image} の \CRANpkg{lattice} の対応物は
  \code{\link[lattice]{levelplot}}．

  \code{\link{heat.colors}}, \code{\link{topo.colors}},
  \code{\link{terrain.colors}}, \code{\link{rainbow}},
  \code{\link{hsv}}, \code{\link{par}}.

  \code{useRaster = TRUE} が現在のデバイスでサポートされているかを
  確認するには is\code{\link{dev.capabilities}}．
}

\examples{
require(grDevices) # 色のため
x <- y <- seq(-4*pi, 4*pi, len = 27)
r <- sqrt(outer(x^2, y^2, "+"))
image(z = z <- cos(r^2)*exp(-r/6), col  = gray((0:32)/32))
image(z, axes = FALSE, main = "Math can be beautiful ...",
      xlab = expression(cos(r^2) * e^{-r/6}))
contour(z, add = TRUE, drawlabels = FALSE)

# 行列として視覚化された火山データ．行列を転置し水平に裏返す必要がある
image(t(volcano)[ncol(volcano):1,])

# 火山のより見栄えの良いディスプレイ
x <- 10*(1:nrow(volcano))
y <- 10*(1:ncol(volcano))
image(x, y, volcano, col = terrain.colors(100), axes = FALSE)
contour(x, y, volcano, levels = seq(90, 200, by = 5),
        add = TRUE, col = "peru")
axis(1, at = seq(100, 800, by = 100))
axis(2, at = seq(100, 600, by = 100))
box()
title(main = "Maunga Whau Volcano", font.main = 4)
}
\keyword{hplot}
\keyword{aplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/image.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{image}
%\alias{image}
%\alias{image.default}
%\title{Display a Color Image}
%\usage{
%image(x, \dots)
%
%\method{image}{default}(x, y, z, zlim, xlim, ylim, col = heat.colors(12),
%      add = FALSE, xaxs = "i", yaxs = "i", xlab, ylab,
%      breaks, oldstyle = FALSE, useRaster, \dots)
%}
%\arguments{
%  \item{x, y}{locations of grid lines at which the values in \code{z} are
%    measured.  These must be finite, non-missing and in (strictly)
%    ascending order.  By default, equally
%    spaced values from 0 to 1 are used.  If \code{x} is a \code{list},
%    its components \code{x$x} and \code{x$y} are used for \code{x}
%    and \code{y}, respectively. If the list has component \code{z} this
%    is used for \code{z}.}
%  \item{z}{a numeric or logical matrix containing the values to be plotted
%    (\code{NA}s are allowed).  Note that \code{x} can be used instead
%    of \code{z} for convenience.}
%  \item{zlim}{the minimum and maximum \code{z} values for which colors
%    should be plotted, defaulting to the range of the finite values of
%    \code{z}. Each of the given colors will be used to color an
%    equispaced interval of this range. The \emph{midpoints} of the
%    intervals cover the range, so that values just outside the range
%    will be plotted.}
%  \item{xlim, ylim}{ranges for the plotted \code{x} and \code{y} values,
%    defaulting to the ranges of \code{x} and \code{y}.}
%  \item{col}{a list of colors such as that generated by
%    \code{\link{rainbow}}, \code{\link{heat.colors}},
%    \code{\link{topo.colors}}, \code{\link{terrain.colors}} or similar
%    functions.}
%  \item{add}{logical; if \code{TRUE}, add to current plot (and disregard
%    the following four arguments).  This is rarely useful because
%    \code{image} \sQuote{paints} over existing graphics.}
%  \item{xaxs, yaxs}{style of x and y axis.  The default \code{"i"} is
%    appropriate for images.  See \code{\link{par}}.}
%  \item{xlab, ylab}{each a character string giving the labels for the x and
%    y axis.  Default to the \sQuote{call names} of \code{x} or \code{y}, or to
%    \code{""} if these were unspecified.}
%  \item{breaks}{a set of finite numeric breakpoints for the colours:
%    must have one more breakpoint than colour and be in increasing
%    order.  Unsorted vectors will be sorted, with a warning.}
%  \item{oldstyle}{logical. If true the midpoints of the colour intervals
%    are equally spaced, and \code{zlim[1]} and \code{zlim[2]} were taken
%    to be midpoints.  The default is to have colour intervals of equal
%    lengths between the limits.}
%  \item{useRaster}{logical; if \code{TRUE} a bitmap raster is used to
%    plot the image instead of polygons. The grid must be regular in that
%    case, otherwise an error is raised.   For the behaviour when this is
%    not specified, see \sQuote{Details}.}
%  \item{\dots}{\link{graphical parameters} for \code{\link{plot}} may also be
%    passed as arguments to this function, as can the plot aspect ratio
%    \code{asp} and \code{axes} (see \code{\link{plot.window}}).}
%}
%\description{
%  Creates a grid of colored or gray-scale rectangles with colors
%  corresponding to the values in \code{z}.  This can be used to display
%  three-dimensional or spatial data aka \emph{images}.
%  This is a generic function.
%
%  The functions \code{\link{heat.colors}}, \code{\link{terrain.colors}}
%  and \code{\link{topo.colors}} create heat-spectrum (red to white) and
%  topographical color schemes suitable for displaying ordered data, with
%  \code{n} giving the number of colors desired.
%}
%\details{
%  The length of \code{x} should be equal to the \code{nrow(z)+1} or
%  \code{nrow(z)}.  In the first case \code{x} specifies the boundaries
%  between the cells: in the second case \code{x} specifies the midpoints
%  of the cells.  Similar reasoning applies to \code{y}.  It probably
%  only makes sense to specify the midpoints of an equally-spaced
%  grid.  If you specify just one row or column and a length-one \code{x}
%  or \code{y}, the whole user area in the corresponding direction is
%  filled. For logarithmic \code{x} or \code{y} axes the boundaries between
%  cells must be specified.
%
%  Rectangles corresponding to missing values are not plotted (and so are
%  transparent and (unless \code{add = TRUE}) the default background
%  painted in \code{par("bg")} will show though and if that is
%  transparent, the canvas colour will be seen).
%
%  If \code{breaks} is specified then \code{zlim} is unused and the
%  algorithm used follows \code{\link{cut}}, so intervals are closed on
%  the right and open on the left except for the lowest interval which is
%  closed at both ends.
%
%  The axes (where plotted) make use of the classes of \code{xlim} and
%  \code{ylim} (and hence by default the classes of \code{x} and
%  \code{y}): this will mean that for example dates are labelled as
%  such.  (As from \R 3.0.1.)
%
%  Notice that \code{image} interprets the \code{z} matrix as a table of
%  \code{f(x[i], y[j])} values, so that the x axis corresponds to row
%  number and the y axis to column number, with column 1 at the bottom,
%  i.e.\sspace{}a 90 degree counter-clockwise rotation of the conventional
%  printed layout of a matrix.
%
%  Images for large \code{z} on a regular grid are rendered more
%  efficiently with \code{useRaster = TRUE} and can prevent rare
%  anti-aliasing artifacts, but may not be supported by all graphics
%  devices.  Some devices (such as \code{postscript} and \code{X11(type =
%  "Xlib")}) which do not support semi-transparent colours may emit
%  missing values as white rather than transparent, and there may be
%  limitations on the size of a raster image.  (Problems with the
%  rendering of raster images have been reported by users of
%  \code{windows()} devices under Remote Desktop, at least under its
%  default settings.)
%
%  The graphics files in PDF and PostScript can be much smaller under
%  this option.
%
%  If \code{useRaster} is not specified, raster images are used when the
%  \code{\link{getOption}("preferRaster")} is true, the grid is regular
%  and either \code{\link{dev.capabilities}("rasterImage")$rasterImage}
%  is \code{"yes"} or it is \code{"non-missing"} and there are no missing
%  values.
%}
%
%\note{
%  Originally based on a function by Thomas Lumley.
%}
%
%\seealso{
%  \code{\link{filled.contour}} or \code{\link{heatmap}} which can
%  look nicer (but are less modular),
%  \code{\link{contour}};
%  The \CRANpkg{lattice} equivalent of \code{image} is
%  \code{\link[lattice]{levelplot}}.
%
%  \code{\link{heat.colors}}, \code{\link{topo.colors}},
%  \code{\link{terrain.colors}}, \code{\link{rainbow}},
%  \code{\link{hsv}}, \code{\link{par}}.
%
%  \code{\link{dev.capabilities}} to see if \code{useRaster = TRUE} is
%  supported on the current device.
%}
%
%\examples{
%require(grDevices) # for colours
%x <- y <- seq(-4*pi, 4*pi, len = 27)
%r <- sqrt(outer(x^2, y^2, "+"))
%image(z = z <- cos(r^2)*exp(-r/6), col  = gray((0:32)/32))
%image(z, axes = FALSE, main = "Math can be beautiful ...",
%      xlab = expression(cos(r^2) * e^{-r/6}))
%contour(z, add = TRUE, drawlabels = FALSE)
%
%# Volcano data visualized as matrix. Need to transpose and flip
%# matrix horizontally.
%image(t(volcano)[ncol(volcano):1,])
%
%# A prettier display of the volcano
%x <- 10*(1:nrow(volcano))
%y <- 10*(1:ncol(volcano))
%image(x, y, volcano, col = terrain.colors(100), axes = FALSE)
%contour(x, y, volcano, levels = seq(90, 200, by = 5),
%        add = TRUE, col = "peru")
%axis(1, at = seq(100, 800, by = 100))
%axis(2, at = seq(100, 600, by = 100))
%box()
%title(main = "Maunga Whau Volcano", font.main = 4)
%}
%\keyword{hplot}
%\keyword{aplot}
%
%\encoding{UTF8}
%