% File src/library/graphics/man/pairs.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{pairs}
\alias{pairs}
\alias{pairs.default}
\alias{pairs.formula}

\title{Scatterplot Matrices}
\description{
  散布図の行列を作る．
}
\usage{
pairs(x, \dots)

\method{pairs}{formula}(formula, data = NULL, \dots, subset,
      na.action = stats::na.pass)

\method{pairs}{default}(x, labels, panel = points, \dots,
      horInd = 1:nc, verInd = 1:nc,
      lower.panel = panel, upper.panel = panel,
      diag.panel = NULL, text.panel = textPanel,
      label.pos = 0.5 + has.diag/3, line.main = 3,
      cex.labels = NULL, font.labels = 1,
      row1attop = TRUE, gap = 1, log = "")
}
\arguments{
  \item{x}{行列又はデータフレームの数値列としての点の座標．
    論理値と因子の列は \code{\link{data.matrix}} が行うのと
    同様に数値に変換される．
  }
  \item{formula}{\code{~ x + y + z} の様な公式．各項は対プロット中の
    個別の変数を与えるので，項は数値ベクトルでなければならない．
    (応答変数は別の変数として解釈されるが，
    特別には処理されず使うと混乱を招く．}
  \item{data}{\code{formula} 中の変数がそこから取られるべきデータフレーム(又はリスト)．}
  \item{subset}{プロットに使われる観測値の部分集合を指定するオプションのベクトル．}
  \item{na.action}{データが \code{NA} を含む時何が起こるべきか指示する関数．
    既定では欠損値をパネル関数に渡すが，\code{na.action = na.omit} は
    任意の変数中の欠損値を持つ全てのケースを完全に取り除く．}
  \item{labels}{変数の名前．}
  \item{panel}{ディスプレイの各パネルの内容をプロットするのに
    使われる \code{function(x, y, \dots)}．}
  \item{\dots}{メソッドに・から渡される引数．

    同様にグラフィックスパラメータは \code{main} のような
    \code{plot} への詰め込み引数として使うことが出来る．
    \code{par("oma")} は指定されない限り適当に設定される．
  }
  \item{horInd, verInd}{それぞれ水平と垂直軸上にプロットされる変数の
    (数値)添字．}
  \item{lower.panel, upper.panel}{対角部分のそれぞれ下と上に使われる
    個別のパネル関数(又は \code{NULL})．}
  \item{diag.panel}{対角部分に適用されるオプションの
    \code{function(x, \dots)}．}
  \item{text.panel}{対角部分に適用されるオプションの
    \code{function(x, y, labels, cex, font, \dots)}．}
  \item{label.pos}{テキストパネル中のラベルの \code{y} 位置．}
  \item{line.main}{もし \code{main} が指定されると，\code{line.main} は
    \code{line} 引数をタイトルを描く \code{\link{mtext}()} に渡す．
    \code{line.main} を変更するときは \code{oma} を指定したいかもしれない．}
  \item{cex.labels, font.labels}{テキストパネルに対するグラフィックスパラメータ．}
  \item{row1attop}{論理値．レイアウトは行1がトップにある行列風か，
    又は行1が底部にあるグラフ風か?}
  \item{gap}{副プロット間の距離でマージン行単位．}
  \item{log}{対数軸が使われるべきかどうかを指示する文字列：
    \code{\link{plot.default}} を見よ．\code{log = "xy"} は全ての変数に対して
    対数軸を指定する．}
}
\details{
  \eqn{ij} 番目の散布図は \code{x[,j]} に対してプロットされた \code{x[,i]}
  を含む．散布図は全く異なって見える何かであるパネル関数を設定することで
  カスタム化出来る．非対角パネル関数は \code{x} の適当な列を
  \code{x} と \code{y} として渡される：
  対角パネル関数は(もしあれば)は単一の列を渡され，そして \code{text.panel} 関数は
  単一の \code{(x, y)} 位置と列名を受け取る．
  これらのパネル関数のどれかを \code{\link{NULL}} に設定することは
  そこに何も描かないことと同値である．

  グラフィカルパラメータ \code{pch} と \code{col} はプロット中で使われる
  プロットシンボルと色のベクトルを指定するのに使うことが出来る．

  グラフィカルパラメータ \code{oma} は引数として与えられなければ
  \code{pairs.default} で設定される．

  パネル関数は新しいプロットを開始しようとすべきではなく，
  単に与えられた座標系の中でプロットすべきである：
  従って \code{plot} と \code{boxplot} はパネル関数ではない．

  既定では，欠損値はパネル関数に渡され，しばしばパネルの内部で無視される．
  しかしながら，公式メソッドと \code{na.action = na.omit} に対しては，
  変数のどれかに対して欠損値を含む全てのケースは完全に除外される
  (スケールが選択された時を含む)．
  
  引数 \code{horInd} と \code{verInd} は \R 3.2.0 で導入された．
  もし同じ値が与えられると，それらは変数の選択又は再並べ替えに使うことが出来る：
  連続する値の異なった範囲があると
  それらは完全な対プロットの矩形のプロットに使うことが出来る；
  後者の場合\sQuote{対角}とは完全なプロットの対角部分を参照する．
}
\author{
  \R 1.0.0 に対する拡張は Dr. Jens Oehlschlaegel-Akiyoshi と R-core
  メンバーの貢献による．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
pairs(iris[1:4], main = "Anderson's Iris Data -- 3 species",
      pch = 21, bg = c("red", "green3", "blue")[unclass(iris$Species)])

## 公式メソッド
pairs(~ Fertility + Education + Catholic, data = swiss,
      subset = Education < 20, main = "Swiss data, Education < 20")

pairs(USJudgeRatings)
## 下三角部分だけを示す(and suppress labeling for whatever reason):
pairs(USJudgeRatings, text.panel = NULL, upper.panel = NULL)

## 対角線にヒストグラムを置く
panel.hist <- function(x, ...)
{
    usr <- par("usr"); on.exit(par(usr))
    par(usr = c(usr[1:2], 0, 1.5) )
    h <- hist(x, plot = FALSE)
    breaks <- h$breaks; nB <- length(breaks)
    y <- h$counts; y <- y/max(y)
    rect(breaks[-nB], 0, breaks[-1], y, col = "cyan", ...)
}
pairs(USJudgeRatings[1:5], panel = panel.smooth,
      cex = 1.5, pch = 24, bg = "light blue",
      diag.panel = panel.hist, cex.labels = 2, font.labels = 2)

## (絶対)相関を上部のパネルに置く，サイズは相関に比例する．
panel.cor <- function(x, y, digits = 2, prefix = "", cex.cor, ...)
{
    usr <- par("usr"); on.exit(par(usr))
    par(usr = c(0, 1, 0, 1))
    r <- abs(cor(x, y))
    txt <- format(c(r, 0.123456789), digits = digits)[1]
    txt <- paste0(prefix, txt)
    if(missing(cex.cor)) cex.cor <- 0.8/strwidth(txt)
    text(0.5, 0.5, txt, cex = cex.cor * r)
}
pairs(USJudgeRatings, lower.panel = panel.smooth, upper.panel = panel.cor)

pairs(iris[-5], log = "xy") # 全ての変数を対数スケールでプロット
pairs(iris, log = 1:4, # log the first four
      main = "Lengths and Widths in [log]", line.main=1.5, oma=c(2,2,3,2))
}
\keyword{hplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/pairs.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{pairs}
%\alias{pairs}
%\alias{pairs.default}
%\alias{pairs.formula}
%
%\title{Scatterplot Matrices}
%\description{
%  A matrix of scatterplots is produced.
%}
%\usage{
%pairs(x, \dots)
%
%\method{pairs}{formula}(formula, data = NULL, \dots, subset,
%      na.action = stats::na.pass)
%
%\method{pairs}{default}(x, labels, panel = points, \dots,
%      horInd = 1:nc, verInd = 1:nc,
%      lower.panel = panel, upper.panel = panel,
%      diag.panel = NULL, text.panel = textPanel,
%      label.pos = 0.5 + has.diag/3, line.main = 3,
%      cex.labels = NULL, font.labels = 1,
%      row1attop = TRUE, gap = 1, log = "")
%}
%\arguments{
%  \item{x}{the coordinates of points given as numeric columns of a
%    matrix or data frame.  Logical and factor columns are converted to
%    numeric in the same way that \code{\link{data.matrix}} does.
%  }
%  \item{formula}{a formula, such as \code{~ x + y + z}.  Each term will
%    give a separate variable in the pairs plot, so terms should be
%    numeric vectors.  (A response will be interpreted as another
%    variable, but not treated specially, so it is confusing to use one.)}
%  \item{data}{a data.frame (or list) from which the variables in
%    \code{formula} should be taken.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used for plotting.}
%  \item{na.action}{a function which indicates what should happen
%    when the data contain \code{NA}s.  The default is to pass missing
%    values on to the panel functions, but \code{na.action = na.omit}
%    will cause cases with missing values in any of the variables to be
%    omitted entirely.}
%  \item{labels}{the names of the variables.}
%  \item{panel}{\code{function(x, y, \dots)} which is used to plot
%    the contents of each panel of the display.}
%  \item{\dots}{
%    arguments to be passed to or from methods.
%
%    Also, \link{graphical parameters} can be given as can arguments to
%    \code{plot} such as \code{main}.  \code{par("oma")} will be set
%    appropriately unless specified.
%  }
%  \item{horInd, verInd}{The (numerical) indices of the variables to be
%    plotted on the horizontal and vertical axes respectively.}
%  \item{lower.panel, upper.panel}{separate panel functions (or
%    \code{NULL}) to be used below and above the diagonal respectively.}
%  \item{diag.panel}{optional \code{function(x, \dots)} to be
%    applied on the diagonals.}
%  \item{text.panel}{optional \code{function(x, y, labels, cex,
%      font, \dots)} to be applied on the diagonals.}
%  \item{label.pos}{\code{y} position of labels in the text panel.}
%  \item{line.main}{if \code{main} is specified, \code{line.main} gives
%    the \code{line} argument to \code{\link{mtext}()} which draws the
%    title.  You may want to specify \code{oma} when changing \code{line.main}.}
%  \item{cex.labels, font.labels}{graphics parameters for the text panel.}
%  \item{row1attop}{logical. Should the layout be matrix-like with row 1
%    at the top, or graph-like with row 1 at the bottom?}
%  \item{gap}{distance between subplots, in margin lines.}
%  \item{log}{a character string indicating if logarithmic axes are to be
%    used: see \code{\link{plot.default}}.  \code{log = "xy"} specifies
%    logarithmic axes for all variables.}
%}
%\details{
%  The \eqn{ij}th scatterplot contains \code{x[,i]} plotted against
%  \code{x[,j]}.  The scatterplot can be customised by setting panel
%  functions to appear as something completely different. The
%  off-diagonal panel functions are passed the appropriate columns of
%  \code{x} as \code{x} and \code{y}: the diagonal panel function (if
%  any) is passed a single column, and the \code{text.panel} function is
%  passed a single \code{(x, y)} location and the column name.
%  Setting some of these panel functions to \code{\link{NULL}} is
%  equivalent to \emph{not} drawing anything there.
%
%  The \link{graphical parameters} \code{pch} and \code{col} can be used
%  to specify a vector of plotting symbols and colors to be used in the
%  plots.
%
%  The \link{graphical parameter} \code{oma} will be set by
%  \code{pairs.default} unless supplied as an argument.
%
%  A panel function should not attempt to start a new plot, but just plot
%  within a given coordinate system: thus \code{plot} and \code{boxplot}
%  are not panel functions.
%
%  By default, missing values are passed to the panel functions and will
%  often be ignored within a panel.  However, for the formula method and
%  \code{na.action = na.omit}, all cases which contain a missing values for
%  any of the variables are omitted completely (including when the scales
%  are selected).
%  
%  Arguments \code{horInd} and \code{verInd} were introduced in \R
%  3.2.0. If given the same value they can be used to select or re-order
%  variables: with different ranges of consecutive values they can be
%  used to plot rectangular windows of a full pairs plot; in the latter
%  case \sQuote{diagonal} refers to the diagonal of the full plot. 
%}
%\author{
%  Enhancements for \R 1.0.0 contributed by Dr. Jens
%  Oehlschlaegel-Akiyoshi and R-core members.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%pairs(iris[1:4], main = "Anderson's Iris Data -- 3 species",
%      pch = 21, bg = c("red", "green3", "blue")[unclass(iris$Species)])
%
%## formula method
%pairs(~ Fertility + Education + Catholic, data = swiss,
%      subset = Education < 20, main = "Swiss data, Education < 20")
%
%pairs(USJudgeRatings)
%## show only lower triangle (and suppress labeling for whatever reason):
%pairs(USJudgeRatings, text.panel = NULL, upper.panel = NULL)
%
%## put histograms on the diagonal
%panel.hist <- function(x, ...)
%{
%    usr <- par("usr"); on.exit(par(usr))
%    par(usr = c(usr[1:2], 0, 1.5) )
%    h <- hist(x, plot = FALSE)
%    breaks <- h$breaks; nB <- length(breaks)
%    y <- h$counts; y <- y/max(y)
%    rect(breaks[-nB], 0, breaks[-1], y, col = "cyan", ...)
%}
%pairs(USJudgeRatings[1:5], panel = panel.smooth,
%      cex = 1.5, pch = 24, bg = "light blue",
%      diag.panel = panel.hist, cex.labels = 2, font.labels = 2)
%
%## put (absolute) correlations on the upper panels,
%## with size proportional to the correlations.
%panel.cor <- function(x, y, digits = 2, prefix = "", cex.cor, ...)
%{
%    usr <- par("usr"); on.exit(par(usr))
%    par(usr = c(0, 1, 0, 1))
%    r <- abs(cor(x, y))
%    txt <- format(c(r, 0.123456789), digits = digits)[1]
%    txt <- paste0(prefix, txt)
%    if(missing(cex.cor)) cex.cor <- 0.8/strwidth(txt)
%    text(0.5, 0.5, txt, cex = cex.cor * r)
%}
%pairs(USJudgeRatings, lower.panel = panel.smooth, upper.panel = panel.cor)
%
%pairs(iris[-5], log = "xy") # plot all variables on log scale
%pairs(iris, log = 1:4, # log the first four
%      main = "Lengths and Widths in [log]", line.main=1.5, oma=c(2,2,3,2))
%}
%\keyword{hplot}
%
%\encoding{UTF8}
%