% File src/library/graphics/man/plotdefault.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{plot.default}
\alias{plot.default}
\title{The Default Scatterplot Function}
\description{
  現在アクティブなグラフィックスウィンドに軸やタイトル付きの散布図を描く．
}
\usage{
\method{plot}{default}(x, y = NULL, type = "p",  xlim = NULL, ylim = NULL,
     log = "", main = NULL, sub = NULL, xlab = NULL, ylab = NULL,
     ann = par("ann"), axes = TRUE, frame.plot = axes,
     panel.first = NULL, panel.last = NULL, asp = NA, \dots)
}
\arguments{
  \item{x, y}{
    \code{x} と \code{y} 引数はプロットの x と y 座標を提供する．
    任意の合理的な座標の定義が受け入れられる．詳細は \code{\link{xy.coords}} を
    見よ．もし別個に与えられると，それらは同じ長さでなければならない．}
  \item{type}{希望のプロットのタイプを与える位置文字の文字列．
  1-character string giving the type of plot desired.  The
    以下の値が可能である，詳細は \code{\link{plot}} を見よ：
    \code{"p"} 点，\code{"l"} 線，
    \code{"b"} 点と線，
    \code{"c"} 線で結ばれた空の点，
    \code{"o"} 線と点を重ね描き，
    \code{"s"} と \code{"S"} 階段ステップ，そして
    \code{"h"} ヒストグラム風の垂直線．最後に
    \code{"n"} は点も線も描かない．}
  \item{xlim}{プロットの x 限界 (x1, x2)．
    \code{x1 > x2} が許され\sQuote{逆向きの軸}になる．

    既定値の \code{NULL} はプロットされる有限値の範囲を指示する．}
  \item{ylim}{プロットの y 限界．}
  \item{log}{
    もし x 軸が対数軸ならば \code{"x"} を含む文字列，
    もし y 軸が対数軸ならば \code{"y"} を含む文字列，
    そしてもし両方の軸が対数軸ならば \code{"xy"} か \code{"yx"} を含む文字列．}

  \item{main}{プロットの主タイトル，\code{\link{title}} も見よ．}
  \item{sub}{プロットの副タイトル．}
  \item{xlab}{x 軸に対するラベルで，既定値は \code{x} の説明．}
  \item{ylab}{y 軸に対するラベルで，既定値は \code{y} の説明．}

  \item{ann}{
    既定の注釈(タイトルと x 及び y 軸ラベル)がプロットに現れるかどうかを
    指示する論理値．}
  \item{axes}{
    両方の軸がプロットに描かれるべきかどうかを指示する論理値．
    グラフィカルパラメータ \code{"xaxt"} 又は \code{"yaxt"}
    の使用は軸の丁度一つを抑制する．}
  \item{frame.plot}{プロットの周りにボックスを描くべきかどうかを指示する論理値．}

  \item{panel.first}{
    プロット軸が設定された後であるが他のプロットが実行される前に
    評価される\sQuote{表現式}．
    これは背景グリッドや散布図の平滑化を描くために有用である．
    これは遅延評価されることを注意する：
    この引数を \code{plot} メソッドに引き渡すことはそれが早まって評価される
    可能性があるため失敗するかもしれない．}

  \item{panel.last}{
    プロットが描かれた後であるが軸やタイトルそしてボックスが描かれる
    前に評価される表現式．
    \code{panel.first} に関するコメントを見よ．}

  \item{asp}{アスペクト比 \eqn{y/x}，\code{\link{plot.window}} を見よ．}
  \item{\dots}{他のグラフィカルパラメータ(\code{\link{par}} と
    下の\sQuote{詳細}節を見よ)．}
}
\details{
  普通使われるグラフィックスパラメータは：
  \describe{
    \item{\code{col}}{線と点に対する色．
      各点がそれ自体の色を持つように複数の色を与えることができる．
      もし点の数よりも色数が少なければそれらは標準的な仕方でリサイクルされる．
      線は全て最初に指定された色で描かれる．}
    \item{\code{bg}}{オープンなプロットシンボルに対する背景色のベクトル，
      \code{\link{points}} を見よ．
       注意：これは
      \code{\link{par}("bg")} とは同じでは\bold{無い}．}
    \item{\code{pch}}{プロット文字又はシンボルのベクトル：
      \code{\link{points}} を見よ．}
    \item{\code{cex}}{
      プロット用の文字とシンボルが既定値に対してそれだけスケール化される数値ベクトル．
      これは \code{\link{par}("cex")} の倍数になる．
      \code{NULL} と \code{NA} は \code{1.0} に等しい．
      これは注釈には適用されないことを注意する：下を見よ．}
    \item{\code{cex.main}, \code{col.lab}, \code{font.sub} 
      等}{主と副タイトルそして軸注釈に対する設定，
      \code{\link{title}} と \code{\link{par}} を見よ．}
    \item{\code{lwd}}{先の幅のベクトル，\code{\link{par}} を見よ．}
  }
}
\note{
  \code{panel.first} と \code{panel.last} の存在は歴史的な混乱である：
  既定のプロットは \code{\link{pairs}} プロットとは異なり\sQuote{パネル}を持たない．
 一層の制御のためには低水準プロット関数を使う：
  \code{plot.default} は順番に
  \code{\link{plot.new}}, \code{\link{plot.window}},
  \code{\link{plot.xy}}, \code{\link{axis}}, \code{\link{box}} そして
  \code{\link{title}} の幾つかを呼び出し，
  プロットはこれらを個別に呼び出すか，
  もしくは \code{plot(type = "n")} を呼び出し追加の要素を加えることで構築できる．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Cleveland, W. S. (1985)
  \emph{The Elements of Graphing Data.}
  Monterey, CA: Wadsworth.

  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
}
\seealso{
  \code{\link{plot}}, \code{\link{plot.window}}, \code{\link{xy.coords}}.
  数千の点に対しては代わりに
  \code{\link{smoothScatter}} の使用を考慮しよう．
}
\examples{
Speed <- cars$speed
Distance <- cars$dist
plot(Speed, Distance, panel.first = grid(8, 8),
     pch = 0, cex = 1.2, col = "blue")
plot(Speed, Distance,
     panel.first = lines(stats::lowess(Speed, Distance), lty = "dashed"),
     pch = 0, cex = 1.2, col = "blue")

## 異なったプロットタイプを示す
x <- 0:12
y <- sin(pi/5 * x)
op <- par(mfrow = c(3,3), mar = .1+ c(2,2,3,1))
for (tp in c("p","l","b",  "c","o","h",  "s","S","n")) {
   plot(y ~ x, type = tp, main = paste0("plot(*, type = \"", tp, "\")"))
   if(tp == "S") {
      lines(x, y, type = "s", col = "red", lty = 2)
      mtext("lines(*, type = \"s\", ...)", col = "red", cex = 0.8)
   }
}
par(op)

##--- カスタム化された軸を持つ両対数プロット
lx <- seq(1, 5, length = 41)
yl <- expression(e^{-frac(1,2) * {log[10](x)}^2})
y <- exp(-.5*lx^2)
op <- par(mfrow = c(2,1), mar = par("mar")+c(0,1,0,0))
plot(10^lx, y, log = "xy", type = "l", col = "purple",
     main = "Log-Log plot", ylab = yl, xlab = "x")
plot(10^lx, y, log = "xy", type = "o", pch = ".", col = "forestgreen",
     main = "Log-Log plot with custom axes", ylab = yl, xlab = "x",
     axes = FALSE, frame.plot = TRUE)
my.at <- 10^(1:5)
axis(1, at = my.at, labels = formatC(my.at, format = "fg"))
at.y <- 10^(-5:-1)
axis(2, at = at.y, labels = formatC(at.y, format = "fg"), col.axis = "red")
par(op)
}
\keyword{hplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/plotdefault.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{plot.default}
%\alias{plot.default}
%\title{The Default Scatterplot Function}
%\description{
%  Draw a scatter plot with decorations such as axes and titles
%  in the active graphics window.
%}
%\usage{
%\method{plot}{default}(x, y = NULL, type = "p",  xlim = NULL, ylim = NULL,
%     log = "", main = NULL, sub = NULL, xlab = NULL, ylab = NULL,
%     ann = par("ann"), axes = TRUE, frame.plot = axes,
%     panel.first = NULL, panel.last = NULL, asp = NA, \dots)
%}
%\arguments{
%  \item{x, y}{the \code{x} and \code{y} arguments provide the x and y
%    coordinates for the plot.  Any reasonable way of defining the
%    coordinates is acceptable.  See the function \code{\link{xy.coords}}
%    for details.  If supplied separately, they must be of the same length.}
%  \item{type}{1-character string giving the type of plot desired.  The
%    following values are possible, for details, see \code{\link{plot}}:
%    \code{"p"} for points, \code{"l"} for lines,
%    \code{"b"} for both points and lines,
%    \code{"c"} for empty points joined by lines,
%    \code{"o"} for overplotted points and lines,
%    \code{"s"} and \code{"S"} for stair steps and
%    \code{"h"} for histogram-like vertical lines.  Finally,
%    \code{"n"} does not produce any points or lines.}
%  \item{xlim}{the x limits (x1, x2) of the plot.  Note that \code{x1 > x2}
%    is allowed and leads to a \sQuote{reversed axis}.
%
%    The default value, \code{NULL}, indicates that the range of the
%    \link{finite} values to be plotted should be used.}
%  \item{ylim}{the y limits of the plot.}
%  \item{log}{a character string which contains \code{"x"} if the x axis
%    is to be logarithmic, \code{"y"} if the y axis is to be logarithmic
%    and \code{"xy"} or \code{"yx"} if both axes are to be logarithmic.}
%
%  \item{main}{a main title for the plot, see also \code{\link{title}}.}
%  \item{sub}{a sub title for the plot.}
%  \item{xlab}{a label for the x axis, defaults to a description of \code{x}.}
%  \item{ylab}{a label for the y axis, defaults to a description of \code{y}.}
%
%  \item{ann}{a logical value indicating whether the default annotation
%    (title and x and y axis labels) should appear on the plot.}
%  \item{axes}{a logical value indicating whether both axes should be drawn on
%    the plot.  Use \link{graphical parameter} \code{"xaxt"} or \code{"yaxt"}
%    to suppress just one of the axes.}
%  \item{frame.plot}{a logical indicating whether a box should be drawn
%    around the plot.}
%
%  \item{panel.first}{an \sQuote{expression} to be evaluated after the
%    plot axes are set up but before any plotting takes place.  This can
%    be useful for drawing background grids or scatterplot smooths.  Note
%    that this works by lazy evaluation: passing this argument from other
%    \code{plot} methods may well not work since it may be evaluated too
%    early.}
%
%  \item{panel.last}{an expression to be evaluated after plotting has
%    taken place but before the axes, title and box are added.  See the
%    comments about \code{panel.first}.}
%
%  \item{asp}{the \eqn{y/x} aspect ratio, see \code{\link{plot.window}}.}
%  \item{\dots}{other \link{graphical parameters} (see \code{\link{par}} and
%    section \sQuote{Details} below).}
%}
%\details{
%  Commonly used \link{graphical parameters} are:
%  \describe{
%    \item{\code{col}}{The colors for lines and points.  Multiple colors can be
%      specified so that each point can be given its own color.  If there
%      are fewer colors than points they are recycled in the standard
%      fashion.  Lines will all be plotted in the first colour specified.}
%    \item{\code{bg}}{a vector of background colors for open plot symbols, see
%      \code{\link{points}}.  Note: this is \bold{not} the same setting
%      as \code{\link{par}("bg")}.}
%    \item{\code{pch}}{a vector of plotting characters or symbols:
%      see \code{\link{points}}.}
%    \item{\code{cex}}{a numerical vector giving the amount by which
%      plotting characters and symbols should be scaled relative to the
%      default.  This works as a multiple of \code{\link{par}("cex")}.
%      \code{NULL} and \code{NA} are equivalent to \code{1.0}.  Note that
%      this does not affect annotation: see below.}
%    \item{\code{lty}}{a vector of line types, see \code{\link{par}}.}
%    \item{\code{cex.main}, \code{col.lab}, \code{font.sub},
%      etc}{settings for main- and sub-title and axis annotation, see
%      \code{\link{title}} and \code{\link{par}}.}
%    \item{\code{lwd}}{a vector of line widths, see \code{\link{par}}.}
%  }
%}
%\note{
%  The presence of \code{panel.first} and \code{panel.last} is a
%  historical anomaly: default plots do not have \sQuote{panels}, unlike
%  e.g.\sspace{}\code{\link{pairs}} plots.  For more control, use lower-level
%  plotting functions: \code{plot.default} calls in turn some of
%  \code{\link{plot.new}}, \code{\link{plot.window}},
%  \code{\link{plot.xy}}, \code{\link{axis}}, \code{\link{box}} and
%  \code{\link{title}}, and plots can be built up by calling these
%  individually, or by calling \code{plot(type = "n")} and adding further
%  elements.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Cleveland, W. S. (1985)
%  \emph{The Elements of Graphing Data.}
%  Monterey, CA: Wadsworth.
%
%  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
%}
%\seealso{
%  \code{\link{plot}}, \code{\link{plot.window}}, \code{\link{xy.coords}}.
%  For thousands of points, consider using \code{\link{smoothScatter}}
%  instead.
%}
%\examples{
%Speed <- cars$speed
%Distance <- cars$dist
%plot(Speed, Distance, panel.first = grid(8, 8),
%     pch = 0, cex = 1.2, col = "blue")
%plot(Speed, Distance,
%     panel.first = lines(stats::lowess(Speed, Distance), lty = "dashed"),
%     pch = 0, cex = 1.2, col = "blue")
%
%## Show the different plot types
%x <- 0:12
%y <- sin(pi/5 * x)
%op <- par(mfrow = c(3,3), mar = .1+ c(2,2,3,1))
%for (tp in c("p","l","b",  "c","o","h",  "s","S","n")) {
%   plot(y ~ x, type = tp, main = paste0("plot(*, type = \"", tp, "\")"))
%   if(tp == "S") {
%      lines(x, y, type = "s", col = "red", lty = 2)
%      mtext("lines(*, type = \"s\", ...)", col = "red", cex = 0.8)
%   }
%}
%par(op)
%
%##--- Log-Log Plot  with  custom axes
%lx <- seq(1, 5, length = 41)
%yl <- expression(e^{-frac(1,2) * {log[10](x)}^2})
%y <- exp(-.5*lx^2)
%op <- par(mfrow = c(2,1), mar = par("mar")+c(0,1,0,0))
%plot(10^lx, y, log = "xy", type = "l", col = "purple",
%     main = "Log-Log plot", ylab = yl, xlab = "x")
%plot(10^lx, y, log = "xy", type = "o", pch = ".", col = "forestgreen",
%     main = "Log-Log plot with custom axes", ylab = yl, xlab = "x",
%     axes = FALSE, frame.plot = TRUE)
%my.at <- 10^(1:5)
%axis(1, at = my.at, labels = formatC(my.at, format = "fg"))
%at.y <- 10^(-5:-1)
%axis(2, at = at.y, labels = formatC(at.y, format = "fg"), col.axis = "red")
%par(op)
%}
%\keyword{hplot}
%
%\encoding{UTF8}
%