% File src/library/stats/man/cophenetic.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{cophenetic}
\alias{cophenetic}
%@%\alias{共表型的距離}%@%\alias{階層的クラスタリング}
\alias{cophenetic.default}
\alias{cophenetic.dendrogram}
%%\title{Cophenetic Distances for a Hierarchical Clustering}
\title{階層的なクラスター形成のための共表型的距離}
\description{
  階層的クラスタリングに対する共表型的距離を計算する．
}
\usage{
cophenetic(x)
\method{cophenetic}{default}(x)
\method{cophenetic}{dendrogram}(x)
}
\arguments{
  \item{x}{階層的クラスタリングを表現する \R オブジェクト．
    既定メソッドに対しては
    クラス \code{"\link{hclust}"} か，又は
    パッケージ \CRANpkg{cluster} 中の \code{"\link[cluster]{agnes}"}
    のような \code{\link{as.hclust}()} に対するメソッドを持つ
    オブジェクト．}
}
\details{
  クラスタリングされた二つのオブジェクト間の共表型的距離は
  二つの観測値が最初に一つのクラスターに結合される箇所での
  グループ内非類似度と定義される．
  この距離は多くのタイや制限を持つことを注意しよう．

  オリジナルの距離と共表型的距離の間の相関が高ければ
  デンドログラムはあるデータの適当な要約であると
  議論できる．
  さもなければ，これは単にクラスタリングアルゴリズムの出力の
  記述と見做されるべきである．

  \code{cophenetic} は総称的関数である．
  階層的クラスタリング
  (全ての添字化された階層)を表すクラスに対する
  サポートを
  \code{\link{as.hclust}()} を提供することによってか，
  又はより直接的にそうしたクラスに対する
  \code{cophenetic()} メソッドとして
  付け加えることが出来る．

  クラス \code{"\link{dendrogram}"} のオブジェクトに対する
  メソッドは
  デンドロビウムオブジェクトの全ての葉が空でないラベルを持つことを
  要求する．
}
\value{
  クラス \code{"dist"} のオブジェクト．
}
\references{
  Sneath, P.H.A. and Sokal, R.R. (1973)
  \emph{Numerical Taxonomy: The Principles and Practice of Numerical
    Classification}, p.\sspace{}278 ff;
  Freeman, San Francisco.
}
\author{Robert Gentleman}
\seealso{
  \code{\link{dist}},
  \code{\link{hclust}}
}
\examples{
require(graphics)

d1 <- dist(USArrests)
hc <- hclust(d1, "ave")
d2 <- cophenetic(hc)
cor(d1, d2) # 0.7659

## Example from Sneath & Sokal, Fig. 5-29, p.279
d0 <- c(1,3.8,4.4,5.1, 4,4.2,5, 2.6,5.3, 5.4)
attributes(d0) <- list(Size = 5, diag = TRUE)
class(d0) <- "dist"
names(d0) <- letters[1:5]
d0
utils::str(upgma <- hclust(d0, method = "average"))
plot(upgma, hang = -1)
#
(d.coph <- cophenetic(upgma))
cor(d0, d.coph) # 0.9911
}
\keyword{cluster}
\keyword{multivariate}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/cophenetic.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cophenetic}
%\alias{cophenetic}
%\alias{cophenetic.default}
%\alias{cophenetic.dendrogram}
%\title{Cophenetic Distances for a Hierarchical Clustering}
%\description{
%  Computes the cophenetic distances for a hierarchical clustering.
%}
%\usage{
%cophenetic(x)
%\method{cophenetic}{default}(x)
%\method{cophenetic}{dendrogram}(x)
%}
%\arguments{
%  \item{x}{an R object representing a hierarchical clustering.
%    For the default method, an object of class \code{"\link{hclust}"} or
%    with a method for \code{\link{as.hclust}()} such as
%    \code{"\link[cluster]{agnes}"} in package \CRANpkg{cluster}.}
%}
%\details{
%  The cophenetic distance between two observations that have been
%  clustered is defined to be the intergroup dissimilarity at which the
%  two observations are first combined into a single cluster.
%  Note that this distance has many ties and restrictions.
%
%  It can be argued that a dendrogram is an appropriate summary of some
%  data if the correlation between the original distances and the
%  cophenetic distances is high.  Otherwise, it should simply be viewed as
%  the description of the output of the clustering algorithm.
%
%  \code{cophenetic} is a generic function.  Support for classes which
%  represent hierarchical clusterings (total indexed hierarchies) can be
%  added by providing an \code{\link{as.hclust}()} or, more directly, a
%  \code{cophenetic()} method for such a class.
%
%  The method for objects of class \code{"\link{dendrogram}"} requires
%  that all leaves of the dendrogram object have non-null labels.
%}
%\value{
%  An object of class \code{"dist"}.
%}
%\references{
%  Sneath, P.H.A. and Sokal, R.R. (1973)
%  \emph{Numerical Taxonomy: The Principles and Practice of Numerical
%    Classification}, p.\sspace{}278 ff;
%  Freeman, San Francisco.
%}
%\author{Robert Gentleman}
%\seealso{
%  \code{\link{dist}},
%  \code{\link{hclust}}
%}
%\examples{
%require(graphics)
%
%d1 <- dist(USArrests)
%hc <- hclust(d1, "ave")
%d2 <- cophenetic(hc)
%cor(d1, d2) # 0.7659
%
%## Example from Sneath & Sokal, Fig. 5-29, p.279
%d0 <- c(1,3.8,4.4,5.1, 4,4.2,5, 2.6,5.3, 5.4)
%attributes(d0) <- list(Size = 5, diag = TRUE)
%class(d0) <- "dist"
%names(d0) <- letters[1:5]
%d0
%utils::str(upgma <- hclust(d0, method = "average"))
%plot(upgma, hang = -1)
%#
%(d.coph <- cophenetic(upgma))
%cor(d0, d.coph) # 0.9911
%}
%\keyword{cluster}
%\keyword{multivariate}
%
%\encoding{UTF-8}
%
