% File src/library/stats/man/cor.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{cor.test}
\alias{cor.test.default}%@%\alias{対データの関連性の検定}
\alias{cor.test.formula}
\concept{Kendall correlation coefficient}
\concept{Kendall's tau}
\concept{Pearson correlation coefficient}
\concept{Spearman correlation coefficient}
\concept{Spearman's rho}
\title{Test for Association/Correlation Between Paired Samples}
\description{
  対データ間の関連性に対する検定．
  Pearson の積モーメント相関係数，
  Kendall の \eqn{\tau}{tau} 又は Spearman の \eqn{\rho}{rho}
  のどれかを使う．
}
\usage{
cor.test(x, \dots)

\method{cor.test}{default}(x, y,
         alternative = c("two.sided", "less", "greater"),
         method = c("pearson", "kendall", "spearman"),
         exact = NULL, conf.level = 0.95, continuity = FALSE, \dots)

\method{cor.test}{formula}(formula, data, subset, na.action, \dots)
}
\arguments{
  \item{x, y}{データ値の数値ベクトル．
    \code{x} と \code{y} は同じ長さでなければならない．}
  \item{alternative}{対立仮説を指示し，
    \code{"two.sided"}, \code{"greater"} 又は \code{"less"} の
    どれかでなければならない．頭文字だけ指定することが出来る．
    \code{"greater"} は正の関連，
    \code{"less"} は負の関連に対応する．}
  \item{method}{
    検定にどの相関係数を使うかを指示する文字列．
    \code{"pearson"}, \code{"kendall"} 又は \code{"spearman"} の
    どれかで短縮できる．}
  \item{exact}{正確な p 値を計算すべきかどうかを指示する論理値．
    Kendall の \eqn{\tau}{tau} と Spearman の \eqn{\rho}{rho}
    に対して使われる．
    \code{NULL} (既定値)の意味については\sQuote{詳細}を見よ．}
  \item{conf.level}{返される信頼区間の信頼係数．
    interval.  現在，もし少なくとも4組の完全な観測値対が
    あるペアソンの積モーメント相関係数に対してだけ使われる．}
  \item{continuity}{論理値：もし真なら正確に計算されない時に
    連続補正が
    Kendall の \eqn{\tau}{tau} と Spearman の \eqn{\rho}{rho}
    に対して使われる．}
  \item{formula}{型式 \code{~ u + v} の公式で，
    ここで \code{u} と \code{v} は一つの標本に対するデータの値を
    与える数値変数．標本は同じ長さでなければならない．}
  \item{data}{オプションの行列又はデータフレーム
    (又は似たようなもの：\code{\link{model.frame}} を見よ)
    公式 \code{formula} 中の変数を含む．
    既定では変数は \code{environment(formula)} から取られる．}
  \item{subset}{使われる観測値の部分集合を指定するオプションの
    ベクトル．}
  \item{na.action}{
    \code{NA} を含むデータの処理を指示する関数．
    既定では  \code{getOption("na.action")}．}
  \item{\dots}{メソッドに渡される追加の引数．}
}
\value{
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{検定統計量の値．}
  \item{parameter}{t 分布に従う際の検定統計量の自由度．}
  \item{p.value}{検定の p 値．}
  \item{estimate}{推定された関連度で，
    使用された方法に応じて
    \code{"cor"}, \code{"tau"} 又は \code{"rho"}．}
  \item{null.value}{帰無仮説の下での関連度の値で，
    常に \code{0}．}
  \item{alternative}{対立仮説を記述する文字列．}
  \item{method}{関連度がどのように測られたかを指示する文字列．}
  \item{data.name}{データの名前を与える文字列．}
  \item{conf.int}{関連度の信頼区間．
    現在少なくとも4つの完全観測値対がある場合の
    Pearson の積モーメント相関係数に対してだけ与えられる．}
}
\details{
  三つの手法はそれぞれ対標本の関連度を推定し
  値がゼロかどうかを検定する．
  それらは異なった関連度を用い，それらは全て
  範囲 \eqn{[-1, 1]} にあり \eqn{0} が関連無しを指示する．
  これらは時おり\emph{無相関}の検定と呼ばれるが，これはしばしば
  既定メソッドに限られる．

  もし \code{method} が \code{"pearson"} ならば，検定統計量は
  Pearson の積モーメント相関係数
  \code{cor(x, y)} に基づき，もし標本が独立な正規分布に従えば
  自由度 \code{length(x)-2} の t 分布に従う．
  もし少なくとも四つの完全な観測値の対があれば
  Fisher の Z 変換に基づく漸近信頼区間が与えられる．

  もし \code{method} が \code{"kendall"} か \code{"spearman"} ならば，
  Kendall の \eqn{\tau}{tau} か Spearman の \eqn{\rho}{rho} 統計量が
  ランクに基づく関連度の推定量として使われる．
  これらの検定は必ずしも正規分布由来である必要はない．

  Kendall の検定に対しては既定(もし \code{exact} が NULL なら)で，
  もし有限値でタイがない50未満の対標本があれば正確な
  p 値が計算される．
  さもなければ，検定統計量は平均ゼロで単位分散にスケール化された
  推定値で，近似的に正規分布に従う．

  Spearman 検定に対しては，p 値は
  \eqn{n < 1290} で \code{exact = TRUE} に対して
  アルゴリズム AS 89 で計算される．
  さもなければ漸近 \eqn{t} 近似に基づく．
  これらは \eqn{n < 10} に対しては\sQuote{正確}であり，
  より大きな標本サイズに対してはエッジワース級数近似
  (打ち切りはオリジナル論文から変更されている)で計算される
  ことを注意する．
}
\references{
  D. J. Best & D. E. Roberts (1975),
  Algorithm AS 89: The Upper Tail Probabilities of Spearman's \eqn{\rho}{rho}.
  \emph{Applied Statistics}, \bold{24}, 377--379.

  Myles Hollander & Douglas A. Wolfe (1973),
  \emph{Nonparametric Statistical Methods.}
  New York: John Wiley & Sons.
  Pages 185--194 (Kendall and Spearman tests).
}

\seealso{
  パッケージ \CRANpkg{Kendall} 中の \code{\link[Kendall:Kendall]{Kendall}}．

  パッケージ \CRANpkg{SuppDists} の
  \code{\link[SuppDists:Kendall]{pKendall}} と
  \code{\link[SuppDists:Spearman]{pSpearman}}．
  
  パッケージ \CRANpkg{pspearman} 中の
  \code{\link[pspearman:spearman.test]{spearman.test}}．

  これらは異なった(そしてしばしばより正確な)近似を与える．
}

\examples{
## Hollander & Wolfe (1973), p. 187f.
## マグロ肉の品質の評価．Hunter の色の白さの測度 L と
##  9 ロットのマグロ缶に対する消費者のパネルスコアの平均を比較する．
##  (スコアは値 1 から 6 で記録され，そうした 80 の値の平均を取る) 

x <- c(44.4, 45.9, 41.9, 53.3, 44.7, 44.1, 50.7, 45.2, 60.1)
y <- c( 2.6,  3.1,  2.5,  5.0,  3.6,  4.0,  5.2,  2.8,  3.8)

##  興味ある対立仮説は Hunter の L 値は
##  パネルスコアと正の関連を持つということである．

cor.test(x, y, method = "kendall", alternative = "greater")
## => p=0.05972

cor.test(x, y, method = "kendall", alternative = "greater",
         exact = FALSE) # 大標本近似を使う
## => p=0.04765

## これを次と比較せよ
cor.test(x, y, method = "spearm", alternative = "g")
cor.test(x, y,                    alternative = "g")

## 公式によるインタフェイス．
require(graphics)
pairs(USJudgeRatings)
cor.test(~ CONT + INTG, data = USJudgeRatings)
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/cor.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cor.test}
%\alias{cor.test.default}
%\alias{cor.test.formula}
%\concept{Kendall correlation coefficient}
%\concept{Kendall's tau}
%\concept{Pearson correlation coefficient}
%\concept{Spearman correlation coefficient}
%\concept{Spearman's rho}
%\title{Test for Association/Correlation Between Paired Samples}
%\description{
%  Test for association between paired samples, using one of
%  Pearson's product moment correlation coefficient,
%  Kendall's \eqn{\tau}{tau} or Spearman's \eqn{\rho}{rho}.
%}
%\usage{
%cor.test(x, \dots)
%
%\method{cor.test}{default}(x, y,
%         alternative = c("two.sided", "less", "greater"),
%         method = c("pearson", "kendall", "spearman"),
%         exact = NULL, conf.level = 0.95, continuity = FALSE, \dots)
%
%\method{cor.test}{formula}(formula, data, subset, na.action, \dots)
%}
%\arguments{
%  \item{x, y}{numeric vectors of data values.  \code{x} and \code{y}
%    must have the same length.}
%  \item{alternative}{indicates the alternative hypothesis and must be
%    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.  You
%    can specify just the initial letter.  \code{"greater"} corresponds
%    to positive association, \code{"less"} to negative association.}
%  \item{method}{a character string indicating which correlation
%    coefficient is to be  used for the test.  One of \code{"pearson"},
%    \code{"kendall"}, or \code{"spearman"}, can be abbreviated.}
%  \item{exact}{a logical indicating whether an exact p-value should be
%    computed.  Used for Kendall's \eqn{\tau}{tau} and
%    Spearman's \eqn{\rho}{rho}.
%    See \sQuote{Details} for the meaning of \code{NULL} (the default).}
%  \item{conf.level}{confidence level for the returned confidence
%    interval.  Currently only used for the Pearson product moment
%    correlation coefficient if there are at least 4 complete pairs of
%    observations.}
%  \item{continuity}{logical: if true, a continuity correction is used
%    for Kendall's \eqn{\tau}{tau} and Spearman's \eqn{\rho}{rho} when
%    not computed exactly.}
%  \item{formula}{a formula of the form \code{~ u + v}, where each of
%    \code{u} and \code{v} are numeric variables giving the data values
%    for one sample.  The samples must be of the same length.}
%  \item{data}{an optional matrix or data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used.}
%  \item{na.action}{a function which indicates what should happen when
%    the data contain \code{NA}s.  Defaults to
%    \code{getOption("na.action")}.}
%  \item{\dots}{further arguments to be passed to or from methods.}
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the value of the test statistic.}
%  \item{parameter}{the degrees of freedom of the test statistic in the
%    case that it follows a t distribution.}
%  \item{p.value}{the p-value of the test.}
%  \item{estimate}{the estimated measure of association, with name
%    \code{"cor"}, \code{"tau"}, or \code{"rho"} corresponding
%    to the method employed.}
%  \item{null.value}{the value of the association measure under the
%    null hypothesis, always \code{0}.}
%  \item{alternative}{a character string describing the alternative
%    hypothesis.}
%  \item{method}{a character string indicating how the association was
%    measured.}
%  \item{data.name}{a character string giving the names of the data.}
%  \item{conf.int}{a confidence interval for the measure of association.
%    Currently only given for Pearson's product moment correlation
%    coefficient in case of at least 4 complete pairs of observations.}
%}
%\details{
%  The three methods each estimate the association between paired samples
%  and compute a test of the value being zero.  They use different
%  measures of association, all in the range \eqn{[-1, 1]} with \eqn{0}
%  indicating no association.  These are sometimes referred to as tests
%  of no \emph{correlation}, but that term is often confined to the
%  default method.
%
%  If \code{method} is \code{"pearson"}, the test statistic is based on
%  Pearson's product moment correlation coefficient \code{cor(x, y)} and
%  follows a t distribution with \code{length(x)-2} degrees of freedom
%  if the samples follow independent normal distributions.  If there are
%  at least 4 complete pairs of observation, an asymptotic confidence
%  interval is given based on Fisher's Z transform.
%
%  If \code{method} is \code{"kendall"} or \code{"spearman"}, Kendall's
%  \eqn{\tau}{tau} or Spearman's \eqn{\rho}{rho} statistic is used to
%  estimate a rank-based measure of association.  These tests may be used
%  if the data do not necessarily come from a bivariate normal
%  distribution.
%
%  For Kendall's test, by default (if \code{exact} is NULL), an exact
%  p-value is computed if there are less than 50 paired samples containing
%  finite values and there are no ties.  Otherwise, the test statistic is
%  the estimate scaled to zero mean and unit variance, and is approximately
%  normally distributed.
%
%  For Spearman's test, p-values are computed using algorithm AS 89 for
%  \eqn{n < 1290} and \code{exact = TRUE}, otherwise via the asymptotic
%  \eqn{t} approximation.  Note that these are \sQuote{exact} for \eqn{n
%  < 10}, and use an Edgeworth series approximation for larger sample
%  sizes (the cutoff has been changed from the original paper).
%}
%\references{
%  D. J. Best & D. E. Roberts (1975),
%  Algorithm AS 89: The Upper Tail Probabilities of Spearman's \eqn{\rho}{rho}.
%  \emph{Applied Statistics}, \bold{24}, 377--379.
%
%  Myles Hollander & Douglas A. Wolfe (1973),
%  \emph{Nonparametric Statistical Methods.}
%  New York: John Wiley & Sons.
%  Pages 185--194 (Kendall and Spearman tests).
%}
%
%\seealso{
%  \code{\link[Kendall:Kendall]{Kendall}} in package \CRANpkg{Kendall}.
%
%  \code{\link[SuppDists:Kendall]{pKendall}} and
%  \code{\link[SuppDists:Spearman]{pSpearman}} in package
%  \CRANpkg{SuppDists},
%  \code{\link[pspearman:spearman.test]{spearman.test}} in package
%  \CRANpkg{pspearman},
%  which supply different (and often more accurate) approximations.
%}
%
%\examples{
%## Hollander & Wolfe (1973), p. 187f.
%## Assessment of tuna quality.  We compare the Hunter L measure of
%##  lightness to the averages of consumer panel scores (recoded as
%##  integer values from 1 to 6 and averaged over 80 such values) in
%##  9 lots of canned tuna.
%
%x <- c(44.4, 45.9, 41.9, 53.3, 44.7, 44.1, 50.7, 45.2, 60.1)
%y <- c( 2.6,  3.1,  2.5,  5.0,  3.6,  4.0,  5.2,  2.8,  3.8)
%
%##  The alternative hypothesis of interest is that the
%##  Hunter L value is positively associated with the panel score.
%
%cor.test(x, y, method = "kendall", alternative = "greater")
%## => p=0.05972
%
%cor.test(x, y, method = "kendall", alternative = "greater",
%         exact = FALSE) # using large sample approximation
%## => p=0.04765
%
%## Compare this to
%cor.test(x, y, method = "spearm", alternative = "g")
%cor.test(x, y,                    alternative = "g")
%
%## Formula interface.
%require(graphics)
%pairs(USJudgeRatings)
%cor.test(~ CONT + INTG, data = USJudgeRatings)
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
