% File src/library/stats/man/formula.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{formula}
\alias{formula}%@%\alias{モデル公式}
\alias{formula.default}
\alias{formula.formula}
\alias{formula.terms}
\alias{formula.data.frame}
\alias{as.formula}
\alias{print.formula}
\alias{[.formula}

\title{Model Formulae}
\usage{
formula(x, \dots)
as.formula(object, env = parent.frame())

\method{print}{formula}(x, showEnv = !identical(e, .GlobalEnv), \dots)
}
\description{
  総称的関数 \code{formula} とその固有のメソッドは
  他のオブジェクトに含まれていた公式を抜き出す手段を提供する．

  \code{as.formula} はほとんど同じであるが，
  追加で \code{object} が
  既に \code{"formula"} を継承している時属性を保存する．
}
\arguments{
  \item{x, object}{\R オブジェクト．}
  \item{\dots}{他のメソッドに・から渡される追加引数．}
  \item{env}{もし既に公式でなければ，結果に付随する環境．}
  \item{showEnv}{環境もプリントすべきかどうかを指示する論理値．}
}
\details{
  例えば
  \code{\link{lm}} と \code{\link{glm}} 関数による
  モデル当てはめは簡潔なシンボリック形式で指定される．
  \code{~} 演算子はそうしたモデルの形成で基本になる．
  形式 \code{y ~ model} の表現式は
  応答 \code{y} が
  \code{model} でシンボリックに指定される線形予測子で
  モデル化されると解釈される．

  そうしたモデルは
  \code{+} 演算子で分離された一連の項からなる．
  項自体は変数と \code{:} 演算子で分離された因子名からなる．
  そうした項は項の中に現れる全ての変数と因子の交互作用と
  解釈される．

  \code{+} と \code{:} に加えて，幾つかの他の演算子が
  モデル公式中で有用である．
  \code{*} 演算子は因子の交差を意味する：
  \code{a*b} は \code{a+b+a:b} と解釈される．
  \code{^} 演算子は指定された程度までの交差を指示する．
  例えば \code{(a+b+c)^2} は \code{(a+b+c)*(a+b+c)} に
  等しく，それは順に
  主効果 \code{a}, \code{b} そして \code{c} と共に
  それらの二次の相互作用をを含む公式に展開される．
  \code{\%in\%} 演算子は左側の項が右側のそれらに
  入れ子になっていることを指示する．
  例えば \code{a + b \%in\% a} は公式
  \code{a + a:b} に展開される．
  \code{-} 演算子は特定の項を取り除くので，
  \code{(a+b+c)^2 - a:b} は
  \code{a + b + c + b:c + a:c} と同じになる．
  これは又切片項を取り除くのに使える：
  線形モデル \code{y ~ x - 1} は原点を通る直線を意味する．
  切片項を持たないモデルは又 \code{y ~ x + 0} や \code{y ~ 0 + x}
  でも指定できる．

  公式は普通単に変数と因子名だけを含むが，
  算術表現を含むことも出来る．
  公式\cr
  \code{log(y) ~ a + log(x)} は全く正当である．
  そうした算術表現がモデル公式中でまたシンボリックに使われている
  演算子を含む時，算術とシンボリック演算子の間に
  混乱が起きるかもしれない．

  この混乱を避けるために，
  関数 \code{\link{I}()} を使い，演算子がそれらの算術的
  意味で使われる箇所を囲むことが出来る．
  例えば公式 \code{y ~ a + I(b+c)} 中では，項 \code{b+c} は
  \code{b} と \code{c} の和と解釈される．

  変数名は公式中で
  \code{`like this`} のようにバックチックで引用化出来るが，
  公式を使う全てのコードがそうした非シンタックス的な
  名前を受け入れるかどうかは保証できない．

  殆どのモデル当てはめ関数は
  固定係数 1 の項を指示する関数
  右辺に \code{\link{offset}}
  を含む公式を受け入れる．
  
  ある種の関数は \code{strata} や \code{cluster} 等の
  \sQuote{特殊語}を受け入れる
  (\code{\link{terms.formula}} の \code{specials} 引数を見よ)

  公式中での \code{.} の二つの特殊な解釈がある．
  普通のそれはモデル当てはめ関数の
  \code{data} 引数の文脈中で
  \sQuote{さもなければ公式中にない全ての列}を意味する．
  \code{\link{update.formula}} の文脈中(だけ)では，
  それは\sQuote{公式のこの部分に以前にあったもの}を意味する．

  モデル当てはめ関数に関して \code{formula} が呼び出されると，
  (クラス \code{"nls"} に対するもののように)
  特別なメソッドが使われるか，既定のメソッドが使われる．
  既定は先ずオブジェクトの \code{"formula"} 成分
  (そしてそれを評価する)，それから \code{"terms"} 成分，
  そして呼び出しの \code{formula} パラメータ
  (そしてその値を評価する)，そして最後に
  \code{"formula"} 属性を探す．

  データフレームに対しては \code{formula} メソッドがある．
  もし列が一つだけならそれは左辺式のない右辺式を作る．
  複数の列があれば，最初の列が左辺式で残りが
  \code{+} で分離されて右辺式となる．
}
\section{環境}{
  公式オブジェクトは付随する環境を持ち，
  この環境は(親環境ではなく) 提供された \code{data} 引数に
  見つからない変数を評価するために
  \code{\link{model.frame}} によって使われる．

  \code{~} で生成された公式はそれらが作りだされた環境を使う．
  \code{as.formula} で生成された公式はそれらの環境として
  \code{env} 引数を使う．
}
\value{
  上の全ての関数は
  シンボリックなモデル公式を含むクラス \code{"formula"}
  のオブジェクトを生成する．
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical models.}
  Chapter 2 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{I}}, \code{\link{offset}}.

  公式の操作に対しては：
  \code{\link{terms}}，そして \code{\link{all.vars}}；
  典型的な使用に対しては： \code{\link{lm}}, \code{\link{glm}} そして
  \code{\link{coplot}}．
}
\examples{
class(fo <- y ~ x1*x2) # "formula"
fo
typeof(fo)  # R 内部 : "language"
terms(fo)

environment(fo)
environment(as.formula("y ~ x"))
environment(as.formula("y ~ x", env = new.env()))


## 大量の変数を持つモデルに対する公式を作る：
xnam <- paste0("x", 1:25)
(fmla <- as.formula(paste("y ~ ", paste(xnam, collapse= "+"))))
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/formula.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{formula}
%\alias{formula}
%\alias{formula.default}
%\alias{formula.formula}
%\alias{formula.terms}
%\alias{formula.data.frame}
%\alias{as.formula}
%\alias{print.formula}
%\alias{[.formula}
%
%\title{Model Formulae}
%\usage{
%formula(x, \dots)
%as.formula(object, env = parent.frame())
%
%\method{print}{formula}(x, showEnv = !identical(e, .GlobalEnv), \dots)
%}
%\description{
%  The generic function \code{formula} and its specific methods provide a
%  way of extracting formulae which have been included in other objects.
%
%  \code{as.formula} is almost identical, additionally preserving
%  attributes when \code{object} already inherits from
%  \code{"formula"}.
%}
%\arguments{
%  \item{x, object}{\R object.}
%  \item{\dots}{further arguments passed to or from other methods.}
%  \item{env}{the environment to associate with the result, if not
%    already a formula.}
%  \item{showEnv}{logical indicating if the environment should be printed
%    as well.}
%}
%\details{
%  The models fit by, e.g., the \code{\link{lm}} and \code{\link{glm}} functions
%  are specified in a compact symbolic form.
%  The \code{~} operator is basic in the formation of such models.
%  An expression of the form \code{y ~ model} is interpreted
%  as a specification that the response \code{y} is modelled
%  by a linear predictor specified symbolically by \code{model}.
%  Such a model consists of a series of terms separated
%  by \code{+} operators.
%  The terms themselves consist of variable and factor
%  names separated by \code{:} operators.
%  Such a term is interpreted as the interaction of
%  all the variables and factors appearing in the term.
%
%  In addition to \code{+} and \code{:}, a number of other operators are
%  useful in model formulae.  The \code{*} operator denotes factor
%  crossing: \code{a*b} interpreted as \code{a+b+a:b}.  The \code{^}
%  operator indicates crossing to the specified degree.  For example
%  \code{(a+b+c)^2} is identical to \code{(a+b+c)*(a+b+c)} which in turn
%  expands to a formula containing the main effects for \code{a},
%  \code{b} and \code{c} together with their second-order interactions.
%  The \code{\%in\%} operator indicates that the terms on its left are
%  nested within those on the right.  For example \code{a + b \%in\% a}
%  expands to the formula \code{a + a:b}.  The \code{-} operator removes
%  the specified terms, so that \code{(a+b+c)^2 - a:b} is identical to
%  \code{a + b + c + b:c + a:c}.  It can also used to remove the
%  intercept term: when fitting a linear model \code{y ~ x - 1} specifies
%  a line through the origin.  A model with no intercept can be also
%  specified as \code{y ~ x + 0} or \code{y ~ 0 + x}.
%
%  While formulae usually involve just variable and factor
%  names, they can also involve arithmetic expressions.
%  The formula \code{log(y) ~ a + log(x)} is quite legal.
%  When such arithmetic expressions involve
%  operators which are also used symbolically
%  in model formulae, there can be confusion between
%  arithmetic and symbolic operator use.
%
%  To avoid this confusion, the function \code{\link{I}()}
%  can be used to bracket those portions of a model
%  formula where the operators are used in their
%  arithmetic sense.  For example, in the formula
%  \code{y ~ a + I(b+c)}, the term \code{b+c} is to be
%  interpreted as the sum of \code{b} and \code{c}.
%
%  Variable names can be quoted by backticks \code{`like this`} in
%  formulae, although there is no guarantee that all code using formulae
%  will accept such non-syntactic names.
%
%  Most model-fitting functions accept formulae with right-hand-side
%  including the function \code{\link{offset}} to indicate terms with a
%  fixed coefficient of one.  Some functions accept other
%  \sQuote{specials} such as \code{strata} or \code{cluster} (see the
%  \code{specials} argument of \code{\link{terms.formula})}.
%
%  There are two special interpretations of \code{.} in a formula.  The
%  usual one is in the context of a \code{data} argument of model
%  fitting functions and means \sQuote{all columns not otherwise in the
%  formula}: see \code{\link{terms.formula}}.  In the context of
%  \code{\link{update.formula}}, \bold{only}, it means \sQuote{what was
%    previously in this part of the formula}.
%
%  When \code{formula} is called on a fitted model object, either a
%  specific method is used (such as that for class \code{"nls"}) or the
%  default method.  The default first looks for a \code{"formula"}
%  component of the object (and evaluates it), then a \code{"terms"}
%  component, then a \code{formula} parameter of the call (and evaluates
%  its value) and finally a \code{"formula"} attribute.
%
%  There is a \code{formula} method for data frames.  If there is only
%  one column this forms the RHS with an empty LHS.  For more columns,
%  the first column is the LHS of the formula and the remaining columns
%  separated by \code{+} form the RHS.
%}
%\section{Environments}{
%  A formula object has an associated environment, and
%  this environment (rather than the parent
%  environment) is used by \code{\link{model.frame}} to evaluate variables
%  that are not found in the supplied \code{data} argument.
%
%  Formulas created with the \code{~} operator use the
%  environment in which they were created.  Formulas created with
%  \code{as.formula} will use the \code{env} argument for their
%  environment.
%}
%\value{
%  All the functions above produce an object of class \code{"formula"}
%  which contains a symbolic model formula.
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical models.}
%  Chapter 2 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{I}}, \code{\link{offset}}.
%
%  For formula manipulation: \code{\link{terms}}, and \code{\link{all.vars}};
%  for typical use: \code{\link{lm}}, \code{\link{glm}}, and
%  \code{\link{coplot}}.
%}
%\examples{
%class(fo <- y ~ x1*x2) # "formula"
%fo
%typeof(fo)  # R internal : "language"
%terms(fo)
%
%environment(fo)
%environment(as.formula("y ~ x"))
%environment(as.formula("y ~ x", env = new.env()))
%
%
%## Create a formula for a model with a large number of variables:
%xnam <- paste0("x", 1:25)
%(fmla <- as.formula(paste("y ~ ", paste(xnam, collapse= "+"))))
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
