% File src/library/stats/man/ftable.formula.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{ftable.formula}
\alias{ftable.formula}%@%\alias{公式によるフラットな表の操作}
\title{Formula Notation for Flat Contingency Tables}
\description{公式表記を用いてフラットな分割表を作ったり操作したりする．}
\usage{
\method{ftable}{formula}(formula, data = NULL, subset, na.action, \dots)
}
\arguments{
  \item{formula}{フラットな表の列と行変数を指定する左辺と右辺を持つ公式
    オブジェクト．}
  \item{data}{クロス集計される変数を含む
    データフレーム，リスト，又は環境
    (又は類似物：\code{\link{model.frame}} を見よ)，
    もしくは分割表(下を見よ)．}
  \item{subset}{使用される観測値の部分集合を指定する
    オプションのベクトル．}
  \item{na.action}{データが \code{NA} を含む時何が起きるべきかを指示する関数．
    もし \code{data} が分割表ならば無視される．}
  \item{\dots}{既定の ftable メソッドへの追加引数も
    引数として渡すことが出来る，\cr
    \code{\link{ftable.default}} を見よ．}
}
\details{
  これは総称的関数 \code{\link{ftable}} のメソッドである．

  \code{formula} の左辺と右辺はそれぞれ作られるフラットな分割表の
  列と行変数を指定する．
  \code{+} 演算子だけが変数の結合のために許される．
  \code{.} が全ての残りの変数を含むことを指示するために公式中に
  一回使うことが出来る．

  もし \code{data} が
  クラス \code{"table"} のオブジェクトか二次元以上の配列ならば，
  それは分割表とされ，全ての項目は非負でなければならない．
  さもなければ，もしそれがフラットな分割表
  (つまりクラス \code{"ftable"})でなければ，それはデータフレームか
  行列，クロス集計される変数を含むリストか環境でなければならない．
  この場合 \code{na.action} が欠損値を処理するためにデータに適用され，
  そしてもしかすると \code{subset} 引数で指定されるデータの部分集合を
  選択した後で，変数から分割表が作られる．

  それから分割表は
  \code{formula} で指定される行と列変数に従いフラットな表に
  潰される．
}
\value{
  変数の水準の各組み合わせに対するカウントを含むフラットな表で，
  カウントの適切な表示のために行列に潰されている．
}
\seealso{
  \code{\link{ftable}},
  \code{\link{ftable.default}};
  \code{\link{table}}.
}
\examples{
Titanic
x <- ftable(Survived ~ ., data = Titanic)
x
ftable(Sex ~ Class + Age, data = x)
}
\keyword{category}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/ftable.formula.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ftable.formula}
%\alias{ftable.formula}
%\title{Formula Notation for Flat Contingency Tables}
%\description{Produce or manipulate a flat contingency table using
%  formula notation.}
%\usage{
%\method{ftable}{formula}(formula, data = NULL, subset, na.action, \dots)
%}
%\arguments{
%  \item{formula}{a formula object with both left and right hand sides
%    specifying the column and row variables of the flat table.}
%  \item{data}{a data frame, list or environment (or similar: see
%    \code{\link{model.frame}}) containing the variables
%    to be cross-tabulated, or a contingency table (see below).}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used.
%    Ignored if \code{data} is a contingency table.}
%  \item{na.action}{a function which indicates what should happen when
%    the data contain \code{NA}s.
%    Ignored if \code{data} is a contingency table.}
%  \item{\dots}{further arguments to the default ftable method may also
%    be passed as arguments, see \code{\link{ftable.default}}.}
%}
%\details{
%  This is a method of the generic function \code{\link{ftable}}.
%
%  The left and right hand side of \code{formula} specify the column and
%  row variables, respectively, of the flat contingency table to be
%  created.  Only the \code{+} operator is allowed for combining the
%  variables.  A \code{.} may be used once in the formula to indicate
%  inclusion of all the remaining variables.
%
%  If \code{data} is an object of class \code{"table"} or an array with
%  more than 2 dimensions, it is taken as a contingency table, and hence
%  all entries should be nonnegative.  Otherwise, if it is not a flat
%  contingency table (i.e., an object of class \code{"ftable"}), it
%  should be a data frame or matrix, list or environment containing the
%  variables to be cross-tabulated.  In this case, \code{na.action} is
%  applied to the data to handle missing values, and, after possibly
%  selecting a subset of the data as specified by the \code{subset}
%  argument, a contingency table is computed from the variables.
%
%  The contingency table is then collapsed to a flat table, according to
%  the row and column variables specified by \code{formula}.
%}
%\value{
%  A flat contingency table which contains the counts of each combination
%  of the levels of the variables, collapsed into a matrix for suitably
%  displaying the counts.
%}
%\seealso{
%  \code{\link{ftable}},
%  \code{\link{ftable.default}};
%  \code{\link{table}}.
%}
%\examples{
%Titanic
%x <- ftable(Survived ~ ., data = Titanic)
%x
%ftable(Sex ~ Class + Age, data = x)
%}
%\keyword{category}
%
%\encoding{UTF-8}
%
