% File src/library/stats/man/kruskal.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{kruskal.test}
\alias{kruskal.test}%@%\alias{クルスカル・ワリスのランク和検定}
\alias{kruskal.test.default}
\alias{kruskal.test.formula}
\title{Kruskal-Wallis Rank Sum Test}
\description{
  Kruskal-Wallis のランク和検定を実行する．
}
\usage{
kruskal.test(x, \dots)

\method{kruskal.test}{default}(x, g, \dots)

\method{kruskal.test}{formula}(formula, data, subset, na.action, \dots)
}
\arguments{
  \item{x}{データ値の数値ベクトル，又は数値データベクトルのリスト．
    数値でないリスト成分は強制変換され警告が出る．}
  \item{g}{
    \code{x} の要素に対するグループを与えるベクトルか因子オブジェクト．
    \code{x} がリストなら警告と共に無視される．}
  \item{formula}{
    形式 \code{response ~ group} の公式で，ここで
    \code{response} はデータ値を
    \code{group} は対応するベクトルか因子を表す．}
  \item{data}{オプションの行列かデータフレーム
    (又は類似物：\code{\link{model.frame}} を見よ)で
    公式 \code{formula} 中の変数を含む．
    既定では変数は
    \code{environment(formula)} から取られる．}
  \item{subset}{使用される観測値の部分集合を指定するオプションのベクトル．}
  \item{na.action}{
    データが \code{NA} を含む時何が起きるかを指示する関数．
    既定では\cr
    \code{getOption("na.action")}．}
  \item{\dots}{メソッドに/から渡される追加引数．}
}
\details{
  \code{kruskal.test} は
  \code{x} の分布の位置パラメータが各グループ(標本)で同じという帰無仮説を
  Kruskal-Wallis のランク和検定で検定する．対立仮説は
  それらが少なくとも一つで異なるというものである．

  もし \code{x} がリストなら，その要素は比較される標本とされるので，
  数値データベクトルでなければならない．
  この場合 \code{g} は無視され，検定を実行するには単に
  \code{kruskal.test(x)} とすれば良い．もし標本がまだリストに含まれていなければ
  \code{kruskal.test(list(x, ...))} とする．

  さもなければ，\code{x} は数値データベクトルでなければならず，
  \code{g} は \code{x} と同じ長さのベクトルもしくは因子で，
  対応する \code{x} の要素に対するグループを与える．
}
\value{
  A list with class
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{Kruskal-Wallis のランク和統計量．}
  \item{parameter}{検定統計量の近似カイ二乗分布の自由度．}
  \item{p.value}{検定の p 値．}
  \item{method}{文字列 \code{"Kruskal-Wallis rank sum test"}．}
  \item{data.name}{データの名前を与える文字列．}
}
\references{
  Myles Hollander and Douglas A. Wolfe (1973),
  \emph{Nonparametric Statistical Methods.}
  New York: John Wiley & Sons.
  Pages 115--120.
}
\seealso{
  二標本の地区別な場合としての Wilcoxon ランク和検定(\code{\link{wilcox.test}})；
  正規仮定の下での一元データの位置解析には \code{\link{anova}} と共に \code{\link{lm}}；
  二標本に対する特別な場合としての Student の
  t 検定 (\code{\link{t.test}})．

  タイの存在を含む正確，漸近，モンテカルロ
  \emph{条件付き} p 値には
  パッケージ \CRANpkg{coin} 中の\cr
  \code{\link[coin:LocationTests]{wilcox_test}}．
}
\examples{
## Hollander & Wolfe (1973), 116.
## 健康な人，気道閉塞疾患を持つ患者，石綿症の患者に対する
## 埃の除去率からの除粘膜毛様体の効率性
x <- c(2.9, 3.0, 2.5, 2.6, 3.2) # 正常
y <- c(3.8, 2.7, 4.0, 2.4)      # 気道閉塞疾患
z <- c(2.8, 3.4, 3.7, 2.2, 2.0) # 石綿症
kruskal.test(list(x, y, z))
## 同値なものとして，
x <- c(x, y, z)
g <- factor(rep(1:3, c(5, 4, 5)),
            labels = c("Normal subjects",
                       "Subjects with obstructive airway disease",
                       "Subjects with asbestosis"))
kruskal.test(x, g)

## 公式インタフェイス．
require(graphics)
boxplot(Ozone ~ Month, data = airquality)
kruskal.test(Ozone ~ Month, data = airquality)
}
\keyword{htest}

\encoding{UTF-8}
