% File src/library/stats/man/loglin.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{loglin}
\alias{loglin}%@%\alias{対数線形モデルの当てはめ}
\title{Fitting Log-Linear Models}
\usage{
loglin(table, margin, start = rep(1, length(table)), fit = FALSE,
       eps = 0.1, iter = 20, param = FALSE, print = TRUE)
}
\description{
  \code{loglin} は多次元分割表に繰り返し比例当てはめにより
  対数線形モデルを当てはめる．
}
\arguments{
  \item{table}{当てはめられるべき分割表，典型的に
    \code{table} の出力．}
  \item{margin}{当てはめられるべき周辺和のベクトルのリスト．

    (階層的)対数線形モデルは
    モデルに含まれる\sQuote{最大}因子集合を与えるこれらの
    周辺和の言葉で指定することが出来る．
    例えば3因子モデルに対しては，
    \code{list(c(1, 2), c(1, 3))} は
    大局的平均，各因子，そしてそれぞれ 1-2 と 1-3 相互作用
    (しかし 2-3 や 1-2-3 相互作用は無い)を含むモデルを指定する，
    つまり因子 2 と 3 は因子 1 を与えて条件付き独立
    (\sQuote{[12][13]} と表記されることがある)．

    因子名(つまり \code{names(dimnames(table))})を数値添字の代わりに
    使うことが出来る．
  }
  \item{start}{当てはめ表に対する初期推定．
    このオプションの引数は
    \code{table} 中に当てはめで保護されるべき構造的なゼロをもつ
    不完全な表に対して重要である．この場合，対応する
    \code{start} 中の項目はゼロでなければならず他は1に取ることができる．}
  \item{fit}{当てはめ値を返すべきかどうかを指示する論理値．}
  \item{eps}{周辺に対する観測値と当てはめ値の許される最大偏差．}
  \item{iter}{繰り返しの最大数．}
  \item{param}{パラメータ値を返すべきかどうかを指示する論理値．}
  \item{print}{論理値．もし \code{TRUE} なら繰り返し数と最終的な偏差がプリントされる．}
}
\value{
  次の成分を持つリスト．
  \item{lrt}{尤度非検定統計量．}
  \item{pearson}{ペアソン検定統計量(カイ二乗)．}
  \item{df}{当てはめモデルの自由度．
    構造的なゼロに対する補正はされない．}
  \item{margin}{当てはめがされた周辺値のリスト．
    基本的に入力 \code{margin} と同じだが，可能ならば番号は名前で
    置き換えられる．}
  \item{fit}{
    \code{table} のような配列で当てはめ値を含む．
    \code{fit} が \code{TRUE} の時だけ返される．}
  \item{param}{モデルの推定パラメータを含むリスト．
    \sQuote{標準的な}ゼロ周辺和の制約
    (例えば，二因子パラメータに対してはゼロの行和と列和)
    か用いられる．
    \code{param} が \code{TRUE} の時だけ返される．}
}
\details{
  Haberman (1972) で紹介されている繰り返し比率当てはめアルゴリズムが
  モデルの当てはめに使われる．
  最大 \code{iter} 回の繰り返しが実行され，周辺の観測値と当てはめ値の
  最大偏差が
  \code{eps} より小さくなれば収束したとされる．
  内部的な全ての計算は倍精度で行われる；
  モデル中の因子数(表の次元)に制限はない．

  構造的なゼロが無いと仮定すれば，
  尤度比検定とペアソン検定の統計量は漸近的に
  自由度 \code{df} のカイ二乗分布に従う．

  IPF ステップは
  \code{margin} 中に現れた順序で因子に適用される．
  従ってもしモデルが分解可能で
  \code{margin} 中で与えられた順序が移動交差性を持てば
  IPF は一回の繰り返しで収束する．

  パッケージ \CRANpkg{MASS} は \code{loglm} を含む，これは
  \code{loglin} へのフロントエンドで，
  対数線形モデルを
  \code{lm} や \code{glm} のような他の当てはめ関数のそれと類似の
  公式ベースの方法で指定し当てはめが出来る．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Haberman, S. J. (1972)
  Log-linear fit for contingency tables---Algorithm AS51.
  \emph{Applied Statistics}, \bold{21}, 218--225.

  Agresti, A. (1990)
  \emph{Categorical data analysis}.
  New York: Wiley.
}
\author{Kurt Hornik}
\seealso{
  \code{\link{table}}.

  パッケージ \CRANpkg{MASS} 中の使いやすいラッパ
  \code{\link[MASS]{loglm}}．

  対数線形モデルを当てはめる別の方法 \code{\link{glm}}．
}
\examples{
## 性別と髪・瞳の色の同時独立性
fm <- loglin(HairEyeColor, list(c(1, 2), c(1, 3), c(2, 3)))
fm
1 - pchisq(fm$lrt, fm$df)
## 3因子の相互作用のないモデルが良く当てはまる
}
\keyword{category}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/loglin.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{loglin}
%\alias{loglin}
%\title{Fitting Log-Linear Models}
%\usage{
%loglin(table, margin, start = rep(1, length(table)), fit = FALSE,
%       eps = 0.1, iter = 20, param = FALSE, print = TRUE)
%}
%\description{
%  \code{loglin} is used to fit log-linear models to multidimensional
%  contingency tables by Iterative Proportional Fitting.
%}
%\arguments{
%  \item{table}{a contingency table to be fit, typically the output from
%    \code{table}.}
%  \item{margin}{a list of vectors with the marginal totals to be fit.
%
%    (Hierarchical) log-linear models can be specified in terms of these
%    marginal totals which give the \sQuote{maximal} factor subsets contained
%    in the model.  For example, in a three-factor model,
%    \code{list(c(1, 2), c(1, 3))} specifies a model which contains
%    parameters for the grand mean, each factor, and the 1-2 and 1-3
%    interactions, respectively (but no 2-3 or 1-2-3 interaction), i.e.,
%    a model where factors 2 and 3 are independent conditional on factor
%    1 (sometimes represented as \sQuote{[12][13]}).
%
%    The names of factors (i.e., \code{names(dimnames(table))}) may be
%    used rather than numeric indices.
%  }
%  \item{start}{a starting estimate for the fitted table.  This optional
%    argument is important for incomplete tables with structural zeros
%    in \code{table} which should be preserved in the fit.  In this
%    case, the corresponding entries in \code{start} should be zero and
%    the others can be taken as one.}
%  \item{fit}{a logical indicating whether the fitted values should be
%    returned.}
%  \item{eps}{maximum deviation allowed between observed and fitted
%    margins.}
%  \item{iter}{maximum number of iterations.}
%  \item{param}{a logical indicating whether the parameter values should
%    be returned.}
%  \item{print}{a logical.  If \code{TRUE}, the number of iterations and
%    the final deviation are printed.}
%}
%\value{
%  A list with the following components.
%  \item{lrt}{the Likelihood Ratio Test statistic.}
%  \item{pearson}{the Pearson test statistic (X-squared).}
%  \item{df}{the degrees of freedom for the fitted model.  There is no
%    adjustment for structural zeros.}
%  \item{margin}{list of the margins that were fit.  Basically the same
%    as the input \code{margin}, but with numbers replaced by names
%    where possible.}
%  \item{fit}{An array like \code{table} containing the fitted values.
%    Only returned if \code{fit} is \code{TRUE}.}
%  \item{param}{A list containing the estimated parameters of the
%    model.  The \sQuote{standard} constraints of zero marginal sums
%    (e.g., zero row and column sums for a two factor parameter) are
%    employed.  Only returned if \code{param} is \code{TRUE}.}
%}
%\details{
%  The Iterative Proportional Fitting algorithm as presented in
%  Haberman (1972) is used for fitting the model.  At most \code{iter}
%  iterations are performed, convergence is taken to occur when the
%  maximum deviation between observed and fitted margins is less than
%  \code{eps}.  All internal computations are done in double precision;
%  there is no limit on the number of factors (the dimension of the
%  table) in the model.
%
%  Assuming that there are no structural zeros, both the Likelihood
%  Ratio Test and Pearson test statistics have an asymptotic chi-squared
%  distribution with \code{df} degrees of freedom.
%
%  Note that the IPF steps are applied to the factors in the order given
%  in \code{margin}.  Hence if the model is decomposable and the order
%  given in \code{margin} is a running intersection property ordering
%  then IPF will converge in one iteration.
%
%  Package \CRANpkg{MASS} contains \code{loglm}, a front-end to
%  \code{loglin} which allows the log-linear model to be specified and
%  fitted in a formula-based manner similar to that of other fitting
%  functions such as \code{lm} or \code{glm}.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Haberman, S. J. (1972)
%  Log-linear fit for contingency tables---Algorithm AS51.
%  \emph{Applied Statistics}, \bold{21}, 218--225.
%
%  Agresti, A. (1990)
%  \emph{Categorical data analysis}.
%  New York: Wiley.
%}
%\author{Kurt Hornik}
%\seealso{
%  \code{\link{table}}.
%
%  \code{\link[MASS]{loglm}} in package \CRANpkg{MASS} for a
%  user-friendly wrapper.
%
%  \code{\link{glm}} for another way to fit log-linear models.
%}
%\examples{
%## Model of joint independence of sex from hair and eye color.
%fm <- loglin(HairEyeColor, list(c(1, 2), c(1, 3), c(2, 3)))
%fm
%1 - pchisq(fm$lrt, fm$df)
%## Model with no three-factor interactions fits well.
%}
%\keyword{category}
%\keyword{models}
%
%\encoding{UTF-8}
%
