% File src/library/stats/man/predict.nls.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{predict.nls}
\title{Predicting from Nonlinear Least Squares Fits}
\alias{predict.nls}\alias{非線形最少二乗当てはめからの予測}
\usage{
\method{predict}{nls}(object, newdata , se.fit = FALSE, scale = NULL, df = Inf,
        interval = c("none", "confidence", "prediction"),
        level = 0.95, \dots)
}
\description{
  \code{predict.nls} は回帰関数をフレーム
  \code{newdata} で評価して得られる予測値を作る．
  もし論理値 \code{se.fit} が \code{TRUE} なら予測値の標準誤差が
  計算される．
  もし数値引数 \code{scale} が設定(オプションの \code{df} と共に)
  されていれば，それが標準誤差の計算中で残差標準偏差として
  使われる．さもなければ，これはモデル当てはめから取り出される．
  \code{intervals} の設定は指定された \code{level} での
  信頼もしくは予測(許容)区間の計算を指示する．
  

  現在 \code{se.fit} と \code{interval} は無視される．
}
\arguments{
 \item{object}{
   クラス \code{nls} を継承するオブジェクト．}
 \item{newdata}{
   そこで予測を行う変数を探す名前付きリスト化データフレーム．
   もし \code{newdata} がなければオリジナルのデータにおける当てはめ値が
   返される．}
 \item{se.fit}{
   予測値の標準誤差を返すべきかどうかを指示する論理値．
   既定値は \code{FALSE}．
   現在この引数は無視される．}
 \item{scale}{数値スカラ．もしこれが
   (オプションの \code{df} とともに)設定されると，それは
   標準誤差の計算で残差標準偏差として使われる．さもなければ
   この情報はモデル当てはめから取り出される．
   現在この情報は無視される．}
 \item{df}{
   \code{scale} の推定に対する自由度を与える正の数値スカラ．
   現在この引数は無視される．}
 \item{interval}{
   平均応答の予測区間か信頼区間を計算するかどうかを指示する文字列．
   現在この引数は無視される．}
 \item{level}{
   計算される区間(もしあれば)に対する信頼水準を与える
   0 と 1 の間の数値スカラ．
   現在この引数は無視される．}
 \item{\dots}{追加のオプションパラメータ．現在オプションパラメータは
   使われない．}
}
\value{
  \code{predict.nls} は予測値のベクトルを作る．
  もし移植されていれば，
  \code{interval} は
  列名 \code{fit}, \code{lwr} そして \code{upr} を持つ予測値と
  限界を持つ行列を作る．
  移植されている時，もし \code{se.fit} が真なら
  次の成分を持つリストが返される：

  \item{fit}{上のようなベクトルか行列．}
  \item{se.fit}{予測の標準誤差．}
  \item{residual.scale}{残差標準誤差．}
  \item{df}{残差の自由度．}
}
\seealso{
  モデル当てはめ関数 \code{\link{nls}},
  \code{\link{predict}}.
}
\note{
  変数は最初
  \code{newdata} で探され，次に通常の仕方で探される
  (当てはめに使われた公式の環境も含まれる)．
  見つかった変数が
  (もし提供されていたならば) \code{newdata} 中のそれらと長さが異なれば
  警告が出る．
}
\examples{
\testonly{od <- options(digits = 5)}
require(graphics)

fm <- nls(demand ~ SSasympOrig(Time, A, lrc), data = BOD)
predict(fm)              # 観測時刻に於ける当てはめ値
## データのプロットと予測のための平滑線を作る
opar <- par(las = 1)
plot(demand ~ Time, data = BOD, col = 4,
     main = "BOD data and fitted first-order curve",
     xlim = c(0,7), ylim = c(0, 20) )
tt <- seq(0, 8, length = 101)
lines(tt, predict(fm, list(Time = tt)))
par(opar)
\testonly{options(od)}
}
\keyword{nonlinear}
\keyword{regression}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/predict.nls.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{predict.nls}
%\title{Predicting from Nonlinear Least Squares Fits}
%\alias{predict.nls}
%\usage{
%\method{predict}{nls}(object, newdata , se.fit = FALSE, scale = NULL, df = Inf,
%        interval = c("none", "confidence", "prediction"),
%        level = 0.95, \dots)
%}
%\description{
%  \code{predict.nls} produces predicted values, obtained by evaluating
%  the regression function in the frame \code{newdata}.  If the logical
%  \code{se.fit} is \code{TRUE}, standard errors of the predictions are
%  calculated.  If the numeric argument \code{scale} is set (with
%  optional \code{df}), it is used as the residual standard deviation in
%  the computation of the standard errors, otherwise this is extracted
%  from the model fit.  Setting \code{intervals} specifies computation of
%  confidence or prediction (tolerance) intervals at the specified
%  \code{level}.
%
%  At present \code{se.fit} and \code{interval} are ignored.
%}
%\arguments{
% \item{object}{An object that inherits from class \code{nls}.}
% \item{newdata}{A named list or data frame in which to look for variables with
%   which to predict.  If \code{newdata} is
%   missing the fitted values at the original data points are returned.}
% \item{se.fit}{A logical value indicating if the standard errors of the
%   predictions should be calculated.  Defaults to \code{FALSE}.  At
%   present this argument is ignored.}
% \item{scale}{A numeric scalar.  If it is set (with optional
%   \code{df}), it is used as the residual standard deviation in the
%   computation of the standard errors, otherwise this information is
%   extracted from the model fit. At present this argument is ignored.}
% \item{df}{A positive numeric scalar giving the number of degrees of
%   freedom for the \code{scale} estimate. At present this argument is
%   ignored.}
% \item{interval}{A character string indicating if prediction intervals
%   or a confidence interval on the mean responses are to be
%   calculated. At present this argument is ignored.}
% \item{level}{A numeric scalar between 0 and 1 giving the confidence
%   level for the intervals (if any) to be calculated.  At present
%   this argument is ignored.}
% \item{\dots}{Additional optional arguments.  At present no optional
%   arguments are used.}
%}
%\value{
%  \code{predict.nls} produces a vector of predictions.
%  When implemented, \code{interval} will produce a matrix of
%  predictions and bounds with column names \code{fit}, \code{lwr}, and
%  \code{upr}.  When implemented, if \code{se.fit} is
%  \code{TRUE}, a list with the following components will be returned:
%
%  \item{fit}{vector or matrix as above}
%  \item{se.fit}{standard error of predictions}
%  \item{residual.scale}{residual standard deviations}
%  \item{df}{degrees of freedom for residual}
%}
%\seealso{
%  The model fitting function \code{\link{nls}},
%  \code{\link{predict}}.
%}
%\note{
%  Variables are first looked for in \code{newdata} and then searched for
%  in the usual way (which will include the environment of the formula
%  used in the fit).  A warning will be given if the
%  variables found are not of the same length as those in \code{newdata}
%  if it was supplied.
%}
%\examples{
%\testonly{od <- options(digits = 5)}
%require(graphics)
%
%fm <- nls(demand ~ SSasympOrig(Time, A, lrc), data = BOD)
%predict(fm)              # fitted values at observed times
%## Form data plot and smooth line for the predictions
%opar <- par(las = 1)
%plot(demand ~ Time, data = BOD, col = 4,
%     main = "BOD data and fitted first-order curve",
%     xlim = c(0,7), ylim = c(0, 20) )
%tt <- seq(0, 8, length = 101)
%lines(tt, predict(fm, list(Time = tt)))
%par(opar)
%\testonly{options(od)}
%}
%\keyword{nonlinear}
%\keyword{regression}
%\keyword{models}
%
%\encoding{UTF-8}
%