% File src/library/stats/man/termplot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{termplot}
\alias{termplot}%@%\alias{回帰項のプロット}
\title{Plot Regression Terms}
\description{
  回帰項をそれらの予測子に対してプロットする．
  オプションで標準エラーと部分残差が付け加えられる．
}
\usage{
termplot(model, data = NULL, envir = environment(formula(model)),
         partial.resid = FALSE, rug = FALSE,
         terms = NULL, se = FALSE,
         xlabs = NULL, ylabs = NULL, main = NULL,
         col.term = 2, lwd.term = 1.5,
         col.se = "orange", lty.se = 2, lwd.se = 1,
         col.res = "gray", cex = 1, pch = par("pch"),
         col.smth = "darkred", lty.smth = 2, span.smth = 2/3,
         ask = dev.interactive() && nb.fig < n.tms,
         use.factor.levels = TRUE, smooth = NULL, ylim = "common",
         plot = TRUE, transform.x = FALSE, \dots)
}
\arguments{
  \item{model}{当てはめモデルオブジェクト．}
  \item{data}{
    その中で \code{model} 中の変数が見つけられるデータフレーム．}
  \item{envir}{
    その中で \code{model} 中の変数が見つけられる環境．}  
  \item{partial.resid}{論理値；部分残差をプロットすべきか?}
  \item{rug}{軸に対するラグプロット(ジッターされた一次元ヒストグラム)を加えるか?}
  \item{terms}{どの項をプロットするか(既定の \code{NULL} は
    全ての項を意味する)；\cr
    \code{\link{predict}(.., type = "terms", terms = *)}
    に渡されるベクトル．}
  \item{se}{点毎の標準エラーをプロットするか?}
  \item{xlabs}{x 軸に対するラベルのベクトル．}
  \item{ylabs}{y 軸に対するラベルのベクトル．}
  \item{main}{論理値，又は主タイトルのベクトル；
    もし \code{TRUE} なら，
    モデルの呼び出しが主タイトルに取られ，
    \code{NULL} か \code{FALSE} はタイトル無しを意味する．}
  \item{col.term, lwd.term}{
    \sQuote{項のカーブ}に対する色と線幅，
    \code{\link{lines}} を見よ．}
  \item{col.se, lty.se, lwd.se}{
    \code{se = TRUE} の時\sQuote{二倍の標準エラー曲線}
    に対する色，線種そして線幅．}
  \item{col.res, cex, pch}{
    \code{partial.resid = TRUE} の時の部分残差に対する色，プロット文字の
    拡大率と種類，\code{\link{points}} を見よ．}
   \item{ask}{
     論理値；もし \code{TRUE} なら，各プロットの前に\emph{問い合わせ}がある，
     \code{\link{par}(ask=.)} を見よ．}
   \item{use.factor.levels}{
     因子項に対する x 軸のチックマークは因子水準を
     使うか数値を使うか?}
   \item{smooth}{
     \code{NULL} 又は
     非因子項に対する部分残差を通る滑らかな曲線を描く
     \code{\link{panel.smooth}} と同じ引数の関数．}
   \item{lty.smth, col.smth, span.smth}{\code{smooth} に渡される．}
   \item{ylim}{
     y 軸に対するオプションの範囲，又は
     全てのプロットに十分な範囲が計算されるときは \code{"common"}，
     又は限界が各プロットに対して計算されるときは
     \code{"free"}．}
   \item{plot}{もし \code{FALSE} に設定するとプロットは作られない：
     代わりにプロットされたであろうデータを含む
     リストが返される．}
   \item{transform.x}{論理値ベクトル；
     もし要素(必要ならリサイクるされる)
     が \code{TRUE} なら，対応する項に対する部分残差が
     変換された値に対してプロットされる．
     モデルの応答はそうすると直線で，
     データや
     \code{smooth-panel.smooth} から得られたカーブに
     対して比較が容易に出来る．}
   \item{\dots}{他のグラフィカルパラメータ．}
}
\details{
  \code{model} オブジェクトは
  \code{type = "terms"} を受け入れる \code{predict} メソッドを
  持たなければならない，例えば
  \pkg{stats} パッケージ中の \code{\link{glm}}，
  \CRANpkg{survival} パッケージ中の
  \code{\link[survival]{coxph}} と \code{\link[survival]{survreg}}
  である．

  オプション \code{partial.resid = TRUE} に対しては \code{model} は
  \code{\link{lm}} や \code{\link{glm}} がそうであるような
  \code{type = "partial"} を受け入れる
  \code{\link{residuals}} メソッドを持たなければならない．
  ,
  \code{data} 引数は滅多に必要とされないが，
  ある場合には
  \code{termplot} はオリジナルのデータフレームを再構成できないかもしれない．
  \code{na.action=na.exclude} の使用はこうした問題をより起きにくくする．

  交互作用に対しては意味のあることは起きず，
  エラーを起こすかもしれない．

  オプション \code{plot = FALSE} はある特殊な行動が必要なときは
  有用である，
  例えば，二つの異なったモデルの結果を重ねあわせたり
  信頼帯をプロットする場合である．
}
\value{
  For
  \code{plot = FALSE} に対しては，作られた各プロットに対して一つの成分を持つ
  リスト．リストの各成分は変数 \code{x}, \code{y} そしてオプションで
  点毎の標準エラー \code{se} を持つ．
  連続予測子に対しては \code{x} は
  順序付けられたユニークな値を含み，因子に対しては
  それは各水準に対して一つのインスタンスを含む因子である．
  リストは予測された項オブジェクトからコピーされた属性 \code{"constant"}
  を持つ．
  
  さもなければ不可視で項数を返す．
}
\seealso{(一般化)線形モデル．\code{\link{plot.lm}} と
  \code{\link{predict.glm}}．}
\examples{
require(graphics)

had.splines <- "package:splines" \%in\% search()
if(!had.splines) rs <- require(splines)
x <- 1:100
z <- factor(rep(LETTERS[1:4], 25))
y <- rnorm(100, sin(x/10)+as.numeric(z))
model <- glm(y ~ ns(x, 6) + z)

par(mfrow = c(2,2)) ## 同じモデルの 2 x 2 プロット：
termplot(model, main = paste("termplot( ", deparse(model$call)," ...)"))
termplot(model, rug = TRUE)
termplot(model, partial.resid = TRUE, se = TRUE, main = TRUE)
termplot(model, partial.resid = TRUE, smooth = panel.smooth, span.smth = 1/4)
if(!had.splines && rs) detach("package:splines")

\donttest{## 推奨パッケージ MASS が必要
hills.lm <- lm(log(time) ~ log(climb)+log(dist), data = MASS::hills)
termplot(hills.lm, partial.resid = TRUE, smooth = panel.smooth,
        terms = "log(dist)", main = "Original")
termplot(hills.lm, transform.x = TRUE,
         partial.resid = TRUE, smooth = panel.smooth,
	 terms = "log(dist)", main = "Transformed")

}}
\keyword{hplot}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/termplot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{termplot}
%\alias{termplot}
%\title{Plot Regression Terms}
%\description{
%  Plots regression terms against their predictors, optionally with
%  standard errors and partial residuals added.
%}
%\usage{
%termplot(model, data = NULL, envir = environment(formula(model)),
%         partial.resid = FALSE, rug = FALSE,
%         terms = NULL, se = FALSE,
%         xlabs = NULL, ylabs = NULL, main = NULL,
%         col.term = 2, lwd.term = 1.5,
%         col.se = "orange", lty.se = 2, lwd.se = 1,
%         col.res = "gray", cex = 1, pch = par("pch"),
%         col.smth = "darkred", lty.smth = 2, span.smth = 2/3,
%         ask = dev.interactive() && nb.fig < n.tms,
%         use.factor.levels = TRUE, smooth = NULL, ylim = "common",
%         plot = TRUE, transform.x = FALSE, \dots)
%}
%\arguments{
%  \item{model}{fitted model object}
%  \item{data}{data frame in which variables in \code{model} can be
%    found}
%  \item{envir}{environment in which variables in \code{model} can be found}
%  \item{partial.resid}{logical; should partial residuals be plotted?}
%  \item{rug}{add \link{rug}plots (jittered 1-d histograms) to the axes?}
%  \item{terms}{which terms to plot (default \code{NULL} means all
%    terms); a vector passed to
%    \code{\link{predict}(.., type = "terms", terms = *)}.}
%  \item{se}{plot pointwise standard errors?}
%  \item{xlabs}{vector of labels for the x axes}
%  \item{ylabs}{vector of labels for the y axes}
%  \item{main}{logical, or vector of main titles;  if \code{TRUE}, the
%    model's call is taken as main title, \code{NULL} or \code{FALSE} mean
%    no titles.}
%  \item{col.term, lwd.term}{color and line width for the \sQuote{term curve},
%    see \code{\link{lines}}.}
%  \item{col.se, lty.se, lwd.se}{color, line type and line width for the
%    \sQuote{twice-standard-error curve} when \code{se = TRUE}.}
%  \item{col.res, cex, pch}{color, plotting character expansion and type
%    for partial residuals, when \code{partial.resid = TRUE}, see
%    \code{\link{points}}.}
%   \item{ask}{logical; if \code{TRUE}, the user is \emph{ask}ed before
%     each plot, see \code{\link{par}(ask=.)}.}
%   \item{use.factor.levels}{Should x-axis ticks use factor levels or
%     numbers for factor terms?}
%   \item{smooth}{\code{NULL} or a function with the same arguments as
%     \code{\link{panel.smooth}} to draw a smooth through the partial
%     residuals for non-factor terms}
%   \item{lty.smth, col.smth, span.smth}{Passed to \code{smooth}}
%   \item{ylim}{an optional range for the y axis, or \code{"common"} when
%     a range sufficient for all the plot will be computed, or
%     \code{"free"} when limits are computed for each plot.}
%   \item{plot}{if set to \code{FALSE} plots are not produced: instead a
%     list is returned containing the data that would have been plotted.}
%   \item{transform.x}{logical vector; if an element (recycled as necessary)
%     is \code{TRUE}, partial residuals for the corresponding term are
%     plotted against transformed values.
%     The model response is then a straight line, allowing a
%     ready comparison against the data or against the curve
%     obtained from \code{smooth-panel.smooth}.}
%   \item{\dots}{other graphical parameters.}
%}
%\details{
%  The \code{model} object must have a \code{predict} method that accepts
%  \code{type = "terms"}, e.g., \code{\link{glm}} in the \pkg{stats} package,
%  \code{\link[survival]{coxph}} and \code{\link[survival]{survreg}} in
%  the \CRANpkg{survival} package.
%
%  For the \code{partial.resid = TRUE} option \code{model} must have a
%  \code{\link{residuals}} method that accepts \code{type = "partial"},
%  which \code{\link{lm}} and \code{\link{glm}} do.
%
%  The \code{data} argument should rarely be needed, but in some cases
%  \code{termplot} may be unable to reconstruct the original data
%  frame. Using \code{na.action=na.exclude} makes these problems less likely.
%
%  Nothing sensible happens for interaction terms, and they may cause errors.
%
%  The \code{plot = FALSE} option is useful when some special action is needed,
%  e.g.\sspace{}to overlay the results of two different models or to plot
%  confidence bands.
%}
%\value{
%  For \code{plot = FALSE}, a list with one element for each plot which
%  would have been produced.  Each element of the list is a data frame
%  with variables \code{x}, \code{y}, and optionally the pointwise
%  standard errors \code{se}. For continuous predictors \code{x} will
%  contain the ordered unique values and for a factor it will be a factor
%  containing one instance of each level.  The list has attribute
%  \code{"constant"} copied from the predicted terms object.
%
%  Otherwise, the number of terms, invisibly.
%}
%\seealso{For (generalized) linear models, \code{\link{plot.lm}} and
%  \code{\link{predict.glm}}.}
%\examples{
%require(graphics)
%
%had.splines <- "package:splines" \%in\% search()
%if(!had.splines) rs <- require(splines)
%x <- 1:100
%z <- factor(rep(LETTERS[1:4], 25))
%y <- rnorm(100, sin(x/10)+as.numeric(z))
%model <- glm(y ~ ns(x, 6) + z)
%
%par(mfrow = c(2,2)) ## 2 x 2 plots for same model :
%termplot(model, main = paste("termplot( ", deparse(model$call)," ...)"))
%termplot(model, rug = TRUE)
%termplot(model, partial.resid = TRUE, se = TRUE, main = TRUE)
%termplot(model, partial.resid = TRUE, smooth = panel.smooth, span.smth = 1/4)
%if(!had.splines && rs) detach("package:splines")
%
%\donttest{## requires recommended package MASS
%hills.lm <- lm(log(time) ~ log(climb)+log(dist), data = MASS::hills)
%termplot(hills.lm, partial.resid = TRUE, smooth = panel.smooth,
%        terms = "log(dist)", main = "Original")
%termplot(hills.lm, transform.x = TRUE,
%         partial.resid = TRUE, smooth = panel.smooth,
%	 terms = "log(dist)", main = "Transformed")
%
%}}
%\keyword{hplot}
%\keyword{regression}
%
%\encoding{UTF-8}
%
