% File src/library/stats/man/terms.formula.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{terms.formula}
\alias{terms.formula}%@%\alias{公式から terms オブジェクトを作る}
\title{Construct a terms Object from a Formula}
\description{
  この関数は公式と幾つかのオプション引数を取り，
  項オブジェクトを作る．  項オブジェクトはそれから
  \code{\link{model.matrix}} を作るのに使うことが出来る．
}
\usage{
\method{terms}{formula}(x, specials = NULL, abb = NULL, data = NULL, neg.out = TRUE,
      keep.order = FALSE, simplify = FALSE, \dots,
      allowDotAsName = FALSE)
}
\arguments{
  \item{x}{公式．}
  \item{specials}{
    公式中のどの関数が
    \code{terms} オブジェクト中で特別とマークされるべきか?
    文字列ベクトル又は \code{NULL}．}
  \item{abb}{\R では移植されていない．}
  \item{data}{
    特殊シンボル \code{.} の意味をそれから推測出来る
    データフレーム．公式中に \code{.} がなければ使われない．}
  \item{neg.out}{\R では移植されていない．}
  \item{keep.order}{
    項がそれらの位置を保つべきかどうかを指示する論理値．
    もし \code{FALSE} ならば項は主効果が最初，交互作用がそれに続き，
    全ての2次項，全ての3次項，等になるように
    並べ替えられる．
    与えられた順序の効果は指定された順序で保たれる．}
  \item{simplify}{
    バージョン 1.7.0 以前のように公式を展開し簡略化するべきか?}
  \item{\dots}{他のメソッドに・から渡される追加引数．}
  \item{allowDotAsName}{普通公式中の \code{.} は
    \code{data} 中に含まれる残りの変数をサンショする．
    例外的に，
    \code{.} は公式の非標準的な使用のために名前として扱うことが出来る．}
}
\details{
  全てのオプションが S と同じように動作するわけではなく，
  全てが移植されてはいない．
}
\value{
  \code{\link{terms.object}} オブジェクトが返される．オブジェクト自体は
  並べ替えられた(\code{keep.order = TRUE} で無い限り)公式である．
  全てのケースで公式中の交互作用項中の変数は
  公式中に変数が登場した順序である \code{"variables"} 属性の順序で並べ替えられる．
}
\seealso{
  \code{\link{terms}}, \code{\link{terms.object}}
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/terms.formula.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{terms.formula}
%\alias{terms.formula}
%\title{Construct a terms Object from a Formula}
%\description{
%  This function takes a formula and some optional arguments and
%  constructs a terms object. The terms object can then be used to
%  construct a \code{\link{model.matrix}}.
%}
%\usage{
%\method{terms}{formula}(x, specials = NULL, abb = NULL, data = NULL, neg.out = TRUE,
%      keep.order = FALSE, simplify = FALSE, \dots,
%      allowDotAsName = FALSE)
%}
%\arguments{
%  \item{x}{a formula.}
%  \item{specials}{which functions in the formula should be marked as
%    special in the \code{terms} object?  A character vector or \code{NULL}.}
%  \item{abb}{Not implemented in \R.}
%  \item{data}{a data frame from which the meaning of the special symbol
%    \code{.} can be inferred.  It is unused if there is no \code{.} in
%    the formula.}
%  \item{neg.out}{Not implemented in \R.}
%  \item{keep.order}{a logical value indicating whether the terms should
%    keep their positions.  If \code{FALSE} the terms are reordered so
%    that main effects come first, followed by the interactions,
%    all second-order, all third-order and so on.  Effects of a given
%    order are kept in the order specified.}
%  \item{simplify}{should the formula be expanded and simplified, the
%    pre-1.7.0 behaviour?}
%  \item{\dots}{further arguments passed to or from other methods.}
%  \item{allowDotAsName}{normally \code{.} in a formula refers to the
%    remaining variables contained in \code{data}.  Exceptionally,
%    \code{.} can be treated as a name for non-standard uses of formulae.}
%}
%\details{
%  Not all of the options work in the same way that they do in S and not
%  all are implemented.
%}
%\value{
%  A \code{\link{terms.object}} object is returned.  The object itself is
%  the re-ordered (unless \code{keep.order = TRUE}) formula.  In all
%  cases variables within an interaction term in the formula are
%  re-ordered by the ordering of the \code{"variables"} attribute, which
%  is the order in which the variables occur in the formula.
%}
%\seealso{
%  \code{\link{terms}}, \code{\link{terms.object}}
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
